(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    289435,       5408]
NotebookOptionsPosition[    284837,       5342]
NotebookOutlinePosition[    285210,       5358]
CellTagsIndexPosition[    285167,       5355]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Choi", " ", "matrix", " ", "of", " ", "AD", " ", "channel"}], 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"ADchoi", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         FractionBox["1", "2"], ",", "0", ",", "0", ",", 
         FractionBox[
          SqrtBox[
           RowBox[{"1", "-", "p"}]], "2"]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         FractionBox["p", "2"], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         FractionBox[
          SqrtBox[
           RowBox[{"1", "-", "p"}]], "2"], ",", "0", ",", "0", ",", 
         FractionBox[
          RowBox[{"1", "-", "p"}], "2"]}], "}"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "Choi", " ", "matrix", " ", "of", " ", "PBT", " ", "channel", " ", 
     "using", " ", "Choi", " ", "resource", " ", "to", " ", "simulate", " ", 
     "the", " ", "AD", " ", "channel"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"\[Xi]", " ", "is", " ", "the", " ", "PBT", " ", "number", " ", 
     RowBox[{"(", 
      RowBox[{
      "which", " ", "depends", " ", "on", " ", "the", " ", "number", " ", 
       "of", " ", "ports"}], ")"}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"choiWithChoiRes", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          FractionBox["1", "2"], "-", 
          RowBox[{
           FractionBox["1", "4"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "-", "p1"}], ")"}], " ", "\[Xi]"}]}], ",", "0", ",", 
         "0", ",", 
         RowBox[{
          SqrtBox[
           RowBox[{"1", "-", "p1"}]], " ", 
          RowBox[{"(", 
           RowBox[{
            FractionBox["1", "2"], "-", 
            FractionBox["\[Xi]", "2"]}], ")"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{
          FractionBox["1", "4"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", "p1"}], ")"}], " ", "\[Xi]"}], ",", "0", ",", 
         "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{
          RowBox[{"p1", " ", 
           RowBox[{"(", 
            RowBox[{
             FractionBox["1", "2"], "-", 
             FractionBox["\[Xi]", "4"]}], ")"}]}], "+", 
          FractionBox["\[Xi]", "4"]}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SqrtBox[
           RowBox[{"1", "-", "p1"}]], " ", 
          RowBox[{"(", 
           RowBox[{
            FractionBox["1", "2"], "-", 
            FractionBox["\[Xi]", "2"]}], ")"}]}], ",", "0", ",", "0", ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "p1"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            FractionBox["1", "2"], "-", 
            FractionBox["\[Xi]", "4"]}], ")"}]}]}], "}"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "Difference", " ", "between", " ", "the", " ", "two", " ", "Choi", " ", 
     "matrices"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"difChoi", "=", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{"choiWithChoiRes", "-", "ADchoi"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\"\<Find the two choices for p1 that set the on-diagonals to all be the \
same (ensuring the condition for diamond norm to equal trace norm is \
met).\>\"", "\[IndentingNewLine]", 
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"difChoi", "[", 
       RowBox[{"[", 
        RowBox[{"2", ",", "2"}], "]"}], "]"}], "\[Equal]", 
      RowBox[{"difChoi", "[", 
       RowBox[{"[", 
        RowBox[{"3", ",", "3"}], "]"}], "]"}]}], ",", "p1"}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"difChoi", "[", 
       RowBox[{"[", 
        RowBox[{"2", ",", "2"}], "]"}], "]"}], "\[Equal]", 
      RowBox[{"difChoi", "[", 
       RowBox[{"[", 
        RowBox[{"4", ",", "4"}], "]"}], "]"}]}], ",", "p1"}], "]"}], 
   "\[IndentingNewLine]", 
   "\"\<Trace norm for p1 set to \!\(\*FractionBox[\(\(-p\) + \[Xi]\), \(\(-1\
\) + \[Xi]\)]\).\>\"", "\[IndentingNewLine]", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"Tr", "[", 
      RowBox[{"MatrixPower", "[", 
       RowBox[{
        RowBox[{"MatrixPower", "[", 
         RowBox[{
          RowBox[{"FullSimplify", "[", 
           RowBox[{"difChoi", "/.", 
            RowBox[{"p1", "\[Rule]", 
             FractionBox[
              RowBox[{
               RowBox[{"-", "p"}], "+", "\[Xi]"}], 
              RowBox[{
               RowBox[{"-", "1"}], "+", "\[Xi]"}]]}]}], "]"}], ",", "2"}], 
         "]"}], ",", 
        RowBox[{"1", "/", "2"}]}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"p", ">", "0"}], ",", 
       RowBox[{"p", "<", "1"}], ",", 
       RowBox[{"\[Xi]", ">", "0"}], ",", 
       RowBox[{"\[Xi]", "<", "1"}]}], "}"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"traceNorm", "=", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "p"}], ")"}], " ", "\[Xi]"}], 
         RowBox[{"1", "-", "\[Xi]"}]], "+", 
        SqrtBox[
         RowBox[{
          RowBox[{"4", " ", 
           RowBox[{"(", 
            RowBox[{"1", "-", "p"}], ")"}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"1", "-", 
              SqrtBox[
               RowBox[{"1", "-", "\[Xi]"}]]}], ")"}], "2"]}], "+", 
          FractionBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"1", "-", "p"}], ")"}], "2"], " ", 
            SuperscriptBox["\[Xi]", "2"]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"1", "-", "\[Xi]"}], ")"}], "2"]]}]]}], ")"}]}]}], ";"}],
    "\[IndentingNewLine]", 
   "\"\<Plot of trace norm at each of the two points that set the \
on-diagonals to all be the same.\>\"", "\[IndentingNewLine]", 
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SqrtBox[
           RowBox[{"1", "-", "p"}]], "+", 
          FractionBox[
           RowBox[{"1", "-", "p"}], "2"]}], ")"}], " ", "\[Xi]"}], ",", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "-", "p"}], ")"}], " ", "\[Xi]"}], 
           RowBox[{"1", "-", "\[Xi]"}]], "+", 
          SqrtBox[
           RowBox[{
            RowBox[{"4", " ", 
             RowBox[{"(", 
              RowBox[{"1", "-", "p"}], ")"}], 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"1", "-", 
                SqrtBox[
                 RowBox[{"1", "-", "\[Xi]"}]]}], ")"}], "2"]}], "+", 
            FractionBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"1", "-", "p"}], ")"}], "2"], " ", 
              SuperscriptBox["\[Xi]", "2"]}], 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"1", "-", "\[Xi]"}], ")"}], "2"]]}]]}], ")"}]}]}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Xi]", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"p", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", "Automatic"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.769787957221686*^9, 3.7697880295781183`*^9}, {
  3.7697881835056906`*^9, 3.7697881839063263`*^9}, {3.7697882253236217`*^9, 
  3.769788225923492*^9}, {3.769947943913024*^9, 3.7699479466063337`*^9}, {
  3.825951157372897*^9, 3.8259511672071433`*^9}, {3.82595452524372*^9, 
  3.8259545464748216`*^9}, {3.8259554988970027`*^9, 3.8259555081758175`*^9}, {
  3.8259555671637506`*^9, 3.8259556449574327`*^9}, {3.825955678275298*^9, 
  3.8259556796945357`*^9}, {3.825955769497839*^9, 3.8259557722072906`*^9}, {
  3.825955807442236*^9, 3.8259558260668535`*^9}, {3.825955869321176*^9, 
  3.825955941525532*^9}, {3.8259663432621865`*^9, 3.825966367724287*^9}},
 CellLabel->
  "In[449]:=",ExpressionUUID->"9f571f6c-caa4-4184-8d04-47059d57c182"],

Cell[BoxData["\<\"Find the two choices for p1 that set the on-diagonals to \
all be the same (ensuring the condition for diamond norm to equal trace norm \
is met).\"\>"], "Output",
 CellChangeTimes->{3.825966499411265*^9, 3.825966565894486*^9},
 CellLabel->
  "Out[452]=",ExpressionUUID->"bcd1ef54-3416-42d6-a592-4d8f63eebc66"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"p1", "\[Rule]", "p"}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.825966499411265*^9, 3.825966565899472*^9},
 CellLabel->
  "Out[453]=",ExpressionUUID->"1d28e567-032d-472e-9b4b-af15fa691c05"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"p1", "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"-", "p"}], "+", "\[Xi]"}], 
     RowBox[{
      RowBox[{"-", "1"}], "+", "\[Xi]"}]]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.825966499411265*^9, 3.8259665659044895`*^9},
 CellLabel->
  "Out[454]=",ExpressionUUID->"1e7c2325-aef2-4a57-8e8b-e0777d5f3d58"],

Cell[BoxData["\<\"Trace norm for p1 set to \\!\\(\\*FractionBox[\\(\\(-p\\) + \
\[Xi]\\), \\(\\(-1\\) + \[Xi]\\)]\\).\"\>"], "Output",
 CellChangeTimes->{3.825966499411265*^9, 3.825966565908452*^9},
 CellLabel->
  "Out[455]=",ExpressionUUID->"ac5eea89-94f5-4323-a11a-c77cf0c3c981"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "p"}], ")"}], " ", "\[Xi]"}], 
     RowBox[{
      RowBox[{"-", "1"}], "+", "\[Xi]"}]], "+", 
    SqrtBox[
     RowBox[{
      RowBox[{"4", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SqrtBox[
           RowBox[{"1", "-", "p"}]], "+", 
          RowBox[{
           SqrtBox[
            FractionBox[
             RowBox[{
              RowBox[{"-", "1"}], "+", "p"}], 
             RowBox[{
              RowBox[{"-", "1"}], "+", "\[Xi]"}]]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "\[Xi]"}], ")"}]}]}], ")"}], "2"]}], 
      "+", 
      FractionBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "p"}], ")"}], "2"], " ", 
        SuperscriptBox["\[Xi]", "2"]}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Xi]"}], ")"}], "2"]]}]]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.825966499411265*^9, 3.825966568372554*^9},
 CellLabel->
  "Out[456]=",ExpressionUUID->"dfb31ee2-aab9-46d7-97ef-b3855689dab7"],

Cell[BoxData["\<\"Plot of trace norm at each of the two points that set the \
on-diagonals to all be the same.\"\>"], "Output",
 CellChangeTimes->{3.825966499411265*^9, 3.825966568379363*^9},
 CellLabel->
  "Out[458]=",ExpressionUUID->"6392d7b2-920d-4fc7-8c35-f672a758baaf"],

Cell[BoxData[
 Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJyUnQc8V9//+BFNTaSioaSlPTRwtWnvoSWjoaQkhYrS0C6hQSWhIpXITGRH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   "], {{
     {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[None], Specularity[
       GrayLevel[1], 3], 
      StyleBox[GraphicsGroup3DBox[
        TagBox[{Polygon3DBox[CompressedData["
1:eJwtmgf8ldMfx8/lnkfn+t0bUak0KA1pEJUKDe1dNIxk7+y/3VBkZCWjrAgp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           "]], Polygon3DBox[CompressedData["
1:eJwtmgW4VsUWhvcvZ2+dzTlHkVDBQkEElLYVAcVCTFREsPXqta7dndjd3dit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           "]], Polygon3DBox[CompressedData["
1:eJwt13mcTmUbB/AHM49mzAzCjH3f9+yRpWztpNIqvZa0ifZV3tJuqdCq7Q3J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           "]], Polygon3DBox[{{2651, 1623, 1390, 1391, 1624, 2652}}]},
         Annotation[#, "Charting`Private`Tag$259809#1"]& ]],
       Lighting->{{"Ambient", 
          RGBColor[0.30100577, 0.22414668499999998`, 0.090484535]}, {
         "Directional", 
          RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
          ImageScaled[{0, 2, 2}]}, {"Directional", 
          RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
          ImageScaled[{2, 2, 2}]}, {"Directional", 
          RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
          ImageScaled[{2, 0, 2}]}}]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], EdgeForm[None], Specularity[
       GrayLevel[1], 3], 
      StyleBox[GraphicsGroup3DBox[
        TagBox[{Polygon3DBox[CompressedData["
1:eJxNmge0FdWyRU+4nm66z+krBlDAgIoRFBTJRkSfGVCMIDmqKAYUE+acAyiS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           "]], Polygon3DBox[CompressedData["
1:eJw1mnWgFdXXhs8993pmOHPnYoKBgYEFKIqKhQHmz1ZsQAEDu7sLGztQQhQs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           "]], Polygon3DBox[CompressedData["
1:eJwt1nm8T+UWx/Gd6XCOc9RNKlORkoQjmYeoqKSBJm5pQiU3ihAlZajbVWig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           "]], 
          Polygon3DBox[{{3200, 1085, 1095, 2102, 2148, 3117}, {2828, 2827, 
           3441, 2261, 2262, 3442}, {3029, 2098, 1866, 1867, 2099, 3030}}]},
         Annotation[#, "Charting`Private`Tag$259809#2"]& ]],
       Lighting->{{"Ambient", 
          RGBColor[
          0.19699838300000003`, 0.252204821, 0.33320940200000004`]}, {
         "Directional", 
          RGBColor[
          0.15473514000000002`, 0.21284718000000002`, 0.29811516000000005`], 
          ImageScaled[{0, 2, 2}]}, {"Directional", 
          RGBColor[
          0.15473514000000002`, 0.21284718000000002`, 0.29811516000000005`], 
          ImageScaled[{2, 2, 2}]}, {"Directional", 
          RGBColor[
          0.15473514000000002`, 0.21284718000000002`, 0.29811516000000005`], 
          ImageScaled[{2, 0, 2}]}}]}, {}, 
     {GrayLevel[1], EdgeForm[None], 
      StyleBox[GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJxNmge0FUUShu+7PTyGNwMXM6gIJjB71DXsGtYsmNbAGmDXrBhIimTEgBhw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          "]], Polygon3DBox[CompressedData["
1:eJwtmHfQHlUVxt/v3Zdk+Xa/hA46gzQxdEYUsIAgKCGVIkhTmhBKKhBCSKEk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          "]], Polygon3DBox[CompressedData["
1:eJwlkjssQ3EUxk/1tq7b24qQSCxitnlEiNcgmmgq0smqCYJqhSZaEo/QSlgI
Ea+NVFsmhhoJImJiEI/EYDSKzeL39x++5Hzf+c7jf+6tCcdC0SIRqQYuUG+L
9CM4TZExUAcf9opsEW+CcnK3HpE29DhxGdoKaIVvAFeJiFEscucQWYaPU3tB
vgD20AJoR9R3U2uhzYBGtGdLJEf+Gn4DotR58e076WOILIEUvm9822gL8HlD
z4jhSzDzyi0yS48zS0PFJ/Q6BRH6BfFeEn+59axeeIZaP7vY6HOgCa0DJNAq
4GugHd4J1okrQYBclrqqUnqq97NHGsSZsYovSZx16FlvPpE83iA1v/AwqMXj
Vz7ekYfn1K2pLeAbwXcPfwB9eKbQX4hfTX0LdZMJtEf4k6lvoW4i3H2XuTuG
/kYD5KY9+uYfvPcc3mPrHdQun+AAr5O6kK17v6t9Tf2OQWoj3PRH3Y4eGWYM
oafgaTBJvc+j9f882jEYxdOg/g1iN+jCd4ivGW0R7lX90Frgf0rxURs=
          "]], 
         Polygon3DBox[{{2934, 1141, 2306, 1745, 394, 2750}, {3159, 693, 1164, 
          2308, 2270, 3158}}]}],
       Lighting->{{"Ambient", 
          GrayLevel[0.8]}}]}, {}, {}, {}}, {
     {GrayLevel[0], Line3DBox[CompressedData["
1:eJwl0rtPUwEUwOED9gFW0YHFRcJiXGRTEwLiA+uAAS1xwa2JTagJrrpYLCS4
qah0My6wGRY0hhCisTEGhRDxRX0Ai+HP4Lsh6en3O01v7+1tO4t3CmNNEfHY
XBNJX/L0n7nWiKM8xg6eZBfPspd5XuUN3uQtlkxZV3mPT/iQL1njPOe4zNdc
ZZ2lgxFp5+02G/YzTJn76Yhv9gq/86LXxvUP/SwT0W//qZ/ry/qXntF5valr
+op+4JiGvUdX9W/dqyf0H31OT+q/yTU7ps/+T0/r83pLP9UX9LYu66wumB37
ENvNru/z1d7gB37mApc4y1ec4QtO8RHvcpwVM6qLHOEwB9jPHp7mKZ7gcQ66
Z7u87rxHkp2tZj0V0WZf42F+4SGuMMdPdGh8pI+KOlv4nu9MNvl9mEmum25L
LNIj3no6wDds5m1vamna/+/sAUk0RS0=
       "]]}, 
     {GrayLevel[0], Line3DBox[CompressedData["
1:eJwl0rlPk3Ecx/GvaAp4DA5uOpCwGG+hB6UFxPtWiCJyt4UWlWKMm4OjmngM
GgXxipMDxhg0Rg3R2fgPkLDLf4Cjr8bhndfn9/TpQ4E2FaZ7qmsiYlHVtRFj
Dln21kW8WB9x3fkdb/MTH/InX/I357nE7/zDX1zlXy3ZmzdErHAbV7mdCc9O
cgu72cxlzvGGn93CKc6zvz6ilZeZ5IjrA3bKHrUH7bT9tMFnd87Yz+yC3WbP
2EU7a8/aJXvIe9qdh5mrPZP52vPYwYr7Mu7rtMt22r6pLuec82umnLeuizhg
L/CqLqiqM7qmaU3pojo1pPN6u9Hvw9PqVY86dFR5PfL6IPt1RGc1oHNqbIw4
zEt64L5hptSnpHK67/ohHlSrTumVayfZrWO1z60TavC8ST7x+hVW1KXjKmtc
j702wZLm7Ba2q6iCbm2KqPec/faYRvXcffs4oll7L/coqxnn3bzHNia8dxfv
Ome4U3fsNHfU/ra+Nz8SPh8XOclv/KqK/YVlfuYEFzjOjyzxA4t8zwLz/odv
6v5/3/8BwFhRwA==
       "]], Line3DBox[CompressedData["
1:eJwl0stK1VEUx/Hl8aiVgaASIRHdCRGhwBeJqIGDwAYNupzUTDMvaWmWWWla
VqeL3TStrHDkUAr0DXyDDIJALAKR+mwafPld9llrbzj/3Q25I+cKImIaC8UR
Z4S1TRHnsxGNGNsa0USbcZ+/QDObI1roA/ki7aettA2XcFNup5dxl++gnehC
kdlhXTd/BT3oxYjuKr2GPN+X9uI6BnAj7cUTZ4M0a88tOoTbuJPuwqDz4bQP
9zCKZ7qx9P70ZozjIZ7rH9HHKLQvn/bjaZpJ55hI+N0L+hKv8BpvMImpdL/z
t3QaM3iH9/iAWXzEJ3zGHI6ivNA9mYg6Wl8acZgv48dprX2H+L18CR2gNbpa
vpLP0kUzvXw1X0QzdEHXwR/kf/sfK838lVtxQPdNV6HbkJuxT1dmZlm/Luew
R7e2JWJJ90c+jf1mdunndb/kU2lWt1M3o1uVT2KHnJd/8nP2nqBVuiHdD74e
2+UuudT8d/k4tulyaQ9dkY+lt/BffY/p45yQv/BnC/5/o/8AAuJavg==
       "]]}, 
     {GrayLevel[0.2], 
      Line3DBox[{2315, 2636, 3235, 3653, 2314, 3452, 2537, 2316, 3453, 2538, 
       2317, 3454, 2539, 2318, 3455, 2540, 2319, 3456, 2541, 2320, 3457, 3236,
        3558, 2321, 3237, 3559, 2322, 3458, 2542, 2323, 3459, 2543, 2324, 
       3460, 2544, 2325, 3461, 2545, 2326, 3462, 2546, 2327, 3654, 2637, 2547,
        2638}], 
      Line3DBox[{2329, 3238, 3560, 2328, 3239, 3561, 2330, 3463, 2548, 2331, 
       3464, 2549, 2332, 3465, 2550, 2333, 3466, 2551, 2334, 3467, 3240, 3562,
        2335, 3241, 3563, 2336, 3242, 3564, 2337, 3468, 2552, 2338, 3469, 
       2553, 2339, 3470, 2554, 2340, 3471, 2555, 2341, 3472, 2556, 2342}], 
      Line3DBox[{2344, 3243, 3565, 2343, 3244, 3566, 2345, 3245, 3567, 2346, 
       3473, 2557, 2347, 3474, 2558, 2348, 3475, 2559, 2349, 3476, 3246, 3568,
        2350, 3247, 3569, 2351, 3248, 3570, 2352, 3249, 3571, 2353, 3477, 
       2560, 2354, 3478, 2561, 2355, 3479, 2562, 2356, 3480, 2563, 2357}], 
      Line3DBox[{2359, 3250, 3572, 2358, 3251, 3573, 2360, 3252, 3574, 2361, 
       3253, 3575, 2362, 3481, 2564, 2363, 3482, 2565, 2364, 3483, 3254, 3576,
        2365, 3255, 3577, 2366, 3256, 3578, 2367, 3257, 3579, 2368, 3258, 
       3580, 2369, 3484, 2566, 2370, 3485, 2567, 2371, 3486, 2568, 2372}], 
      Line3DBox[{2374, 3259, 3581, 2373, 3260, 3582, 2375, 3261, 3583, 2376, 
       3262, 3584, 2377, 3263, 3585, 2378, 3487, 2569, 2379, 3488, 3264, 3586,
        2380, 3265, 3587, 2381, 3266, 3588, 2382, 3267, 3589, 2383, 3268, 
       3590, 2384, 3269, 3591, 2385, 3489, 2570, 2386, 3490, 2571, 2387}], 
      Line3DBox[{2389, 3270, 3592, 2388, 3271, 3593, 2390, 3272, 3594, 2391, 
       3273, 3595, 2392, 3274, 3596, 2393, 3275, 3597, 2394, 3491, 3276, 3598,
        2395, 3277, 3599, 2396, 3278, 3600, 2397, 3279, 3601, 2398, 3280, 
       3602, 2399, 3281, 3603, 2400, 3282, 3604, 2401, 3492, 2572, 2402}], 
      Line3DBox[{2406, 3493, 2573, 2404, 3494, 2574, 2408, 3495, 2575, 2410, 
       3496, 2576, 2412, 3497, 2577, 2414, 3498, 2578, 2416, 3499, 3500, 2579,
        2418, 3501, 2580, 2420, 3502, 2581, 2422, 3503, 2582, 2424, 3504, 
       2583, 2426, 3505, 2584, 2428, 3506, 2585, 2430, 3507, 2586, 2432}], 
      Line3DBox[{2431, 3619, 3296, 2429, 3618, 3295, 2427, 3617, 3294, 2425, 
       3616, 3293, 2423, 3615, 3292, 2421, 3614, 3291, 2419, 3613, 3290, 2417,
        3612, 3611, 3289, 2415, 3610, 3288, 2413, 3609, 3287, 2411, 3608, 
       3286, 2409, 3607, 3285, 2407, 3606, 3284, 2403, 3605, 3283, 2405}], 
      Line3DBox[{2434, 3508, 2587, 2433, 3509, 2588, 2435, 3510, 2589, 2436, 
       3511, 2590, 2437, 3512, 2591, 2438, 3513, 2592, 2439, 3514, 3297, 3620,
        2440, 3515, 2593, 2441, 3516, 2594, 2442, 3517, 2595, 2443, 3518, 
       2596, 2444, 3519, 2597, 2445, 3520, 2598, 2446, 3521, 2599, 2447}], 
      Line3DBox[{2449, 3298, 3621, 2448, 3522, 2600, 2450, 3523, 2601, 2451, 
       3524, 2602, 2452, 3525, 2603, 2453, 3526, 2604, 2454, 3527, 3299, 3622,
        2455, 3300, 3623, 2456, 3528, 2605, 2457, 3529, 2606, 2458, 3530, 
       2607, 2459, 3531, 2608, 2460, 3532, 2609, 2461, 3533, 2610, 2462}], 
      Line3DBox[{2464, 3301, 3624, 2463, 3302, 3625, 2465, 3534, 2611, 2466, 
       3535, 2612, 2467, 3536, 2613, 2468, 3537, 2614, 2469, 3538, 3303, 3626,
        2470, 3304, 3627, 2471, 3305, 3628, 2472, 3539, 2615, 2473, 3540, 
       2616, 2474, 3541, 2617, 2475, 3542, 2618, 2476, 3543, 2619, 2477}], 
      Line3DBox[{2479, 3306, 3629, 2478, 3307, 3630, 2480, 3308, 3631, 2481, 
       3544, 2620, 2482, 3545, 2621, 2483, 3546, 2622, 2484, 3547, 3309, 3632,
        2485, 3310, 3633, 2486, 3311, 3634, 2487, 3312, 3635, 2488, 3548, 
       2623, 2489, 3549, 2624, 2490, 3550, 2625, 2491, 3551, 2626, 2492}], 
      Line3DBox[{2494, 3313, 3636, 2493, 3314, 3637, 2495, 3315, 3638, 2496, 
       3316, 3639, 2497, 3552, 2627, 2498, 3553, 2628, 2499, 3554, 3317, 3640,
        2500, 3318, 3641, 2501, 3319, 3642, 2502, 3320, 3643, 2503, 3321, 
       3644, 2504, 3555, 2629, 2505, 3556, 2630, 2506, 3557, 2631, 2507}], 
      Line3DBox[{2509, 2639, 2640, 3655, 2508, 2642, 2643, 3656, 2510, 2645, 
       3645, 3322, 2511, 3323, 3646, 2647, 2512, 3325, 3647, 2648, 2513, 3657,
        2649, 2650, 2514, 3659, 2651, 2652, 3658, 2515, 2653, 2654, 3660, 
       2516, 2655, 2656, 3661, 2517, 2657, 3648, 3328, 2518, 3329, 3649, 2658,
        2519, 3330, 3650, 2659, 2520, 3662, 2660, 2661, 2521, 3675, 2710, 
       2711, 2522}], Line3DBox[CompressedData["
1:eJwVzccyQ3EUwOFj2DB4B8/CQlkgIsRkZSFqrt579F5n8Gpa9DyEwWfxzTn/
35m5t6E/SRUqIiJHuToiXxNxwx235OojvvQr+zUTXNKlV9VFfLqde18wTp9+
Zp7y4XZsnpCQdTsyD3l32zcPaNIL5h67vLntmL16pX+M2bfZ4tWtW9+0Fxll
g3Ve3NJuq/Y1RlhhmR695L5oX2KYlPZbG/Gsz3svMESn/qM/6bPecwzSoX/r
j/q09wyNWsZs40GfNDPalJmmlXu9XWv5/zbNDPAHhZI1hA==
       "]], 
      Line3DBox[{2716, 2990, 3333, 3677, 2715, 3766, 2908, 2717, 3767, 2909, 
       2718, 3768, 2910, 2719, 3769, 2911, 2720, 3770, 2912, 2721, 3771, 2913,
        2722, 3772, 3773, 2914, 2723, 3774, 2915, 2724, 3775, 2916, 2725, 
       3207}], Line3DBox[{2728, 3334, 3678, 2727, 3335, 3679, 2729, 3776, 
       2920, 2730, 3777, 2921, 2731, 3778, 2922, 2732, 3779, 2923, 2733, 3780,
        2924, 2734, 3781, 3336, 3680, 2735, 3782, 2925, 2736, 3783, 2926, 
       2737, 3208}], 
      Line3DBox[{2740, 3337, 3681, 2739, 3338, 3682, 2741, 3339, 3683, 2742, 
       3784, 2929, 2743, 3785, 2930, 2744, 3786, 2931, 2745, 3787, 2932, 2746,
        3788, 3340, 3684, 2747, 3341, 3685, 2748, 3789, 2933, 2749, 3790, 
       3209}], Line3DBox[{2752, 3342, 3686, 2751, 3343, 3687, 2753, 3344, 
       3688, 2754, 3345, 3689, 2755, 3793, 2936, 2756, 3794, 2937, 2757, 3795,
        2938, 2758, 3796, 3346, 3690, 2759, 3347, 3691, 2760, 3348, 3692, 
       2761, 3797, 3198, 3224}], 
      Line3DBox[{2764, 3349, 3693, 2763, 3350, 3694, 2765, 3351, 3695, 2766, 
       3352, 3696, 2767, 3353, 3697, 2768, 3799, 2939, 2769, 3800, 2940, 2770,
        3801, 3354, 3698, 2771, 3355, 3699, 2772, 3356, 3700, 2773, 3357, 
       3701, 3197, 3225}], 
      Line3DBox[{2777, 3358, 3702, 2776, 3359, 3703, 2778, 3360, 3704, 2779, 
       3361, 3705, 2780, 3362, 3706, 2781, 3363, 3707, 2782, 3803, 2941, 2783,
        3804, 3364, 3708, 2784, 3365, 3709, 2785, 3366, 3710, 2786, 3367, 
       3711, 2787, 3203, 3226}], 
      Line3DBox[{2791, 3368, 3712, 2790, 3369, 3713, 2792, 3370, 3714, 2793, 
       3371, 3715, 2794, 3372, 3716, 2795, 3373, 3717, 2796, 3374, 3718, 2797,
        3805, 3375, 3719, 2798, 3376, 3720, 2799, 3377, 3721, 2800, 3378, 
       3722, 2801, 3439, 3897, 3451}], 
      Line3DBox[{2808, 3380, 3724, 2806, 3806, 2942, 2810, 3807, 2943, 2812, 
       3808, 2944, 2814, 3809, 2945, 2816, 3810, 2946, 2818, 3811, 2947, 2820,
        3813, 3814, 2948, 2822, 3815, 2949, 2824, 3816, 2950, 2826, 3817, 
       2951, 2828, 3442, 3886, 2952, 3219}], 
      Line3DBox[{2833, 3391, 3735, 2832, 3392, 3736, 2834, 3818, 2955, 2835, 
       3819, 2956, 2836, 3820, 2957, 2837, 3821, 2958, 2838, 3822, 2959, 2839,
        3823, 3393, 3737, 2840, 3824, 2960, 2841, 3825, 2961, 2842, 3826, 
       2962, 2843, 3445, 3888, 2963, 3157, 3220}], 
      Line3DBox[{2845, 3394, 3738, 2844, 3395, 3739, 2846, 3396, 3740, 2847, 
       3827, 2965, 2848, 3828, 2966, 2849, 3829, 2967, 2850, 3830, 2968, 2851,
        3831, 3397, 3741, 2852, 3398, 3742, 2853, 3832, 2969, 2854, 3833, 
       2970, 2855, 3834, 3008, 3056, 2971, 3037, 3428, 3835, 3201, 3057, 
       3230}], Line3DBox[{2857, 3399, 3743, 2856, 3400, 3744, 2858, 3401, 
       3745, 2859, 3402, 3746, 2860, 3836, 2972, 2861, 3837, 2973, 2862, 3838,
        2974, 2863, 3839, 3403, 3747, 2864, 3404, 3748, 2865, 3405, 3749, 
       2866, 3840, 2975, 2867, 3841, 3011, 3058, 2976, 3038, 3842, 3012, 3039,
        3199, 3212}], 
      Line3DBox[{2869, 3406, 3750, 2868, 3407, 3751, 2870, 3408, 3752, 2871, 
       3409, 3753, 2872, 3410, 3754, 2873, 3844, 2977, 2874, 3845, 2978, 2875,
        3846, 3411, 3755, 2876, 3412, 3756, 2877, 3413, 3757, 2878, 3414, 
       3758, 2879, 3847, 3017, 3059, 3018, 2880, 3854, 3014, 3040, 3015, 3114,
        3140, 3213}], 
      Line3DBox[{2882, 3415, 3759, 2881, 3416, 3760, 2883, 3021, 3855, 3421, 
       2884, 3023, 3856, 3422, 2885, 3423, 3857, 3025, 2886, 3425, 3859, 3026,
        2887, 3848, 3027, 3028, 2888, 3849, 3029, 3030, 3761, 2889, 3167, 
       3892, 3450, 2890, 3417, 3762, 2891, 3418, 3763, 2892, 3446, 3889, 3162,
        2893, 3890, 3165, 3019, 3166, 3020, 3095, 3141, 3862, 3117, 3200, 
       3215}], Line3DBox[CompressedData["
1:eJwVz7tOAmEUReFjJyiaEIgK44VErDXGJzCxMqCDdy1wCIk2Wqqtj2JvB69B
6BS18focfhQrZ+91Tv7M1LLb9GYiInbxMRXxhnf0ZiIa5vl0xOZsxF0hoqkP
8ImuPscv2O/pQ3wh4apcBft6212R+5YXuQSpnPEl/kde5pbQkjt8mf+Va9wK
DuQq92L+4YKb1x/cHuqXeoY2tvh7/mj87WbffxzL1/Ka3Y6bk/Ebel5/lk9x
pa/q2/aves6cxJlc59flDYz0R/MJ/3EwIwo=
       "]], 
      Line3DBox[{3227, 3898, 3441, 2827, 3734, 3390, 2825, 3733, 3389, 2823, 
       3732, 3388, 2821, 3731, 3387, 3812, 2819, 3730, 3386, 2817, 3729, 3385,
        2815, 3728, 3384, 2813, 3727, 3383, 2811, 3726, 3382, 2809, 3725, 
       3381, 2805, 3723, 3379, 2807}]}, 
     {GrayLevel[0.2], 
      Line3DBox[{1206, 1414, 3452, 1207, 3561, 1428, 1235, 3566, 1443, 1250, 
       3573, 1458, 1265, 3582, 1473, 1280, 3593, 1488, 1295, 3606, 1503, 3494,
        1310, 1518, 3509, 1325, 1533, 3522, 1340, 3625, 1548, 1355, 3630, 
       1563, 1370, 3637, 1578, 1385, 1610, 3656, 1593, 1400, 3670, 291, 1651, 
       1600, 1407}], 
      Line3DBox[{1208, 1415, 3453, 1209, 1429, 3463, 1236, 3567, 1444, 1251, 
       3574, 1459, 1266, 3583, 1474, 1281, 3594, 1489, 1296, 3607, 1504, 3495,
        1311, 1519, 3510, 1326, 1534, 3523, 1341, 1549, 3534, 1356, 3631, 
       1564, 1371, 3638, 1579, 1386, 3645, 1611, 1594, 1401, 1666, 3651, 1605,
        1652, 1601, 1408}], 
      Line3DBox[{1210, 1416, 3454, 1211, 1430, 3464, 1237, 1445, 3473, 1252, 
       3575, 1460, 1267, 3584, 1475, 1282, 3595, 1490, 1297, 3608, 1505, 3496,
        1312, 1520, 3511, 1327, 1535, 3524, 1342, 1550, 3535, 1357, 1565, 
       3544, 1372, 3639, 1580, 1387, 3646, 1612, 1613, 1644, 3664, 1614, 1653,
        1615, 1697, 1684}], 
      Line3DBox[{1212, 1417, 3455, 1213, 1431, 3465, 1238, 1446, 3474, 1253, 
       1461, 3481, 1268, 3585, 1476, 1283, 3596, 1491, 1298, 3609, 1506, 3497,
        1313, 1521, 3512, 1328, 1536, 3525, 1343, 1551, 3536, 1358, 1566, 
       3545, 1373, 1581, 3552, 1388, 3647, 1616, 1617, 1645, 3665, 1618, 1654,
        1619, 1698, 1685}], 
      Line3DBox[{1214, 1418, 3456, 1215, 1432, 3466, 1239, 1447, 3475, 1254, 
       1462, 3482, 1269, 1477, 3487, 1284, 3597, 1492, 1299, 3610, 1507, 3498,
        1314, 1522, 3513, 1329, 1537, 3526, 1344, 1552, 3537, 1359, 1567, 
       3546, 1374, 1582, 3553, 1389, 1620, 3657, 1621, 1646, 3666, 1622, 1655,
        1700, 1699, 1686}], 
      Line3DBox[{1216, 1419, 3457, 1218, 1433, 3467, 1240, 1448, 3476, 1255, 
       1463, 3483, 1270, 1478, 3488, 1285, 1493, 3491, 1300, 3611, 1508, 3499,
        1315, 1523, 3514, 1330, 1538, 3527, 1345, 1553, 3538, 1360, 1568, 
       3547, 1375, 1583, 3554, 1390, 1623, 3659, 1625, 1647, 1667, 3671, 1668,
        1656, 1702, 1701, 1687}], 
      Line3DBox[{1220, 3559, 1421, 1221, 3563, 1435, 1242, 3569, 1450, 1257, 
       3577, 1465, 1272, 3587, 1480, 1287, 3599, 1495, 1302, 3613, 1510, 3501,
        1317, 1525, 3515, 1332, 3623, 1540, 1347, 3627, 1555, 1362, 3633, 
       1570, 1377, 3641, 1585, 1392, 1626, 3660, 1596, 1403, 1671, 3669, 1672,
        1658, 1692, 1603, 1410}], 
      Line3DBox[{1222, 1422, 3458, 1223, 3564, 1436, 1243, 3570, 1451, 1258, 
       3578, 1466, 1273, 3588, 1481, 1288, 3600, 1496, 1303, 3614, 1511, 3502,
        1318, 1526, 3516, 1333, 1541, 3528, 1348, 3628, 1556, 1363, 3634, 
       1571, 1378, 3642, 1586, 1393, 1627, 3661, 1597, 1404, 3672, 1673, 1628,
        1659, 1693, 1694, 1411}], 
      Line3DBox[{1224, 1423, 3459, 1225, 1437, 3468, 1244, 3571, 1452, 1259, 
       3579, 1467, 1274, 3589, 1482, 1289, 3601, 1497, 1304, 3615, 1512, 3503,
        1319, 1527, 3517, 1334, 1542, 3529, 1349, 1557, 3539, 1364, 3635, 
       1572, 1379, 3643, 1587, 1394, 3648, 1629, 1598, 1405, 1674, 3652, 1630,
        1660, 1695, 1696, 1412}], 
      Line3DBox[{1226, 1424, 3460, 1227, 1438, 3469, 1245, 1453, 3477, 1260, 
       3580, 1468, 1275, 3590, 1483, 1290, 3602, 1498, 1305, 3616, 1513, 3504,
        1320, 1528, 3518, 1335, 1543, 3530, 1350, 1558, 3540, 1365, 1573, 
       3548, 1380, 3644, 1588, 1395, 3649, 1631, 1632, 1648, 1675, 3673, 1633,
        1661, 1634, 1688, 1681}], 
      Line3DBox[{1228, 1425, 3461, 1229, 1439, 3470, 1246, 1454, 3478, 1261, 
       1469, 3484, 1276, 3591, 1484, 1291, 3603, 1499, 1306, 3617, 1514, 3505,
        1321, 1529, 3519, 1336, 1544, 3531, 1351, 1559, 3541, 1366, 1574, 
       3549, 1381, 1589, 3555, 1396, 3650, 1635, 1636, 1649, 1676, 3674, 1637,
        1662, 1638, 1689, 1682}], 
      Line3DBox[{1230, 1426, 3462, 1231, 1440, 3471, 1247, 1455, 3479, 1262, 
       1470, 3485, 1277, 1485, 3489, 1292, 3604, 1500, 1307, 3618, 1515, 3506,
        1322, 1530, 3520, 1337, 1545, 3532, 1352, 1560, 3542, 1367, 1575, 
       3550, 1382, 1590, 3556, 1397, 1639, 3662, 1640, 1650, 3667, 1677, 1678,
        1663, 1691, 1690, 1683}], 
      Line3DBox[{1232, 1607, 3654, 1608, 1233, 1441, 3472, 1248, 1456, 3480, 
       1263, 1471, 3486, 1278, 1486, 3490, 1293, 1501, 3492, 1308, 3619, 1516,
        3507, 1323, 1531, 3521, 1338, 1546, 3533, 1353, 1561, 3543, 1368, 
       1576, 3551, 1383, 1591, 3557, 1398, 1703, 3675, 1704, 1705, 1706, 3676,
        1707, 1664, 1680, 1679, 1642}], 
      Line3DBox[{1406, 1599, 1665, 1641, 3663, 1604, 1399, 1592, 3655, 1609, 
       1384, 1577, 3636, 1369, 1562, 3629, 1354, 1547, 3624, 1339, 1532, 3621,
        1324, 3508, 1517, 1309, 3493, 1502, 3605, 1294, 1487, 3592, 1279, 
       1472, 3581, 1264, 1457, 3572, 1249, 1442, 3565, 1234, 1427, 3560, 1205,
        1413, 3653, 1606, 1643}], 
      Line3DBox[{1409, 1602, 1657, 1670, 3668, 1669, 1402, 1595, 3658, 1624, 
       1391, 1584, 3640, 1376, 1569, 3632, 1361, 1554, 3626, 1346, 1539, 3622,
        1331, 1524, 3620, 1316, 3500, 1509, 3612, 1301, 1494, 3598, 1286, 
       1479, 3586, 1271, 1464, 3576, 1256, 1449, 3568, 1241, 1434, 3562, 1219,
        1420, 3558, 1217}], 
      Line3DBox[{1709, 1890, 3766, 1710, 3679, 1902, 1735, 3682, 1914, 1748, 
       3687, 1925, 1760, 3694, 1936, 1772, 3703, 1948, 1785, 3713, 1960, 1798,
        3725, 1972, 3806, 1810, 3736, 1984, 1823, 3739, 1996, 1836, 3744, 
       2008, 1848, 3751, 2020, 1860, 3760, 2032, 1873, 3891, 2277, 2278, 2040,
        1882}], 
      Line3DBox[{1711, 1891, 3767, 1712, 1903, 3776, 1736, 3683, 1915, 1749, 
       3688, 1926, 1761, 3695, 1937, 1773, 3704, 1949, 1786, 3714, 1961, 1799,
        3726, 1973, 3807, 1811, 1985, 3818, 1824, 3740, 1997, 1837, 3745, 
       2009, 1849, 3752, 2021, 1861, 3855, 2083, 2033, 1874, 3863, 2141, 2084,
        2129, 2041, 1883}], 
      Line3DBox[{1713, 1892, 3768, 1714, 1904, 3777, 1737, 1916, 3784, 1750, 
       3689, 1927, 1762, 3696, 1938, 1774, 3705, 1950, 1787, 3715, 1962, 1800,
        3727, 1974, 3808, 1812, 1986, 3819, 1825, 1998, 3827, 1838, 3746, 
       2010, 1850, 3753, 2022, 1862, 3856, 2085, 2034, 1875, 2142, 3868, 2086,
        2130, 2042, 1884}], 
      Line3DBox[{1715, 1893, 3769, 1716, 1905, 3778, 1738, 1917, 3785, 1751, 
       1928, 3793, 1763, 3697, 1939, 1775, 3706, 1951, 1788, 3716, 1963, 1801,
        3728, 1975, 3809, 1813, 1987, 3820, 1826, 1999, 3828, 1839, 2011, 
       3836, 1851, 3754, 2023, 1863, 3857, 2087, 2088, 2114, 3858, 2089, 2131,
        2090, 2279, 2198}], 
      Line3DBox[{1717, 1894, 3770, 1718, 1906, 3779, 1739, 1918, 3786, 1752, 
       1929, 3794, 1764, 1940, 3799, 1776, 3707, 1952, 1789, 3717, 1964, 1802,
        3729, 1976, 3810, 1814, 1988, 3821, 1827, 2000, 3829, 1840, 2012, 
       3837, 1852, 2024, 3844, 1864, 3859, 2091, 2092, 2115, 3860, 2093, 2132,
        2094, 2280, 2199}], 
      Line3DBox[{1719, 1895, 3771, 1720, 1907, 3780, 1740, 1919, 3787, 1753, 
       1930, 3795, 1765, 1941, 3800, 1777, 1953, 3803, 1790, 3718, 1965, 1803,
        3730, 1977, 3811, 1815, 1989, 3822, 1828, 2001, 3830, 1841, 2013, 
       3838, 1853, 2025, 3845, 1865, 2095, 3848, 2096, 2116, 3861, 2097, 2133,
        2282, 2281, 2200}], 
      Line3DBox[{1721, 1896, 3772, 1723, 1908, 3781, 1741, 1920, 3788, 1754, 
       1931, 3796, 1766, 1942, 3801, 1778, 1954, 3804, 1791, 1966, 3805, 1804,
        1978, 3812, 3813, 1816, 1990, 3823, 1829, 2002, 3831, 1842, 2014, 
       3839, 1854, 2026, 3846, 1866, 2098, 3849, 2100, 2117, 2101, 3867, 2134,
        2288, 2287, 2201}], 
      Line3DBox[{1725, 1898, 3774, 1726, 1910, 3782, 1743, 3685, 1922, 1756, 
       3691, 1933, 1768, 3699, 1944, 1780, 3709, 1956, 1793, 3720, 1968, 1806,
        3732, 1980, 3815, 1818, 1992, 3824, 1831, 3742, 2004, 1844, 3748, 
       2016, 1856, 3756, 2028, 1868, 3892, 2291, 2036, 1877, 3893, 2283, 2044,
        1886}], 
      Line3DBox[{1727, 1899, 3775, 1728, 1911, 3783, 1744, 1923, 3789, 1757, 
       3692, 1934, 1769, 3700, 1945, 1781, 3710, 1957, 1794, 3721, 1969, 1807,
        3733, 1981, 3816, 1819, 1993, 3825, 1832, 2005, 3832, 1845, 3749, 
       2017, 1857, 3757, 2029, 1869, 3762, 2037, 1878, 3765, 2045, 1887}], 
      Line3DBox[{1881, 2039, 3764, 2105, 1872, 2031, 3759, 1859, 2019, 3750, 
       1847, 2007, 3743, 1835, 1995, 3738, 1822, 1983, 3735, 1809, 1971, 3724,
        3723, 1797, 1959, 3712, 1784, 1947, 3702, 1771, 1935, 3693, 1759, 
       1924, 3686, 1747, 1913, 3681, 1734, 1901, 3678, 1708, 1889, 3677, 2048,
        2109}], 
      Line3DBox[{1885, 2043, 2284, 2286, 2285, 3864, 1876, 2035, 3761, 2099, 
       1867, 2027, 3755, 1855, 2015, 3747, 1843, 2003, 3741, 1830, 1991, 3737,
        1817, 3814, 1979, 3731, 1805, 1967, 3719, 1792, 1955, 3708, 1779, 
       1943, 3698, 1767, 1932, 3690, 1755, 1921, 3684, 1742, 1909, 3680, 1724,
        3773, 1897, 1722}], 
      Line3DBox[{1888, 2211, 2210, 3878, 1879, 2038, 3763, 1870, 2030, 3758, 
       1858, 3840, 2018, 1846, 3833, 2006, 1833, 3826, 1994, 1820, 3817, 1982,
        3734, 1808, 1970, 3722, 1795, 1958, 3711, 1782, 1946, 3701, 2294, 
       3797, 2297, 2293, 3790, 2296, 2310}], 
      Line3DBox[{2108, 2137, 2205, 2138, 2107, 2150, 2209, 3877, 2149, 2104, 
       2135, 2202, 2136, 2102, 2148, 3862, 2208, 2147, 2300, 2302, 2197, 2303,
        2313}], 
      Line3DBox[{2151, 2153, 2154, 2106, 2204, 2203, 3876, 2103, 2275, 2276, 
       2274, 2290, 3890, 2289, 2113, 2206, 2207, 2082, 3854, 2078, 2112, 2076,
        3842, 2111, 2075, 2127, 2139, 2140, 3835, 2110, 2298, 2301, 2312}], 
      Line3DBox[{2152, 2213, 2047, 2212, 2046, 3850, 1880, 2273, 2272, 3889, 
       1871, 2081, 3847, 2080, 2128, 2074, 3841, 2073, 2126, 2070, 3834, 2069,
        1834, 3888, 2269, 2268, 1821, 3886, 2262, 2261, 3898, 2295, 2255, 
       2254, 3897, 2311}]}, {}, {}, {}, {}, {}}},
   VertexNormals->CompressedData["
1:eJzsuWdQ1Evb7osEFUkmUBEDCBINgICIcINkQUQxgGRJIohiQAURkSACkgQk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    "]],
  Axes->True,
  AxesLabel->{
    FormBox[
     TagBox["\[Xi]", HoldForm], TraditionalForm], 
    FormBox[
     TagBox["p", HoldForm], TraditionalForm], 
    FormBox[
     TagBox[
      TemplateBox[{0}, "Spacer1"], HoldForm], TraditionalForm]},
  AxesOrigin->{Automatic, Automatic, Automatic},
  BoxRatios->{1, 1, 0.4},
  DisplayFunction->Identity,
  FaceGrids->None,
  FaceGridsStyle->Automatic,
  Method->{"DefaultBoundaryStyle" -> Directive[
      GrayLevel[0.3]], "RotationControl" -> "Globe"},
  PlotRange->{{0, 1}, {0, 1}, {0., 2.660042687114384}},
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->{Automatic, Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.825966499411265*^9, 3.8259665685532312`*^9},
 CellLabel->
  "Out[459]=",ExpressionUUID->"60ff8f28-b607-477f-81b5-204685fa36e1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{"\"\<Solve for the trace norm with p1 = p to be equal to the \
trace norm with p1 = \!\(\*FractionBox[\(\(-p\) + \[Xi]\), \(\(-1\) + \
\[Xi]\)]\)\>\"", "\[IndentingNewLine]", 
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SqrtBox[
           RowBox[{"1", "-", "p"}]], "+", 
          FractionBox[
           RowBox[{"1", "-", "p"}], "2"]}], ")"}], " ", "\[Xi]"}], "\[Equal]",
        "traceNorm"}], "}"}], ",", "p"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Xi]", ">", "0"}], ",", 
     RowBox[{"\[Xi]", "<", "1"}]}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", "\"\<The first solution is trivial, the \
second is always negative. Interested in the third.\>\"", \
"\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"crossOverValue", "=", 
   RowBox[{
    FractionBox["1", 
     RowBox[{
      SuperscriptBox["\[Xi]", "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", "\[Xi]"}], ")"}], "2"]}]], 
    RowBox[{"(", 
     RowBox[{"8", "-", 
      RowBox[{"8", " ", 
       SqrtBox[
        RowBox[{"1", "-", "\[Xi]"}]]}], "+", 
      RowBox[{"\[Xi]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "4"}], "+", 
         RowBox[{"\[Xi]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "11"}], "+", 
            RowBox[{"8", " ", 
             SqrtBox[
              RowBox[{"1", "-", "\[Xi]"}]]}], "-", 
            RowBox[{"3", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "+", "\[Xi]"}], ")"}], " ", "\[Xi]"}], "+", 
            RowBox[{"8", " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  SqrtBox[
                   RowBox[{"1", "-", "\[Xi]"}]]}], ")"}]}], "+", "\[Xi]", "-", 
               RowBox[{
                SuperscriptBox["\[Xi]", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "3"}], "+", 
                  RowBox[{"2", " ", 
                   SqrtBox[
                    RowBox[{"1", "-", "\[Xi]"}]]}], "+", "\[Xi]"}], 
                 ")"}]}]}]]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", "\"\<Plot the p value for which the second \
known point (p1 = \!\(\*FractionBox[\(\(-p\) + \[Xi]\), \(\(-1\) + \
\[Xi]\)]\)) gives a lower trace norm.\>\"", "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{"crossOverValue", ",", 
   RowBox[{"{", 
    RowBox[{"\[Xi]", ",", "0", ",", "1"}], "}"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<\[Xi]\>\"", ",", "\"\<p\>\""}], "}"}]}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<boundary between regimes\>\""}]}], 
  "]"}], "\[IndentingNewLine]", "\"\<Find the \[Xi] value for which there is \
no p value such that the first known point (p1 = p) gives a lower trace norm.\
\>\"", "\[IndentingNewLine]", 
 RowBox[{"FullSimplify", "[", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{"crossOverValue", "\[Equal]", "0"}], ",", "\[Xi]"}], "]"}], 
  "]"}], "\[IndentingNewLine]", "\"\<Numerical value\>\"", "\
\[IndentingNewLine]", 
 RowBox[{"N", "[", 
  RowBox[{"Root", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "32"}], "+", 
      RowBox[{"184", " ", "#1"}], "-", 
      RowBox[{"215", " ", 
       SuperscriptBox["#1", "2"]}], "+", 
      RowBox[{"18", " ", 
       SuperscriptBox["#1", "3"]}], "+", 
      RowBox[{"81", " ", 
       SuperscriptBox["#1", "4"]}]}], "&"}], ",", "2"}], "]"}], 
  "]"}]}], "Input",
 CellChangeTimes->{
  3.7697882631404953`*^9, 3.769788300823896*^9, {3.7697883459409385`*^9, 
   3.7697883557745905`*^9}, {3.769788410558224*^9, 3.7697884123081646`*^9}, {
   3.769995552619989*^9, 3.7699956319019003`*^9}, 3.8259557096776876`*^9, {
   3.8259560012266836`*^9, 3.8259560831524086`*^9}, {3.8259561385764837`*^9, 
   3.825956181124569*^9}, {3.825956248160988*^9, 3.8259563745804543`*^9}, {
   3.825966372136891*^9, 3.825966396118222*^9}},
 CellLabel->
  "In[460]:=",ExpressionUUID->"b93dbfd4-35c6-4f62-b2e6-f69cb0b73839"],

Cell[BoxData["\<\"Solve for the trace norm with p1 = p to be equal to the \
trace norm with p1 = \\!\\(\\*FractionBox[\\(\\(-p\\) + \[Xi]\\), \\(\\(-1\\) \
+ \[Xi]\\)]\\)\"\>"], "Output",
 CellChangeTimes->{3.825966502086274*^9, 3.825966568652467*^9},
 CellLabel->
  "Out[460]=",ExpressionUUID->"2e927a8f-af78-4fb1-baea-fb90b0ed9bf0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"p", "\[Rule]", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", "\[Rule]", 
     FractionBox[
      RowBox[{"8", "-", 
       RowBox[{"8", " ", 
        SqrtBox[
         RowBox[{"1", "-", "\[Xi]"}]]}], "-", 
       RowBox[{"\[Xi]", " ", 
        RowBox[{"(", 
         RowBox[{"4", "+", 
          RowBox[{"\[Xi]", " ", 
           RowBox[{"(", 
            RowBox[{"11", "-", 
             RowBox[{"8", " ", 
              SqrtBox[
               RowBox[{"1", "-", "\[Xi]"}]]}], "+", 
             RowBox[{"3", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "2"}], "+", "\[Xi]"}], ")"}], " ", "\[Xi]"}], 
             "+", 
             RowBox[{"8", " ", 
              SqrtBox[
               RowBox[{
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   SqrtBox[
                    RowBox[{"1", "-", "\[Xi]"}]]}], ")"}]}], "+", "\[Xi]", 
                "-", 
                RowBox[{
                 SuperscriptBox["\[Xi]", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "3"}], "+", 
                   RowBox[{"2", " ", 
                    SqrtBox[
                    RowBox[{"1", "-", "\[Xi]"}]]}], "+", "\[Xi]"}], 
                  ")"}]}]}]]}]}], ")"}]}]}], ")"}]}]}], 
      RowBox[{
       SuperscriptBox["\[Xi]", "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", "\[Xi]"}], ")"}], "2"]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", "\[Rule]", 
     FractionBox[
      RowBox[{"8", "-", 
       RowBox[{"8", " ", 
        SqrtBox[
         RowBox[{"1", "-", "\[Xi]"}]]}], "+", 
       RowBox[{"\[Xi]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "4"}], "+", 
          RowBox[{"\[Xi]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "11"}], "+", 
             RowBox[{"8", " ", 
              SqrtBox[
               RowBox[{"1", "-", "\[Xi]"}]]}], "-", 
             RowBox[{"3", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "2"}], "+", "\[Xi]"}], ")"}], " ", "\[Xi]"}], 
             "+", 
             RowBox[{"8", " ", 
              SqrtBox[
               RowBox[{
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   SqrtBox[
                    RowBox[{"1", "-", "\[Xi]"}]]}], ")"}]}], "+", "\[Xi]", 
                "-", 
                RowBox[{
                 SuperscriptBox["\[Xi]", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "3"}], "+", 
                   RowBox[{"2", " ", 
                    SqrtBox[
                    RowBox[{"1", "-", "\[Xi]"}]]}], "+", "\[Xi]"}], 
                  ")"}]}]}]]}]}], ")"}]}]}], ")"}]}]}], 
      RowBox[{
       SuperscriptBox["\[Xi]", "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", "\[Xi]"}], ")"}], "2"]}]]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.825966502086274*^9, 3.8259665697734585`*^9},
 CellLabel->
  "Out[461]=",ExpressionUUID->"a9a3bbd2-3dfb-4cb0-991d-a934b7d5877f"],

Cell[BoxData["\<\"The first solution is trivial, the second is always \
negative. Interested in the third.\"\>"], "Output",
 CellChangeTimes->{3.825966502086274*^9, 3.8259665697836075`*^9},
 CellLabel->
  "Out[462]=",ExpressionUUID->"1cc1e0fd-73d2-4bee-a522-cefb455e3173"],

Cell[BoxData["\<\"Plot the p value for which the second known point (p1 = \\!\
\\(\\*FractionBox[\\(\\(-p\\) + \[Xi]\\), \\(\\(-1\\) + \[Xi]\\)]\\)) gives a \
lower trace norm.\"\>"], "Output",
 CellChangeTimes->{3.825966502086274*^9, 3.825966569786599*^9},
 CellLabel->
  "Out[464]=",ExpressionUUID->"d16ac57b-8f0f-4138-b3d9-d0b2836d245e"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwd1nk8Ff0XB3BJ0WZNtjxSkoS0iXg6FRUlpUUIRZSQpE0i8ZAilGwhpLTJ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       "]]},
     Annotation[#, "Charting`Private`Tag$262558#1"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"\[Xi]\"", TraditionalForm], 
    FormBox["\"p\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotLabel->FormBox["\"boundary between regimes\"", TraditionalForm],
  PlotRange->{{0, 1}, {-1.9958840654728787`, 0.9999999999999994}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.825966502086274*^9, 3.8259665698753*^9},
 CellLabel->
  "Out[465]=",ExpressionUUID->"591e6065-25ca-4e0d-89d2-791132fefc00"],

Cell[BoxData["\<\"Find the \[Xi] value for which there is no p value such \
that the first known point (p1 = p) gives a lower trace norm.\"\>"], "Output",
 CellChangeTimes->{3.825966502086274*^9, 3.8259665698842435`*^9},
 CellLabel->
  "Out[466]=",ExpressionUUID->"b1e80881-742c-472e-80d5-97f38d15fce2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"\[Xi]", "\[Rule]", 
    RowBox[{"Root", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"-", "32"}], "+", 
        RowBox[{"184", " ", "#1"}], "-", 
        RowBox[{"215", " ", 
         SuperscriptBox["#1", "2"]}], "+", 
        RowBox[{"18", " ", 
         SuperscriptBox["#1", "3"]}], "+", 
        RowBox[{"81", " ", 
         SuperscriptBox["#1", "4"]}]}], "&"}], ",", "2"}], "]"}]}], "}"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.825966502086274*^9, 3.8259665698882647`*^9},
 CellLabel->
  "Out[467]=",ExpressionUUID->"713504e6-e7d3-4209-8697-cded2442c3bd"],

Cell[BoxData["\<\"Numerical value\"\>"], "Output",
 CellChangeTimes->{3.825966502086274*^9, 3.8259665698912573`*^9},
 CellLabel->
  "Out[468]=",ExpressionUUID->"62dcb3f6-d978-4e7d-a138-3b47a5fc3569"],

Cell[BoxData["0.2367001471704767`"], "Output",
 CellChangeTimes->{3.825966502086274*^9, 3.8259665698942213`*^9},
 CellLabel->
  "Out[469]=",ExpressionUUID->"e1cb8e1e-aade-470f-a708-5a962003581b"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Defined", " ", "as", " ", "per", " ", 
     RowBox[{"Eqs", ".", " ", "85"}]}], ",", " ", "86", ",", " ", 
    RowBox[{"A1", " ", "and", " ", "A2"}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"e1", "=", 
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", "p1"}], ")"}], " ", "\[Xi]"}]}], ";", 
    RowBox[{"e2", "=", 
     RowBox[{
      FractionBox["1", "2"], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"p1", "-", "p"}], ")"}], "+", 
        RowBox[{
         FractionBox["\[Xi]", "2"], 
         RowBox[{"(", 
          RowBox[{"1", "-", "p1"}], ")"}]}]}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"e3", "=", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"e1", "+", "e2"}], ")"}], "+", 
         RowBox[{"Sqrt", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"e1", "-", "e2"}], ")"}], "^", "2"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Sqrt", "[", 
               RowBox[{"1", "-", "p"}], "]"}], "-", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "-", "\[Xi]"}], ")"}], " ", 
               RowBox[{"Sqrt", "[", 
                RowBox[{"1", "-", "p1"}], "]"}]}]}], ")"}], "^", "2"}]}], 
          "]"}]}], ")"}]}], "/", "2"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"e4", "=", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"e1", "+", "e2"}], ")"}], "-", 
         RowBox[{"Sqrt", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"e1", "-", "e2"}], ")"}], "^", "2"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Sqrt", "[", 
               RowBox[{"1", "-", "p"}], "]"}], "-", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "-", "\[Xi]"}], ")"}], " ", 
               RowBox[{"Sqrt", "[", 
                RowBox[{"1", "-", "p1"}], "]"}]}]}], ")"}], "^", "2"}]}], 
          "]"}]}], ")"}]}], "/", "2"}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.7697938638554826`*^9, 3.7697940339727173`*^9}, 
   3.76979408092306*^9, 3.769794152673258*^9, {3.7697942067737513`*^9, 
   3.769794223023431*^9}, {3.769794270907179*^9, 3.769794326774324*^9}, {
   3.7697943626406994`*^9, 3.769794410241284*^9}, {3.7697944403743324`*^9, 
   3.769794497291616*^9}, {3.7697950571767845`*^9, 3.769795143127611*^9}, {
   3.7697960330309987`*^9, 3.7697960435808096`*^9}, {3.769950063269477*^9, 
   3.7699501443388643`*^9}, {3.8259583800106697`*^9, 3.825958398735595*^9}, {
   3.8259663988231416`*^9, 3.8259664007622104`*^9}},
 CellLabel->
  "In[470]:=",ExpressionUUID->"113d2130-d400-4344-a615-eb113838b50f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Gradient", " ", "of"}], " ", "|", "e3", "|", 
    RowBox[{"+", 
     RowBox[{"|", "e4", "|", " ", 
      RowBox[{"from", " ", 
       RowBox[{"Eq", ".", " ", "A7"}]}]}]}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"gradiente3pluse4", "=", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "p"}], "+", "p1", "-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "\[Xi]"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SqrtBox[
            RowBox[{"1", "-", "p"}]], "-", 
           SqrtBox[
            RowBox[{"1", "-", "p1"}]], "+", 
           RowBox[{
            SqrtBox[
             RowBox[{"1", "-", "p1"}]], " ", "\[Xi]"}]}], ")"}]}], 
        SqrtBox[
         RowBox[{"1", "-", "p1"}]]]}], 
      RowBox[{"4", " ", 
       SqrtBox[
        RowBox[{
         RowBox[{
          FractionBox["1", "4"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"p", "-", "p1"}], ")"}], "2"]}], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SqrtBox[
             RowBox[{"1", "-", "p"}]], "+", 
            RowBox[{
             SqrtBox[
              RowBox[{"1", "-", "p1"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "\[Xi]"}], ")"}]}]}], ")"}], 
          "2"]}]]}]]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\"\<Find the minimum value of the gradient of the trace norm immediately \
after the discontinuity.\>\"", "\[IndentingNewLine]", 
   RowBox[{"NMinimize", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"gradiente3pluse4", "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "\[Xi]"}], ")"}], "/", "2"}]}], "/.", 
        RowBox[{"p1", "\[Rule]", 
         FractionBox[
          RowBox[{
           RowBox[{"2", "p"}], "-", "\[Xi]"}], 
          RowBox[{"2", "-", "\[Xi]"}]]}]}], ",", 
       RowBox[{"p", ">", "0"}], ",", 
       RowBox[{"p", "<", "1"}], ",", 
       RowBox[{"\[Xi]", ">", "0"}], ",", 
       RowBox[{"\[Xi]", "<", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"6", "-", 
           RowBox[{"Sqrt", "[", "3", "]"}]}], ")"}], "/", "6"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"p", ",", "\[Xi]"}], "}"}]}], "]"}], "\[IndentingNewLine]", 
   "\"\<It is always positive.\>\"", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   "\"\<Solve for the minima of the expression for the trace norm in the \
region before the discontinuity.\>\"", "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"gradiente3pluse4", "-", 
         RowBox[{"1", "/", "2"}]}], "\[Equal]", "0"}], ",", "p1"}], "]"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Xi]", ">", "0"}], ",", 
       RowBox[{"\[Xi]", "<", "1"}], ",", 
       RowBox[{"p", ">", "0"}], ",", 
       RowBox[{"p", "<", "1"}]}], "}"}]}], "]"}], "\[IndentingNewLine]", 
   "\"\<Note that the first value is not a real minimum of the expression for \
p < 1. The second is a maximum, not a minimum.\>\"", "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"gradiente3pluse4", "-", 
       RowBox[{"1", "/", "2"}]}], "/.", 
      RowBox[{"p1", "\[Rule]", 
       FractionBox[
        RowBox[{"p", "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "2"}], "+", "\[Xi]"}], ")"}], " ", "\[Xi]"}]}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "\[Xi]"}], ")"}], "2"]]}]}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Xi]", ">", "0"}], ",", 
       RowBox[{"\[Xi]", "<", "1"}], ",", 
       RowBox[{"p", ">", "0"}]}], "}"}]}], "]"}], "\[IndentingNewLine]", 
   "\"\<Consequently, we are interested in when the third of these values is \
less than \!\(\*FractionBox[\(2  p - \[Xi]\), \(2 - \[Xi]\)]\).\>\"", 
   "\[IndentingNewLine]", 
   "\"\<If it is, the minimum lies at that value, rather than at the \
discontinuity (\!\(\*FractionBox[\(2  p - \[Xi]\), \(2 - \[Xi]\)]\)).\>\"", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"minValue", "=", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", "p"}], ")"}]}]]}], 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["p", "2"], "-", 
        RowBox[{"4", " ", "\[Xi]"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["p", "2"], " ", "\[Xi]"}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["\[Xi]", "2"]}], "+", 
        RowBox[{"8", " ", "p", " ", 
         SuperscriptBox["\[Xi]", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["p", "2"], " ", 
         SuperscriptBox["\[Xi]", "2"]}], "-", 
        RowBox[{"12", " ", 
         SuperscriptBox["\[Xi]", "3"]}], "-", 
        RowBox[{"8", " ", "p", " ", 
         SuperscriptBox["\[Xi]", "3"]}], "+", 
        RowBox[{"13", " ", 
         SuperscriptBox["\[Xi]", "4"]}], "+", 
        RowBox[{"2", " ", "p", " ", 
         SuperscriptBox["\[Xi]", "4"]}], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["\[Xi]", "5"]}], "+", 
        SuperscriptBox["\[Xi]", "6"], "-", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Xi]"}], ")"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{"p", "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2"}], "+", "\[Xi]"}], ")"}], " ", "\[Xi]"}]}], 
          ")"}], " ", 
         SqrtBox[
          RowBox[{"4", "+", 
           SuperscriptBox["p", "2"], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["\[Xi]", "2"]}], "-", 
           RowBox[{"4", " ", 
            SuperscriptBox["\[Xi]", "3"]}], "+", 
           SuperscriptBox["\[Xi]", "4"], "+", 
           RowBox[{"2", " ", "p", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2"}], "-", 
              RowBox[{"2", " ", "\[Xi]"}], "+", 
              SuperscriptBox["\[Xi]", "2"]}], ")"}]}]}]]}]}], ")"}]}]}], 
    ";"}]}]}]], "Input",
 CellChangeTimes->{{3.7699507544169197`*^9, 3.769950886059273*^9}, {
  3.769950944043232*^9, 3.769950953222982*^9}, {3.769990935467817*^9, 
  3.7699909357939744`*^9}, {3.825959243684909*^9, 3.825959264671531*^9}, {
  3.8259615226563244`*^9, 3.825961620788554*^9}, {3.825961674622526*^9, 
  3.825961708484128*^9}, {3.825961977765008*^9, 3.8259619994591293`*^9}, {
  3.8259620654797697`*^9, 3.8259620658814497`*^9}, {3.8259624708932548`*^9, 
  3.8259625121785917`*^9}, {3.8259628752386265`*^9, 3.8259629307404757`*^9}, {
  3.8259633904553146`*^9, 3.825963426245144*^9}, {3.8259644459072933`*^9, 
  3.8259645086740994`*^9}, {3.8259645401431837`*^9, 3.8259645404814386`*^9}, {
  3.825964586729628*^9, 3.825964627736925*^9}, {3.8259652306153264`*^9, 
  3.825965297685398*^9}, {3.825966402327771*^9, 3.825966444368843*^9}},
 CellLabel->
  "In[473]:=",ExpressionUUID->"fcabaef8-5c0e-496a-a064-b05c97c4827d"],

Cell[BoxData["\<\"Find the minimum value of the gradient of the trace norm \
immediately after the discontinuity.\"\>"], "Output",
 CellChangeTimes->{3.825966503402105*^9, 3.8259665700268297`*^9},
 CellLabel->
  "Out[474]=",ExpressionUUID->"bb260b01-b206-4fa0-8ddf-431a27b3f0c7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.05284180737725312`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"p", "\[Rule]", "0.`"}], ",", 
     RowBox[{"\[Xi]", "\[Rule]", "0.7113248654051871`"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.825966503402105*^9, 3.825966570100603*^9},
 CellLabel->
  "Out[475]=",ExpressionUUID->"4987501b-2db6-44fc-ba00-8cbf75cfd4c2"],

Cell[BoxData["\<\"It is always positive.\"\>"], "Output",
 CellChangeTimes->{3.825966503402105*^9, 3.825966570104591*^9},
 CellLabel->
  "Out[476]=",ExpressionUUID->"e6bab95d-5c1b-4bec-ba98-224f9a6f16a7"],

Cell[BoxData["\<\"Solve for the minima of the expression for the trace norm \
in the region before the discontinuity.\"\>"], "Output",
 CellChangeTimes->{3.825966503402105*^9, 3.825966570109577*^9},
 CellLabel->
  "Out[477]=",ExpressionUUID->"7b201a6e-7ddc-48ee-ace1-a0e7a2652974"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"p1", "\[Rule]", 
     FractionBox[
      RowBox[{"p", "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", "\[Xi]"}], ")"}], " ", "\[Xi]"}]}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Xi]"}], ")"}], "2"]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"p1", "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["p", "2"], "-", 
        RowBox[{"4", " ", "\[Xi]"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["p", "2"], " ", "\[Xi]"}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["\[Xi]", "2"]}], "+", 
        RowBox[{"8", " ", "p", " ", 
         SuperscriptBox["\[Xi]", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["p", "2"], " ", 
         SuperscriptBox["\[Xi]", "2"]}], "-", 
        RowBox[{"12", " ", 
         SuperscriptBox["\[Xi]", "3"]}], "-", 
        RowBox[{"8", " ", "p", " ", 
         SuperscriptBox["\[Xi]", "3"]}], "+", 
        RowBox[{"13", " ", 
         SuperscriptBox["\[Xi]", "4"]}], "+", 
        RowBox[{"2", " ", "p", " ", 
         SuperscriptBox["\[Xi]", "4"]}], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["\[Xi]", "5"]}], "+", 
        SuperscriptBox["\[Xi]", "6"], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Xi]"}], ")"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{"p", "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2"}], "+", "\[Xi]"}], ")"}], " ", "\[Xi]"}]}], 
          ")"}], " ", 
         SqrtBox[
          RowBox[{"4", "+", 
           SuperscriptBox["p", "2"], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["\[Xi]", "2"]}], "-", 
           RowBox[{"4", " ", 
            SuperscriptBox["\[Xi]", "3"]}], "+", 
           SuperscriptBox["\[Xi]", "4"], "+", 
           RowBox[{"2", " ", "p", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2"}], "-", 
              RowBox[{"2", " ", "\[Xi]"}], "+", 
              SuperscriptBox["\[Xi]", "2"]}], ")"}]}]}]]}]}], 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", "p"}], ")"}]}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"p1", "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["p", "2"], "-", 
        RowBox[{"4", " ", "\[Xi]"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["p", "2"], " ", "\[Xi]"}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["\[Xi]", "2"]}], "+", 
        RowBox[{"8", " ", "p", " ", 
         SuperscriptBox["\[Xi]", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["p", "2"], " ", 
         SuperscriptBox["\[Xi]", "2"]}], "-", 
        RowBox[{"12", " ", 
         SuperscriptBox["\[Xi]", "3"]}], "-", 
        RowBox[{"8", " ", "p", " ", 
         SuperscriptBox["\[Xi]", "3"]}], "+", 
        RowBox[{"13", " ", 
         SuperscriptBox["\[Xi]", "4"]}], "+", 
        RowBox[{"2", " ", "p", " ", 
         SuperscriptBox["\[Xi]", "4"]}], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["\[Xi]", "5"]}], "+", 
        SuperscriptBox["\[Xi]", "6"], "-", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Xi]"}], ")"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{"p", "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2"}], "+", "\[Xi]"}], ")"}], " ", "\[Xi]"}]}], 
          ")"}], " ", 
         SqrtBox[
          RowBox[{"4", "+", 
           SuperscriptBox["p", "2"], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["\[Xi]", "2"]}], "-", 
           RowBox[{"4", " ", 
            SuperscriptBox["\[Xi]", "3"]}], "+", 
           SuperscriptBox["\[Xi]", "4"], "+", 
           RowBox[{"2", " ", "p", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2"}], "-", 
              RowBox[{"2", " ", "\[Xi]"}], "+", 
              SuperscriptBox["\[Xi]", "2"]}], ")"}]}]}]]}]}], 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", "p"}], ")"}]}]]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.825966503402105*^9, 3.8259665703160267`*^9},
 CellLabel->
  "Out[478]=",ExpressionUUID->"f98638ac-cd7e-4a5f-82e6-eceaa66b6066"],

Cell[BoxData["\<\"Note that the first value is not a real minimum of the \
expression for p < 1. The second is a maximum, not a minimum.\"\>"], "Output",
 CellChangeTimes->{3.825966503402105*^9, 3.825966570320025*^9},
 CellLabel->
  "Out[479]=",ExpressionUUID->"0fac271b-d1fa-45f5-966b-e6d4e44e92f2"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\[Piecewise]", GridBox[{
       {
        RowBox[{"-", "1"}], 
        RowBox[{"p", "<", "1"}]},
       {"0", 
        TagBox["True",
         "PiecewiseDefault",
         AutoDelete->True]}
      },
      AllowedDimensions->{2, Automatic},
      Editable->True,
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.84]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}},
      Selectable->True]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxItemSize->{
    "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.35]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  "Piecewise",
  DeleteWithContents->True,
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.825966503402105*^9, 3.8259665704359837`*^9},
 CellLabel->
  "Out[480]=",ExpressionUUID->"7217021f-f6be-4eac-95f2-abeef3e58dc1"],

Cell[BoxData["\<\"Consequently, we are interested in when the third of these \
values is less than \\!\\(\\*FractionBox[\\(2  p - \[Xi]\\), \\(2 - \[Xi]\\)]\
\\).\"\>"], "Output",
 CellChangeTimes->{3.825966503402105*^9, 3.825966570441573*^9},
 CellLabel->
  "Out[481]=",ExpressionUUID->"846b3d95-deee-4e20-b58a-0e8f5d419b44"],

Cell[BoxData["\<\"If it is, the minimum lies at that value, rather than at \
the discontinuity (\\!\\(\\*FractionBox[\\(2  p - \[Xi]\\), \\(2 - \
\[Xi]\\)]\\)).\"\>"], "Output",
 CellChangeTimes->{3.825966503402105*^9, 3.8259665704457283`*^9},
 CellLabel->
  "Out[482]=",ExpressionUUID->"f9bfed5d-9aa0-4f54-9c09-a75e05c11eb5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{"\"\<Find the smallest p value for which the minimum does not \
lie at the discontinuity (in terms of \[Xi]).\>\"", "\[IndentingNewLine]", 
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"minValue", "\[Equal]", 
      FractionBox[
       RowBox[{
        RowBox[{"2", "p"}], "-", "\[Xi]"}], 
       RowBox[{"2", "-", "\[Xi]"}]]}], ",", "p", ",", "Reals"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Xi]", ">", "0"}], ",", 
     RowBox[{"\[Xi]", "<", "1"}]}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", "\"\<Plot this p value in terms of \
\[Xi].\>\"", "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   FractionBox[
    RowBox[{"2", "+", 
     SqrtBox[
      RowBox[{"4", "-", 
       RowBox[{"2", " ", "\[Xi]"}]}]], "-", 
     RowBox[{"\[Xi]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "16"}], "+", 
        RowBox[{"3", " ", 
         SqrtBox[
          RowBox[{"4", "-", 
           RowBox[{"2", " ", "\[Xi]"}]}]]}], "+", 
        RowBox[{"\[Xi]", " ", 
         RowBox[{"(", 
          RowBox[{"24", "-", 
           RowBox[{"3", " ", 
            SqrtBox[
             RowBox[{"4", "-", 
              RowBox[{"2", " ", "\[Xi]"}]}]]}], "+", 
           RowBox[{"\[Xi]", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "12"}], "+", 
              SqrtBox[
               RowBox[{"4", "-", 
                RowBox[{"2", " ", "\[Xi]"}]}]], "+", 
              RowBox[{"2", " ", "\[Xi]"}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"5", "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "4"}], "+", "\[Xi]"}], ")"}], " ", "\[Xi]"}]}], 
      ")"}]}]], ",", 
   RowBox[{"{", 
    RowBox[{"\[Xi]", ",", "0", ",", "1"}], "}"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<\[Xi]\>\"", ",", "\"\<p\>\""}], "}"}]}]}], 
  "]"}], "\[IndentingNewLine]", "\"\<This p value decreases as \[Xi] \
decreases. Find its value as \[Xi] goes to 0.\>\"", "\[IndentingNewLine]", 
 RowBox[{
  FractionBox[
   RowBox[{"2", "+", 
    SqrtBox[
     RowBox[{"4", "-", 
      RowBox[{"2", " ", "\[Xi]"}]}]], "-", 
    RowBox[{"\[Xi]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "16"}], "+", 
       RowBox[{"3", " ", 
        SqrtBox[
         RowBox[{"4", "-", 
          RowBox[{"2", " ", "\[Xi]"}]}]]}], "+", 
       RowBox[{"\[Xi]", " ", 
        RowBox[{"(", 
         RowBox[{"24", "-", 
          RowBox[{"3", " ", 
           SqrtBox[
            RowBox[{"4", "-", 
             RowBox[{"2", " ", "\[Xi]"}]}]]}], "+", 
          RowBox[{"\[Xi]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "12"}], "+", 
             SqrtBox[
              RowBox[{"4", "-", 
               RowBox[{"2", " ", "\[Xi]"}]}]], "+", 
             RowBox[{"2", " ", "\[Xi]"}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{"5", "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "4"}], "+", "\[Xi]"}], ")"}], " ", "\[Xi]"}]}], 
     ")"}]}]], "/.", 
  RowBox[{"\[Xi]", "\[Rule]", "0"}]}]}], "Input",
 CellChangeTimes->{{3.7699919285187035`*^9, 3.769992004567892*^9}, {
   3.7699920877564826`*^9, 3.7699920908871074`*^9}, {3.7699921933002872`*^9, 
   3.769992205259323*^9}, {3.825965305206936*^9, 3.825965455532267*^9}, {
   3.825966445798644*^9, 3.8259664676639214`*^9}, 3.8259665544195757`*^9},
 CellLabel->
  "In[484]:=",ExpressionUUID->"1813b31b-3460-47fa-b8cb-cfd278e3dbf9"],

Cell[BoxData["\<\"Find the smallest p value for which the minimum does not \
lie at the discontinuity (in terms of \[Xi]).\"\>"], "Output",
 CellChangeTimes->{3.825966503872039*^9, 3.825966570472579*^9},
 CellLabel->
  "Out[484]=",ExpressionUUID->"4894f94f-d640-4034-b77b-fd1d32e897d4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"p", "\[Rule]", 
    FractionBox[
     RowBox[{"2", "+", 
      SqrtBox[
       RowBox[{"4", "-", 
        RowBox[{"2", " ", "\[Xi]"}]}]], "-", 
      RowBox[{"\[Xi]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "16"}], "+", 
         RowBox[{"3", " ", 
          SqrtBox[
           RowBox[{"4", "-", 
            RowBox[{"2", " ", "\[Xi]"}]}]]}], "+", 
         RowBox[{"\[Xi]", " ", 
          RowBox[{"(", 
           RowBox[{"24", "-", 
            RowBox[{"3", " ", 
             SqrtBox[
              RowBox[{"4", "-", 
               RowBox[{"2", " ", "\[Xi]"}]}]]}], "+", 
            RowBox[{"\[Xi]", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "12"}], "+", 
               SqrtBox[
                RowBox[{"4", "-", 
                 RowBox[{"2", " ", "\[Xi]"}]}]], "+", 
               RowBox[{"2", " ", "\[Xi]"}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"5", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "4"}], "+", "\[Xi]"}], ")"}], " ", "\[Xi]"}]}], 
       ")"}]}]]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.825966503872039*^9, 3.8259665709321976`*^9},
 CellLabel->
  "Out[485]=",ExpressionUUID->"6734dc97-5215-4ca5-acd0-35858c67a0b5"],

Cell[BoxData["\<\"Plot this p value in terms of \[Xi].\"\>"], "Output",
 CellChangeTimes->{3.825966503872039*^9, 3.8259665709361362`*^9},
 CellLabel->
  "Out[486]=",ExpressionUUID->"bee380e7-2685-4598-96ec-af2056aa4d6f"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwV1Hk4VmkfB3BJhSaGUB4t9qK8SaXU1Fcx9mEspcXYIpI2k2nqldLgNcqo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       "]]},
     Annotation[#, "Charting`Private`Tag$263750#1"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"\[Xi]\"", TraditionalForm], 
    FormBox["\"p\"", TraditionalForm]},
  AxesOrigin->{0, 0.40000002591836703`},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 1}, {0.40000002591836703`, 0.9999999999999996}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.825966503872039*^9, 3.8259665710147667`*^9},
 CellLabel->
  "Out[487]=",ExpressionUUID->"8090b0af-ff2b-4168-ae65-453def5dacc6"],

Cell[BoxData["\<\"This p value decreases as \[Xi] decreases. Find its value \
as \[Xi] goes to 0.\"\>"], "Output",
 CellChangeTimes->{3.825966503872039*^9, 3.825966571018408*^9},
 CellLabel->
  "Out[488]=",ExpressionUUID->"24bbbee5-7dfa-4329-9216-174d0da0a2ad"],

Cell[BoxData[
 FractionBox["2", "5"]], "Output",
 CellChangeTimes->{3.825966503872039*^9, 3.8259665710217514`*^9},
 CellLabel->
  "Out[489]=",ExpressionUUID->"224eb209-4ad7-4051-80f8-1489d4830bfd"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{"\"\<Find the smallest p value for which the value of p1 that \
minimises the trace norm does not lie between the two points p1 = \
\!\(\*FractionBox[\(\(-p\) + \[Xi]\), \(\(-1\) + \[Xi]\)]\) and p1 = p (in \
terms of \[Xi]).\>\"", "\[IndentingNewLine]", 
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"minValue", "\[Equal]", 
      FractionBox[
       RowBox[{
        RowBox[{"2", "p"}], "-", "\[Xi]"}], 
       RowBox[{"2", "-", "\[Xi]"}]]}], ",", "p", ",", "Reals"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Xi]", ">", "0"}], ",", 
     RowBox[{"\[Xi]", "<", "1"}]}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", "\"\<Plot this p value in terms of \
\[Xi].\>\"", "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   FractionBox[
    RowBox[{"1", "+", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "-", "\[Xi]"}], ")"}], 
      RowBox[{"7", "/", "2"}]], "+", 
     RowBox[{"4", " ", "\[Xi]"}], "-", 
     RowBox[{"8", " ", 
      SuperscriptBox["\[Xi]", "2"]}], "+", 
     RowBox[{"5", " ", 
      SuperscriptBox["\[Xi]", "3"]}], "-", 
     SuperscriptBox["\[Xi]", "4"]}], 
    RowBox[{"3", "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3"}], "+", "\[Xi]"}], ")"}], " ", "\[Xi]"}]}]], ",", 
   RowBox[{"{", 
    RowBox[{"\[Xi]", ",", "0", ",", "1"}], "}"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<\[Xi]\>\"", ",", "\"\<p\>\""}], "}"}]}]}], 
  "]"}], "\[IndentingNewLine]", "\"\<This p value decreases as \[Xi] \
decreases. Find its value as \[Xi] goes to 0.\>\"", "\[IndentingNewLine]", 
 RowBox[{
  FractionBox[
   RowBox[{"1", "+", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", "\[Xi]"}], ")"}], 
     RowBox[{"7", "/", "2"}]], "+", 
    RowBox[{"4", " ", "\[Xi]"}], "-", 
    RowBox[{"8", " ", 
     SuperscriptBox["\[Xi]", "2"]}], "+", 
    RowBox[{"5", " ", 
     SuperscriptBox["\[Xi]", "3"]}], "-", 
    SuperscriptBox["\[Xi]", "4"]}], 
   RowBox[{"3", "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "3"}], "+", "\[Xi]"}], ")"}], " ", "\[Xi]"}]}]], "/.", 
  RowBox[{"\[Xi]", "\[Rule]", "0"}]}]}], "Input",
 CellChangeTimes->{{3.770001231023349*^9, 3.7700012359579983`*^9}, {
   3.770001361341113*^9, 3.7700014122922297`*^9}, 3.8259656176378794`*^9, {
   3.8259657455949287`*^9, 3.8259657597107377`*^9}, {3.8259658325445757`*^9, 
   3.8259659523840723`*^9}, {3.8259660125797043`*^9, 3.825966015989787*^9}, {
   3.8259660760532656`*^9, 3.825966079385706*^9}, {3.8259664687719154`*^9, 
   3.82596649057057*^9}, 3.8259665611595545`*^9},
 CellLabel->
  "In[490]:=",ExpressionUUID->"27a84c1a-29ba-4c7a-bb81-0f72a8122a0a"],

Cell[BoxData["\<\"Find the smallest p value for which the value of p1 that \
minimises the trace norm does not lie between the two points p1 = \
\\!\\(\\*FractionBox[\\(\\(-p\\) + \[Xi]\\), \\(\\(-1\\) + \[Xi]\\)]\\) and \
p1 = p (in terms of \[Xi]).\"\>"], "Output",
 CellChangeTimes->{3.825966504477441*^9, 3.825966571113431*^9},
 CellLabel->
  "Out[490]=",ExpressionUUID->"f3b25650-cdce-492c-a785-c9929bc6a4da"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"p", "\[Rule]", 
    FractionBox[
     RowBox[{"2", "+", 
      SqrtBox[
       RowBox[{"4", "-", 
        RowBox[{"2", " ", "\[Xi]"}]}]], "-", 
      RowBox[{"\[Xi]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "16"}], "+", 
         RowBox[{"3", " ", 
          SqrtBox[
           RowBox[{"4", "-", 
            RowBox[{"2", " ", "\[Xi]"}]}]]}], "+", 
         RowBox[{"\[Xi]", " ", 
          RowBox[{"(", 
           RowBox[{"24", "-", 
            RowBox[{"3", " ", 
             SqrtBox[
              RowBox[{"4", "-", 
               RowBox[{"2", " ", "\[Xi]"}]}]]}], "+", 
            RowBox[{"\[Xi]", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "12"}], "+", 
               SqrtBox[
                RowBox[{"4", "-", 
                 RowBox[{"2", " ", "\[Xi]"}]}]], "+", 
               RowBox[{"2", " ", "\[Xi]"}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"5", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "4"}], "+", "\[Xi]"}], ")"}], " ", "\[Xi]"}]}], 
       ")"}]}]]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.825966504477441*^9, 3.8259665715716896`*^9},
 CellLabel->
  "Out[491]=",ExpressionUUID->"d218cfec-fdcc-46b8-9151-67de0099d7e5"],

Cell[BoxData["\<\"Plot this p value in terms of \[Xi].\"\>"], "Output",
 CellChangeTimes->{3.825966504477441*^9, 3.8259665715771656`*^9},
 CellLabel->
  "Out[492]=",ExpressionUUID->"6f0151c3-6921-4684-913a-6590c261ad52"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwd1gk0F3sbB3BZIkK2bFFoQYooKq7nFslSRISuLS9y3ZJdyv4ioZTcklRa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       "]]},
     Annotation[#, "Charting`Private`Tag$264901#1"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"\[Xi]\"", TraditionalForm], 
    FormBox["\"p\"", TraditionalForm]},
  AxesOrigin->{0, 0.666666683673469},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 1}, {0.666666683673469, 1.0000000000000007`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.825966504477441*^9, 3.8259665716484137`*^9},
 CellLabel->
  "Out[493]=",ExpressionUUID->"1d339cc9-5dfb-4418-89b2-8b373829dd13"],

Cell[BoxData["\<\"This p value decreases as \[Xi] decreases. Find its value \
as \[Xi] goes to 0.\"\>"], "Output",
 CellChangeTimes->{3.825966504477441*^9, 3.825966571654395*^9},
 CellLabel->
  "Out[494]=",ExpressionUUID->"bde700f4-b5aa-4319-9c4f-502eae9e2162"],

Cell[BoxData[
 FractionBox["2", "3"]], "Output",
 CellChangeTimes->{3.825966504477441*^9, 3.825966571656397*^9},
 CellLabel->
  "Out[495]=",ExpressionUUID->"7b2f3a7b-2b4d-41b1-bf3b-5ab089a213dd"]
}, Open  ]]
},
WindowSize->{1920, 997},
WindowMargins->{{-8, Automatic}, {Automatic, -8}},
Magnification:>1.1 Inherited,
FrontEndVersion->"11.3 for Microsoft Windows (64-bit) (March 6, 2018)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 8595, 238, 651, "Input",ExpressionUUID->"9f571f6c-caa4-4184-8d04-47059d57c182"],
Cell[9178, 262, 328, 5, 36, "Output",ExpressionUUID->"bcd1ef54-3416-42d6-a592-4d8f63eebc66"],
Cell[9509, 269, 251, 6, 36, "Output",ExpressionUUID->"1d28e567-032d-472e-9b4b-af15fa691c05"],
Cell[9763, 277, 380, 11, 56, "Output",ExpressionUUID->"1e7c2325-aef2-4a57-8e8b-e0777d5f3d58"],
Cell[10146, 290, 281, 4, 56, "Output",ExpressionUUID->"ac5eea89-94f5-4323-a11a-c77cf0c3c981"],
Cell[10430, 296, 1303, 45, 85, "Output",ExpressionUUID->"dfb31ee2-aab9-46d7-97ef-b3855689dab7"],
Cell[11736, 343, 274, 4, 36, "Output",ExpressionUUID->"6392d7b2-920d-4fc7-8c35-f672a758baaf"],
Cell[12013, 349, 215206, 3524, 338, "Output",ExpressionUUID->"60ff8f28-b607-477f-81b5-204685fa36e1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[227256, 3878, 4282, 113, 368, "Input",ExpressionUUID->"b93dbfd4-35c6-4f62-b2e6-f69cb0b73839"],
Cell[231541, 3993, 334, 5, 56, "Output",ExpressionUUID->"2e927a8f-af78-4fb1-baea-fb90b0ed9bf0"],
Cell[231878, 4000, 3375, 100, 95, "Output",ExpressionUUID->"a9a3bbd2-3dfb-4cb0-991d-a934b7d5877f"],
Cell[235256, 4102, 272, 4, 36, "Output",ExpressionUUID->"1cc1e0fd-73d2-4bee-a522-cefb455e3173"],
Cell[235531, 4108, 340, 5, 56, "Output",ExpressionUUID->"d16ac57b-8f0f-4138-b3d9-d0b2836d245e"],
Cell[235874, 4115, 6869, 131, 282, "Output",ExpressionUUID->"591e6065-25ca-4e0d-89d2-791132fefc00"],
Cell[242746, 4248, 303, 4, 36, "Output",ExpressionUUID->"b1e80881-742c-472e-80d5-97f38d15fce2"],
Cell[243052, 4254, 642, 19, 42, "Output",ExpressionUUID->"713504e6-e7d3-4209-8697-cded2442c3bd"],
Cell[243697, 4275, 199, 3, 36, "Output",ExpressionUUID->"62dcb3f6-d978-4e7d-a138-3b47a5fc3569"],
Cell[243899, 4280, 195, 3, 36, "Output",ExpressionUUID->"e1cb8e1e-aade-470f-a708-5a962003581b"]
}, Open  ]],
Cell[244109, 4286, 3008, 83, 130, "Input",ExpressionUUID->"113d2130-d400-4344-a615-eb113838b50f"],
Cell[CellGroupData[{
Cell[247142, 4373, 7317, 196, 577, "Input",ExpressionUUID->"fcabaef8-5c0e-496a-a064-b05c97c4827d"],
Cell[254462, 4571, 279, 4, 36, "Output",ExpressionUUID->"bb260b01-b206-4fa0-8ddf-431a27b3f0c7"],
Cell[254744, 4577, 379, 10, 36, "Output",ExpressionUUID->"4987501b-2db6-44fc-ba00-8cbf75cfd4c2"],
Cell[255126, 4589, 204, 3, 36, "Output",ExpressionUUID->"e6bab95d-5c1b-4bec-ba98-224f9a6f16a7"],
Cell[255333, 4594, 281, 4, 36, "Output",ExpressionUUID->"7b201a6e-7ddc-48ee-ace1-a0e7a2652974"],
Cell[255617, 4600, 4524, 129, 176, "Output",ExpressionUUID->"f98638ac-cd7e-4a5f-82e6-eceaa66b6066"],
Cell[260144, 4731, 300, 4, 36, "Output",ExpressionUUID->"0fac271b-d1fa-45f5-966b-e6d4e44e92f2"],
Cell[260447, 4737, 1665, 48, 54, "Output",ExpressionUUID->"7217021f-f6be-4eac-95f2-abeef3e58dc1"],
Cell[262115, 4787, 326, 5, 56, "Output",ExpressionUUID->"846b3d95-deee-4e20-b58a-0e8f5d419b44"],
Cell[262444, 4794, 326, 5, 56, "Output",ExpressionUUID->"f9bfed5d-9aa0-4f54-9c09-a75e05c11eb5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[262807, 4804, 3622, 105, 268, "Input",ExpressionUUID->"1813b31b-3460-47fa-b8cb-cfd278e3dbf9"],
Cell[266432, 4911, 286, 4, 36, "Output",ExpressionUUID->"4894f94f-d640-4034-b77b-fd1d32e897d4"],
Cell[266721, 4917, 1376, 42, 67, "Output",ExpressionUUID->"6734dc97-5215-4ca5-acd0-35858c67a0b5"],
Cell[268100, 4961, 220, 3, 36, "Output",ExpressionUUID->"bee380e7-2685-4598-96ec-af2056aa4d6f"],
Cell[268323, 4966, 4796, 97, 275, "Output",ExpressionUUID->"8090b0af-ff2b-4168-ae65-453def5dacc6"],
Cell[273122, 5065, 261, 4, 36, "Output",ExpressionUUID->"24bbbee5-7dfa-4329-9216-174d0da0a2ad"],
Cell[273386, 5071, 197, 4, 53, "Output",ExpressionUUID->"224eb209-4ad7-4051-80f8-1489d4830bfd"]
}, Open  ]],
Cell[CellGroupData[{
Cell[273620, 5080, 2742, 71, 269, "Input",ExpressionUUID->"27a84c1a-29ba-4c7a-bb81-0f72a8122a0a"],
Cell[276365, 5153, 414, 6, 56, "Output",ExpressionUUID->"f3b25650-cdce-492c-a785-c9929bc6a4da"],
Cell[276782, 5161, 1376, 42, 67, "Output",ExpressionUUID->"d218cfec-fdcc-46b8-9151-67de0099d7e5"],
Cell[278161, 5205, 220, 3, 36, "Output",ExpressionUUID->"6f0151c3-6921-4684-913a-6590c261ad52"],
Cell[278384, 5210, 5975, 117, 271, "Output",ExpressionUUID->"1d339cc9-5dfb-4418-89b2-8b373829dd13"],
Cell[284362, 5329, 261, 4, 36, "Output",ExpressionUUID->"bde700f4-b5aa-4319-9c4f-502eae9e2162"],
Cell[284626, 5335, 195, 4, 53, "Output",ExpressionUUID->"7b2f3a7b-2b4d-41b1-bf3b-5ab089a213dd"]
}, Open  ]]
}
]
*)

