(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    182043,       4549]
NotebookOptionsPosition[    180987,       4526]
NotebookOutlinePosition[    181360,       4542]
CellTagsIndexPosition[    181317,       4539]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "PBTChoiMatrix", " ", "gives", " ", "the", " ", "Choi", " ", "matrix", 
     " ", "for", " ", "a", " ", "given", " ", "resource", " ", "state"}], ",",
     " ", 
    RowBox[{
    "assuming", " ", "that", " ", "the", " ", "probability", " ", "of", " ", 
     "teleportation", " ", "to", " ", "each", " ", "B", " ", "mode", " ", 
     "is", " ", 
     RowBox[{"identical", ".", " ", "Otherwise"}]}], ",", " ", 
    RowBox[{
    "it", " ", "gives", " ", "the", " ", "Choi", " ", "matrix", " ", 
     "assuming", " ", "teleportation", " ", "to", " ", "the", " ", "first", 
     " ", "B", " ", 
     RowBox[{"mode", ".", " ", "FA"}]}], ",", " ", 
    RowBox[{
    "FB", " ", "and", " ", "FC", " ", "specify", " ", "the", " ", "resource", 
     " ", 
     RowBox[{"state", ".", " ", "They"}], " ", "are", " ", "the", " ", 
     "three", " ", "independent", " ", "quarters", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", "quarters"}], ",", " ", 
       RowBox[{
       "but", " ", "one", " ", "is", " ", "the", " ", "conjugate", " ", 
        "transpose", " ", "of", " ", "another"}]}], ")"}], " ", "of", " ", 
     "the", " ", "density", " ", "matrix", " ", "of", " ", "the", " ", 
     "resource", " ", "state"}], ",", " ", 
    RowBox[{
    "with", " ", "all", " ", "but", " ", "one", " ", "B", " ", "mode", " ", 
     "traced", " ", "over", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"i", ".", "e", ".", " ", "the"}], " ", "resource", " ", 
       "state", " ", "after", " ", "the", " ", "partial", " ", "trace", " ", 
       "has", " ", "been", " ", "taken", " ", "over", " ", "all", " ", "B", 
       " ", "modes", " ", "except", " ", "the", " ", "port", " ", "that", " ",
        "the", " ", "input", " ", "state", " ", "is", " ", "sent", " ", 
       RowBox[{"to", "."}]}], ")"}]}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"PBTChoiMatrix", "[", 
     RowBox[{"FA_", ",", "FB_", ",", "FC_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "n", ",", "lim1", ",", "FCa", ",", "FCb", ",", "FA11", ",", "FA12", 
        ",", "FA21", ",", "FA22", ",", "FB11", ",", "FB12", ",", "FB21", ",", 
        "FB22", ",", "FCa11", ",", "FCa12", ",", "FCa21", ",", "FCa22", ",", 
        "FCb11", ",", "FCb12", ",", "FCb21", ",", "FCb22", ",", "Get1", ",", 
        "Get2", ",", "G", ",", "inds1", ",", "inds2", ",", "jmin", ",", 
        "smin", ",", "mmax", ",", "c11", ",", "c12", ",", "c13", ",", "c14", 
        ",", "c21", ",", "c22", ",", "c23", ",", "c24", ",", "c31", ",", 
        "c32", ",", "c33", ",", "c34", ",", "c41", ",", "c42", ",", "c43", 
        ",", "c44", ",", "cont1", ",", "cont2", ",", "cont3", ",", "cont4", 
        ",", "cont5", ",", "cont6", ",", "cont7", ",", "cont8", ",", "cont9", 
        ",", "cont10", ",", "s", ",", "m", ",", "deg"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
       "Get1", " ", "and", " ", "Get2", " ", "are", " ", "utility", " ", 
        "functions", " ", "that", " ", "get", " ", "the", " ", "position", 
        " ", "of", " ", "an", " ", "element", " ", "if", " ", "it", " ", 
        "exists", " ", "and", " ", "return", " ", "0", " ", "if", " ", "it", 
        " ", "does", " ", 
        RowBox[{"not", ".", " ", "Get1"}], " ", "looks", " ", "in", " ", 
        "the", " ", "list", " ", "of", " ", "type", " ", "1", " ", "vectors", 
        " ", "and", " ", "Get2", " ", "looks", " ", "in", " ", "the", " ", 
        "list", " ", "of", " ", "type", " ", "2", " ", 
        RowBox[{"vectors", ".", " ", "G"}], " ", "calculates", " ", "the", 
        " ", "degeneracy", " ", "of", " ", "a", " ", "j", " ", 
        RowBox[{"value", "."}]}], "*)"}], "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"Get1", "[", "ref_", "]"}], ":=", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Position", "[", 
            RowBox[{"inds1", ",", "ref"}], "]"}], "\[NotEqual]", 
           RowBox[{"{", "}"}]}], ",", 
          RowBox[{
           RowBox[{"Position", "[", 
            RowBox[{"inds1", ",", "ref"}], "]"}], "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", "0"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Get2", "[", "ref_", "]"}], ":=", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Position", "[", 
            RowBox[{"inds2", ",", "ref"}], "]"}], "\[NotEqual]", 
           RowBox[{"{", "}"}]}], ",", 
          RowBox[{
           RowBox[{"Position", "[", 
            RowBox[{"inds2", ",", "ref"}], "]"}], "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", "0"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"G", "[", 
         RowBox[{"n_", ",", "j_"}], "]"}], ":=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", "j"}], "+", "1"}], ")"}], 
         RowBox[{
          RowBox[{"n", "!"}], "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"n", "/", "2"}], "-", "j"}], ")"}], "!"}], 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"n", "/", "2"}], "+", "1", "+", "j"}], ")"}], "!"}]}], 
           ")"}]}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"n", "=", 
        RowBox[{"Log2", "[", 
         RowBox[{
          RowBox[{"Dimensions", "[", "FA", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"lim1", "=", 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", "j"}], "+", "1"}], ")"}], "*", 
           RowBox[{"G", "[", 
            RowBox[{
             RowBox[{"n", "-", "1"}], ",", 
             RowBox[{"j", "+", 
              RowBox[{"1", "/", "2"}]}]}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"EvenQ", "[", "n", "]"}], ",", "0", ",", 
              RowBox[{"1", "/", "2"}]}], "]"}], ",", 
            RowBox[{
             RowBox[{"n", "/", "2"}], "-", "1"}]}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"FCa", "=", "FC"}], ";", 
       RowBox[{"FCb", "=", 
        RowBox[{"ConjugateTranspose", "[", "FC", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
        "Partition", " ", "the", " ", "resource", " ", "state", " ", "into", 
         " ", "the", " ", "parts", " ", "given", " ", "by", " ", "type", " ", 
         "1", " ", "eigenvectors", " ", "and", " ", "those", " ", "given", 
         " ", "by", " ", "type", " ", "2", " ", "eigenvectors", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
           "according", " ", "to", " ", "the", " ", "way", " ", "the", " ", 
            "resource", " ", "state", " ", "is", " ", "constructed"}], ")"}], 
          "."}]}], "*)"}], "\[IndentingNewLine]", 
       RowBox[{"FA11", "=", 
        RowBox[{"Take", "[", 
         RowBox[{"FA", ",", "lim1", ",", "lim1"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"FA12", "=", 
        RowBox[{"Take", "[", 
         RowBox[{
          RowBox[{"Drop", "[", 
           RowBox[{"FA", ",", "0", ",", "lim1"}], "]"}], ",", "lim1"}], 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"FA21", "=", 
        RowBox[{"ConjugateTranspose", "[", "FA12", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"FA22", "=", 
        RowBox[{"Drop", "[", 
         RowBox[{
          RowBox[{"Drop", "[", 
           RowBox[{"FA", ",", "0", ",", "lim1"}], "]"}], ",", "lim1"}], 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"FB11", "=", 
        RowBox[{"Take", "[", 
         RowBox[{"FB", ",", "lim1", ",", "lim1"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"FB12", "=", 
        RowBox[{"Take", "[", 
         RowBox[{
          RowBox[{"Drop", "[", 
           RowBox[{"FB", ",", "0", ",", "lim1"}], "]"}], ",", "lim1"}], 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"FB21", "=", 
        RowBox[{"ConjugateTranspose", "[", "FB12", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"FB22", "=", 
        RowBox[{"Drop", "[", 
         RowBox[{
          RowBox[{"Drop", "[", 
           RowBox[{"FB", ",", "0", ",", "lim1"}], "]"}], ",", "lim1"}], 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"FCa11", "=", 
        RowBox[{"Take", "[", 
         RowBox[{"FCa", ",", "lim1", ",", "lim1"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"FCa12", "=", 
        RowBox[{"Take", "[", 
         RowBox[{
          RowBox[{"Drop", "[", 
           RowBox[{"FCa", ",", "0", ",", "lim1"}], "]"}], ",", "lim1"}], 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"FCa21", "=", 
        RowBox[{"Take", "[", 
         RowBox[{
          RowBox[{"Drop", "[", 
           RowBox[{"FCa", ",", "lim1", ",", "0"}], "]"}], ",", "All", ",", 
          "lim1"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"FCa22", "=", 
        RowBox[{"Drop", "[", 
         RowBox[{
          RowBox[{"Drop", "[", 
           RowBox[{"FCa", ",", "0", ",", "lim1"}], "]"}], ",", "lim1"}], 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"FCb11", "=", 
        RowBox[{"Take", "[", 
         RowBox[{"FCb", ",", "lim1", ",", "lim1"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"FCb12", "=", 
        RowBox[{"Take", "[", 
         RowBox[{
          RowBox[{"Drop", "[", 
           RowBox[{"FCb", ",", "0", ",", "lim1"}], "]"}], ",", "lim1"}], 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"FCb21", "=", 
        RowBox[{"Take", "[", 
         RowBox[{
          RowBox[{"Drop", "[", 
           RowBox[{"FCb", ",", "lim1", ",", "0"}], "]"}], ",", "All", ",", 
          "lim1"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"FCb22", "=", 
        RowBox[{"Drop", "[", 
         RowBox[{
          RowBox[{"Drop", "[", 
           RowBox[{"FCb", ",", "0", ",", "lim1"}], "]"}], ",", "lim1"}], 
         "]"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{
         "Find", " ", "all", " ", "the", " ", "valid", " ", "sets", " ", "of",
           " ", "j"}], ",", " ", 
         RowBox[{
         "m", " ", "and", " ", "alpha", " ", "values", " ", "for", " ", 
          "types", " ", "1", " ", "and", " ", "2."}]}], "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"inds1", "=", 
        RowBox[{"{", "}"}]}], ";", 
       RowBox[{"inds2", "=", 
        RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"EvenQ", "[", "n", "]"}], ",", 
         RowBox[{
          RowBox[{"jmin", "=", "0"}], ";", 
          RowBox[{"smin", "=", 
           RowBox[{"1", "/", "2"}]}]}], ",", 
         RowBox[{
          RowBox[{"jmin", "=", 
           RowBox[{"1", "/", "2"}]}], ";", 
          RowBox[{"smin", "=", "0"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"Do", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"mmax", "=", "j"}], ";", 
          RowBox[{"deg", "=", 
           RowBox[{"G", "[", 
            RowBox[{
             RowBox[{"n", "-", "1"}], ",", 
             RowBox[{"j", "+", 
              RowBox[{"1", "/", "2"}]}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"Do", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"AppendTo", "[", 
              RowBox[{"inds1", ",", 
               RowBox[{"{", 
                RowBox[{"j", ",", "m", ",", "alpha"}], "}"}]}], "]"}], ";"}], 
            "\[IndentingNewLine]", ",", 
            RowBox[{"{", 
             RowBox[{"m", ",", 
              RowBox[{"-", "mmax"}], ",", "mmax"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"alpha", ",", "1", ",", "deg"}], "}"}]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"mmax", "=", "j"}], ";", 
          RowBox[{"deg", "=", 
           RowBox[{"G", "[", 
            RowBox[{
             RowBox[{"n", "-", "1"}], ",", 
             RowBox[{"j", "-", 
              RowBox[{"1", "/", "2"}]}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"Do", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"AppendTo", "[", 
              RowBox[{"inds2", ",", 
               RowBox[{"{", 
                RowBox[{"j", ",", "m", ",", "alpha"}], "}"}]}], "]"}], ";"}], 
            "\[IndentingNewLine]", ",", 
            RowBox[{"{", 
             RowBox[{"m", ",", 
              RowBox[{"-", "mmax"}], ",", "mmax"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"alpha", ",", "1", ",", "deg"}], "}"}]}], "]"}]}], 
         "\[IndentingNewLine]", ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "jmin", ",", 
           RowBox[{"n", "/", "2"}]}], "}"}]}], "]"}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"c11", "=", "0"}], ";", 
       RowBox[{"c12", "=", "0"}], ";", 
       RowBox[{"c22", "=", "0"}], ";", 
       RowBox[{"c13", "=", "0"}], ";", 
       RowBox[{"c14", "=", "0"}], ";", 
       RowBox[{"c23", "=", "0"}], ";", 
       RowBox[{"c24", "=", "0"}], ";", 
       RowBox[{"c33", "=", "0"}], ";", 
       RowBox[{"c34", "=", "0"}], ";", 
       RowBox[{"c44", "=", "0"}], ";", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
        "Calculate", " ", "the", " ", "contributions", " ", "from", " ", 
         "each", " ", "of", " ", "the", " ", "vectors", " ", "in", " ", 
         RowBox[{"M1", "."}]}], "*)"}], "\[IndentingNewLine]", 
       RowBox[{"Do", "[", 
        RowBox[{
         RowBox[{"Do", "[", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"n", "+", "1"}], ")"}], "/", "2"}], "-", "s"}], 
                ")"}], "\[NotEqual]", "0"}], ",", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"cont1", "=", 
                RowBox[{"Simplify", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"n", "+", "1"}], ")"}], "/", "2"}], "-", "s"}], 
                    ")"}], "^", 
                   RowBox[{"(", 
                    RowBox[{"-", "1"}], ")"}]}], 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"s", "-", "m"}], ")"}], "/", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", "s"}], "+", "1"}], ")"}]}]}], "]"}]}], ";", 
               "\[IndentingNewLine]", 
               RowBox[{"cont2", "=", 
                RowBox[{"Simplify", "[", 
                 RowBox[{
                  RowBox[{"-", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"n", "+", "1"}], ")"}], "/", "2"}], "-", "s"}], 
                    ")"}], 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"n", "+", "3"}], ")"}], "/", "2"}], "+", "s"}], 
                    ")"}]}], ")"}], "^", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], 
                  RowBox[{
                   RowBox[{"Sqrt", "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"s", "-", "m"}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"s", "+", "1", "+", "m"}], ")"}]}], "]"}], "/", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", "s"}], "+", "1"}], ")"}]}]}], "]"}]}], ";", 
               "\[IndentingNewLine]", 
               RowBox[{"cont4", "=", 
                RowBox[{"Simplify", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"n", "+", "1"}], ")"}], "/", "2"}], "-", "s"}], 
                    ")"}], "^", 
                   RowBox[{"(", 
                    RowBox[{"-", "1"}], ")"}]}], 
                  RowBox[{
                   RowBox[{"Sqrt", "[", 
                    RowBox[{
                    RowBox[{"s", "^", "2"}], "-", 
                    RowBox[{"m", "^", "2"}]}], "]"}], "/", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", "s"}], "+", "1"}], ")"}]}]}], "]"}]}], ";", 
               "\[IndentingNewLine]", 
               RowBox[{"cont5", "=", 
                RowBox[{"Simplify", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"n", "+", "1"}], ")"}], "/", "2"}], "-", "s"}], 
                    ")"}], 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"n", "+", "3"}], ")"}], "/", "2"}], "+", "s"}], 
                    ")"}]}], ")"}], "^", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "/", "2"}], ")"}]}], 
                  RowBox[{
                   RowBox[{"Sqrt", "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"s", "-", "m"}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"s", "+", "1", "-", "m"}], ")"}]}], "]"}], "/", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", "s"}], "+", "1"}], ")"}]}]}], "]"}]}], ";", 
               "\[IndentingNewLine]", 
               RowBox[{"cont6", "=", 
                RowBox[{"Simplify", "[", 
                 RowBox[{
                  RowBox[{"-", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"n", "+", "1"}], ")"}], "/", "2"}], "-", "s"}], 
                    ")"}], 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"n", "+", "3"}], ")"}], "/", "2"}], "+", "s"}], 
                    ")"}]}], ")"}], "^", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], 
                  RowBox[{
                   RowBox[{"Sqrt", "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"s", "+", "m"}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"s", "+", "1", "+", "m"}], ")"}]}], "]"}], "/", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", "s"}], "+", "1"}], ")"}]}]}], "]"}]}], ";", 
               "\[IndentingNewLine]", 
               RowBox[{"cont8", "=", 
                RowBox[{"Simplify", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"n", "+", "1"}], ")"}], "/", "2"}], "-", "s"}], 
                    ")"}], "^", 
                   RowBox[{"(", 
                    RowBox[{"-", "1"}], ")"}]}], 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"s", "+", "m"}], ")"}], "/", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", "s"}], "+", "1"}], ")"}]}]}], "]"}]}], ";", 
               "\[IndentingNewLine]", 
               RowBox[{"cont9", "=", 
                RowBox[{"Simplify", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"n", "+", "1"}], ")"}], "/", "2"}], "-", "s"}], 
                    ")"}], 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"n", "+", "3"}], ")"}], "/", "2"}], "+", "s"}], 
                    ")"}]}], ")"}], "^", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "/", "2"}], ")"}]}], 
                  RowBox[{
                   RowBox[{"Sqrt", "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"s", "+", "m"}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"s", "+", "1", "-", "m"}], ")"}]}], "]"}], "/", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", "s"}], "+", "1"}], ")"}]}]}], "]"}]}], ";"}],
               ",", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"cont1", "=", "0"}], ";", 
               RowBox[{"cont2", "=", "0"}], ";", 
               RowBox[{"cont4", "=", "0"}], ";", 
               RowBox[{"cont5", "=", "0"}], ";", 
               RowBox[{"cont6", "=", "0"}], ";", 
               RowBox[{"cont8", "=", "0"}], ";", 
               RowBox[{"cont9", "=", "0"}], ";"}]}], "\[IndentingNewLine]", 
             "]"}], ";", "\[IndentingNewLine]", 
            RowBox[{"cont3", "=", 
             RowBox[{"Simplify", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"n", "+", "3"}], ")"}], "/", "2"}], "+", "s"}], 
                 ")"}], "^", 
                RowBox[{"(", 
                 RowBox[{"-", "1"}], ")"}]}], 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"s", "+", "1", "+", "m"}], ")"}], "/", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", "s"}], "+", "1"}], ")"}]}]}], "]"}]}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"cont7", "=", 
             RowBox[{"Simplify", "[", 
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"n", "+", "3"}], ")"}], "/", "2"}], "+", "s"}], 
                  ")"}], "^", 
                 RowBox[{"(", 
                  RowBox[{"-", "1"}], ")"}]}]}], 
               RowBox[{
                RowBox[{"Sqrt", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"s", "+", "1"}], ")"}], "^", "2"}], "-", 
                  RowBox[{"m", "^", "2"}]}], "]"}], "/", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", "s"}], "+", "1"}], ")"}]}]}], "]"}]}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"cont10", "=", 
             RowBox[{"Simplify", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"n", "+", "3"}], ")"}], "/", "2"}], "+", "s"}], 
                 ")"}], "^", 
                RowBox[{"(", 
                 RowBox[{"-", "1"}], ")"}]}], 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"s", "+", "1", "-", "m"}], ")"}], "/", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", "s"}], "+", "1"}], ")"}]}]}], "]"}]}], ";", 
            "\[IndentingNewLine]", "\[IndentingNewLine]", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"Get1", "[", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"s", "-", 
                   RowBox[{"1", "/", "2"}]}], ",", 
                  RowBox[{"m", "+", 
                   RowBox[{"1", "/", "2"}]}], ",", "x_"}], "}"}], "]"}], 
               "\[NotEqual]", "0"}], ",", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"c11", "=", 
                RowBox[{"c11", "+", 
                 RowBox[{"cont1", "*", 
                  RowBox[{"Sum", "[", 
                   RowBox[{
                    RowBox[{"FA11", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"Get1", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}], 
                    ",", 
                    RowBox[{"Get1", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}]}],
                     "]"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"alpha", ",", 
                    RowBox[{"G", "[", 
                    RowBox[{
                    RowBox[{"n", "-", "1"}], ",", "s"}], "]"}]}], "}"}]}], 
                   "]"}]}]}]}], ";", "\[IndentingNewLine]", 
               RowBox[{"c22", "=", 
                RowBox[{"c22", "+", 
                 RowBox[{"cont1", "*", 
                  RowBox[{"Sum", "[", 
                   RowBox[{
                    RowBox[{"FB11", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"Get1", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}], 
                    ",", 
                    RowBox[{"Get1", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}]}],
                     "]"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"alpha", ",", 
                    RowBox[{"G", "[", 
                    RowBox[{
                    RowBox[{"n", "-", "1"}], ",", "s"}], "]"}]}], "}"}]}], 
                   "]"}]}]}]}], ";", "\[IndentingNewLine]", 
               RowBox[{"c12", "=", 
                RowBox[{"c12", "+", 
                 RowBox[{"cont1", "*", 
                  RowBox[{"Sum", "[", 
                   RowBox[{
                    RowBox[{"FCa11", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"Get1", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}], 
                    ",", 
                    RowBox[{"Get1", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}]}],
                     "]"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"alpha", ",", 
                    RowBox[{"G", "[", 
                    RowBox[{
                    RowBox[{"n", "-", "1"}], ",", "s"}], "]"}]}], "}"}]}], 
                   "]"}]}]}]}], ";"}]}], "]"}], ";", "\[IndentingNewLine]", 
            RowBox[{"(*", 
             RowBox[{
              RowBox[{
              "For", " ", "the", " ", "quandrants", " ", "that", " ", "lie", 
               " ", "on", " ", "the", " ", "main", " ", "diagonal"}], ",", 
              " ", 
              RowBox[{
               RowBox[{"I", " ", "can", " ", "write", " ", "2", 
                RowBox[{"Re", "[", "FA12", "]"}], " ", "instead", " ", "of", 
                " ", "FA12"}], "+", 
               RowBox[{
                RowBox[{"FA21", ".", " ", "Not"}], " ", "true", " ", "for", 
                " ", "the", " ", "third", " ", "quadrant"}]}], ",", " ", 
              RowBox[{
              "since", " ", "FCa12", " ", "is", " ", "not", " ", "the", " ", 
               "conjugate", " ", "transpose", " ", "of", " ", 
               RowBox[{"FCa21", "."}]}]}], "*)"}], "\[IndentingNewLine]", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"Get1", "[", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"s", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                   RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", "x_"}], "}"}], "]"}], 
                "\[NotEqual]", "0"}], "&&", 
               RowBox[{
                RowBox[{"Get2", "[", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"s", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                   RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", "x_"}], "}"}], "]"}], 
                "\[NotEqual]", "0"}]}], ",", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"c11", "=", 
                RowBox[{"c11", "+", 
                 RowBox[{"cont2", "*", "2", 
                  RowBox[{"Re", "[", 
                   RowBox[{"Sum", "[", 
                    RowBox[{
                    RowBox[{"FA12", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"Get1", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}], 
                    ",", 
                    RowBox[{"Get2", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}]}],
                     "]"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"alpha", ",", 
                    RowBox[{"G", "[", 
                    RowBox[{
                    RowBox[{"n", "-", "1"}], ",", "s"}], "]"}]}], "}"}]}], 
                    "]"}], "]"}]}]}]}], ";", "\[IndentingNewLine]", 
               RowBox[{"c22", "=", 
                RowBox[{"c22", "+", 
                 RowBox[{"cont2", "*", "2", 
                  RowBox[{"Re", "[", 
                   RowBox[{"Sum", "[", 
                    RowBox[{
                    RowBox[{"FB12", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"Get1", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}], 
                    ",", 
                    RowBox[{"Get2", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}]}],
                     "]"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"alpha", ",", 
                    RowBox[{"G", "[", 
                    RowBox[{
                    RowBox[{"n", "-", "1"}], ",", "s"}], "]"}]}], "}"}]}], 
                    "]"}], "]"}]}]}]}], ";", "\[IndentingNewLine]", 
               RowBox[{"c12", "=", 
                RowBox[{"c12", "+", 
                 RowBox[{"cont2", "*", 
                  RowBox[{"Sum", "[", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"FCa12", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"Get1", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}], 
                    ",", 
                    RowBox[{"Get2", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}]}],
                     "]"}], "]"}], "+", 
                    RowBox[{"FCa21", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"Get2", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}], 
                    ",", 
                    RowBox[{"Get1", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}]}],
                     "]"}], "]"}]}], ",", 
                    RowBox[{"{", 
                    RowBox[{"alpha", ",", 
                    RowBox[{"G", "[", 
                    RowBox[{
                    RowBox[{"n", "-", "1"}], ",", "s"}], "]"}]}], "}"}]}], 
                   "]"}]}]}]}], ";"}]}], "]"}], ";", "\[IndentingNewLine]", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"Get2", "[", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"s", "+", 
                   RowBox[{"1", "/", "2"}]}], ",", 
                  RowBox[{"m", "+", 
                   RowBox[{"1", "/", "2"}]}], ",", "x_"}], "}"}], "]"}], 
               "\[NotEqual]", "0"}], ",", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"c11", "=", 
                RowBox[{"c11", "+", 
                 RowBox[{"cont3", "*", 
                  RowBox[{"Sum", "[", 
                   RowBox[{
                    RowBox[{"FA22", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"Get2", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}], 
                    ",", 
                    RowBox[{"Get2", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}]}],
                     "]"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"alpha", ",", 
                    RowBox[{"G", "[", 
                    RowBox[{
                    RowBox[{"n", "-", "1"}], ",", "s"}], "]"}]}], "}"}]}], 
                   "]"}]}]}]}], ";", "\[IndentingNewLine]", 
               RowBox[{"c22", "=", 
                RowBox[{"c22", "+", 
                 RowBox[{"cont3", "*", 
                  RowBox[{"Sum", "[", 
                   RowBox[{
                    RowBox[{"FB22", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"Get2", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}], 
                    ",", 
                    RowBox[{"Get2", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}]}],
                     "]"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"alpha", ",", 
                    RowBox[{"G", "[", 
                    RowBox[{
                    RowBox[{"n", "-", "1"}], ",", "s"}], "]"}]}], "}"}]}], 
                   "]"}]}]}]}], ";", "\[IndentingNewLine]", 
               RowBox[{"c12", "=", 
                RowBox[{"c12", "+", 
                 RowBox[{"cont3", "*", 
                  RowBox[{"Sum", "[", 
                   RowBox[{
                    RowBox[{"FCa22", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"Get2", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}], 
                    ",", 
                    RowBox[{"Get2", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}]}],
                     "]"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"alpha", ",", 
                    RowBox[{"G", "[", 
                    RowBox[{
                    RowBox[{"n", "-", "1"}], ",", "s"}], "]"}]}], "}"}]}], 
                   "]"}]}]}]}], ";"}]}], "]"}], ";", "\[IndentingNewLine]", 
            "\[IndentingNewLine]", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"Get1", "[", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"s", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                   RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", "x_"}], "}"}], "]"}], 
                "\[NotEqual]", "0"}], "&&", 
               RowBox[{
                RowBox[{"Get1", "[", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"s", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                   RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", "x_"}], "}"}], "]"}], 
                "\[NotEqual]", "0"}]}], ",", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"c13", "=", 
                RowBox[{"c13", "+", 
                 RowBox[{"cont4", "*", 
                  RowBox[{"Sum", "[", 
                   RowBox[{
                    RowBox[{"FA11", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"Get1", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}], 
                    ",", 
                    RowBox[{"Get1", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}]}],
                     "]"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"alpha", ",", 
                    RowBox[{"G", "[", 
                    RowBox[{
                    RowBox[{"n", "-", "1"}], ",", "s"}], "]"}]}], "}"}]}], 
                   "]"}]}]}]}], ";", "\[IndentingNewLine]", 
               RowBox[{"c24", "=", 
                RowBox[{"c24", "+", 
                 RowBox[{"cont4", "*", 
                  RowBox[{"Sum", "[", 
                   RowBox[{
                    RowBox[{"FB11", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"Get1", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}], 
                    ",", 
                    RowBox[{"Get1", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}]}],
                     "]"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"alpha", ",", 
                    RowBox[{"G", "[", 
                    RowBox[{
                    RowBox[{"n", "-", "1"}], ",", "s"}], "]"}]}], "}"}]}], 
                   "]"}]}]}]}], ";", "\[IndentingNewLine]", 
               RowBox[{"c14", "=", 
                RowBox[{"c14", "+", 
                 RowBox[{"cont4", "*", 
                  RowBox[{"Sum", "[", 
                   RowBox[{
                    RowBox[{"FCa11", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"Get1", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}], 
                    ",", 
                    RowBox[{"Get1", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}]}],
                     "]"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"alpha", ",", 
                    RowBox[{"G", "[", 
                    RowBox[{
                    RowBox[{"n", "-", "1"}], ",", "s"}], "]"}]}], "}"}]}], 
                   "]"}]}]}]}], ";", "\[IndentingNewLine]", 
               RowBox[{"c23", "=", 
                RowBox[{"c23", "+", 
                 RowBox[{"cont4", "*", 
                  RowBox[{"Sum", "[", 
                   RowBox[{
                    RowBox[{"FCb11", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"Get1", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}], 
                    ",", 
                    RowBox[{"Get1", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}]}],
                     "]"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"alpha", ",", 
                    RowBox[{"G", "[", 
                    RowBox[{
                    RowBox[{"n", "-", "1"}], ",", "s"}], "]"}]}], "}"}]}], 
                   "]"}]}]}]}], ";"}]}], "]"}], ";", "\[IndentingNewLine]", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"Get1", "[", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"s", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                   RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", "x_"}], "}"}], "]"}], 
                "\[NotEqual]", "0"}], "&&", 
               RowBox[{
                RowBox[{"Get2", "[", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"s", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                   RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", "x_"}], "}"}], "]"}], 
                "\[NotEqual]", "0"}]}], ",", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"c13", "=", 
                RowBox[{"c13", "+", 
                 RowBox[{"cont5", "*", 
                  RowBox[{"Sum", "[", 
                   RowBox[{
                    RowBox[{"FA12", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"Get1", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}], 
                    ",", 
                    RowBox[{"Get2", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}]}],
                     "]"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"alpha", ",", 
                    RowBox[{"G", "[", 
                    RowBox[{
                    RowBox[{"n", "-", "1"}], ",", "s"}], "]"}]}], "}"}]}], 
                   "]"}]}]}]}], ";", "\[IndentingNewLine]", 
               RowBox[{"c24", "=", 
                RowBox[{"c24", "+", 
                 RowBox[{"cont5", "*", 
                  RowBox[{"Sum", "[", 
                   RowBox[{
                    RowBox[{"FB12", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"Get1", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}], 
                    ",", 
                    RowBox[{"Get2", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}]}],
                     "]"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"alpha", ",", 
                    RowBox[{"G", "[", 
                    RowBox[{
                    RowBox[{"n", "-", "1"}], ",", "s"}], "]"}]}], "}"}]}], 
                   "]"}]}]}]}], ";", "\[IndentingNewLine]", 
               RowBox[{"c14", "=", 
                RowBox[{"c14", "+", 
                 RowBox[{"cont5", "*", 
                  RowBox[{"Sum", "[", 
                   RowBox[{
                    RowBox[{"FCa12", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"Get1", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}], 
                    ",", 
                    RowBox[{"Get2", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}]}],
                     "]"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"alpha", ",", 
                    RowBox[{"G", "[", 
                    RowBox[{
                    RowBox[{"n", "-", "1"}], ",", "s"}], "]"}]}], "}"}]}], 
                   "]"}]}]}]}], ";", "\[IndentingNewLine]", 
               RowBox[{"c23", "=", 
                RowBox[{"c23", "+", 
                 RowBox[{"cont5", "*", 
                  RowBox[{"Sum", "[", 
                   RowBox[{
                    RowBox[{"FCb12", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"Get1", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}], 
                    ",", 
                    RowBox[{"Get2", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}]}],
                     "]"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"alpha", ",", 
                    RowBox[{"G", "[", 
                    RowBox[{
                    RowBox[{"n", "-", "1"}], ",", "s"}], "]"}]}], "}"}]}], 
                   "]"}]}]}]}], ";"}]}], "]"}], ";", "\[IndentingNewLine]", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"Get2", "[", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"s", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                   RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", "x_"}], "}"}], "]"}], 
                "\[NotEqual]", "0"}], "&&", 
               RowBox[{
                RowBox[{"Get1", "[", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"s", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                   RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", "x_"}], "}"}], "]"}], 
                "\[NotEqual]", "0"}]}], ",", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"c13", "=", 
                RowBox[{"c13", "+", 
                 RowBox[{"cont6", "*", 
                  RowBox[{"Sum", "[", 
                   RowBox[{
                    RowBox[{"FA21", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"Get2", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}], 
                    ",", 
                    RowBox[{"Get1", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}]}],
                     "]"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"alpha", ",", 
                    RowBox[{"G", "[", 
                    RowBox[{
                    RowBox[{"n", "-", "1"}], ",", "s"}], "]"}]}], "}"}]}], 
                   "]"}]}]}]}], ";", "\[IndentingNewLine]", 
               RowBox[{"c24", "=", 
                RowBox[{"c24", "+", 
                 RowBox[{"cont6", "*", 
                  RowBox[{"Sum", "[", 
                   RowBox[{
                    RowBox[{"FB21", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"Get2", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}], 
                    ",", 
                    RowBox[{"Get1", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}]}],
                     "]"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"alpha", ",", 
                    RowBox[{"G", "[", 
                    RowBox[{
                    RowBox[{"n", "-", "1"}], ",", "s"}], "]"}]}], "}"}]}], 
                   "]"}]}]}]}], ";", "\[IndentingNewLine]", 
               RowBox[{"c14", "=", 
                RowBox[{"c14", "+", 
                 RowBox[{"cont6", "*", 
                  RowBox[{"Sum", "[", 
                   RowBox[{
                    RowBox[{"FCa21", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"Get2", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}], 
                    ",", 
                    RowBox[{"Get1", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}]}],
                     "]"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"alpha", ",", 
                    RowBox[{"G", "[", 
                    RowBox[{
                    RowBox[{"n", "-", "1"}], ",", "s"}], "]"}]}], "}"}]}], 
                   "]"}]}]}]}], ";", "\[IndentingNewLine]", 
               RowBox[{"c23", "=", 
                RowBox[{"c23", "+", 
                 RowBox[{"cont6", "*", 
                  RowBox[{"Sum", "[", 
                   RowBox[{
                    RowBox[{"FCb21", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"Get2", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}], 
                    ",", 
                    RowBox[{"Get1", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}]}],
                     "]"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"alpha", ",", 
                    RowBox[{"G", "[", 
                    RowBox[{
                    RowBox[{"n", "-", "1"}], ",", "s"}], "]"}]}], "}"}]}], 
                   "]"}]}]}]}], ";"}]}], "]"}], ";", "\[IndentingNewLine]", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"Get2", "[", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"s", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                   RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", "x_"}], "}"}], "]"}], 
                "\[NotEqual]", "0"}], "&&", 
               RowBox[{
                RowBox[{"Get2", "[", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"s", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                   RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", "x_"}], "}"}], "]"}], 
                "\[NotEqual]", "0"}]}], ",", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"c13", "=", 
                RowBox[{"c13", "+", 
                 RowBox[{"cont7", "*", 
                  RowBox[{"Sum", "[", 
                   RowBox[{
                    RowBox[{"FA22", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"Get2", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}], 
                    ",", 
                    RowBox[{"Get2", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}]}],
                     "]"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"alpha", ",", 
                    RowBox[{"G", "[", 
                    RowBox[{
                    RowBox[{"n", "-", "1"}], ",", "s"}], "]"}]}], "}"}]}], 
                   "]"}]}]}]}], ";", "\[IndentingNewLine]", 
               RowBox[{"c24", "=", 
                RowBox[{"c24", "+", 
                 RowBox[{"cont7", "*", 
                  RowBox[{"Sum", "[", 
                   RowBox[{
                    RowBox[{"FB22", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"Get2", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}], 
                    ",", 
                    RowBox[{"Get2", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}]}],
                     "]"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"alpha", ",", 
                    RowBox[{"G", "[", 
                    RowBox[{
                    RowBox[{"n", "-", "1"}], ",", "s"}], "]"}]}], "}"}]}], 
                   "]"}]}]}]}], ";", "\[IndentingNewLine]", 
               RowBox[{"c14", "=", 
                RowBox[{"c14", "+", 
                 RowBox[{"cont7", "*", 
                  RowBox[{"Sum", "[", 
                   RowBox[{
                    RowBox[{"FCa22", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"Get2", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}], 
                    ",", 
                    RowBox[{"Get2", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}]}],
                     "]"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"alpha", ",", 
                    RowBox[{"G", "[", 
                    RowBox[{
                    RowBox[{"n", "-", "1"}], ",", "s"}], "]"}]}], "}"}]}], 
                   "]"}]}]}]}], ";", "\[IndentingNewLine]", 
               RowBox[{"c23", "=", 
                RowBox[{"c23", "+", 
                 RowBox[{"cont7", "*", 
                  RowBox[{"Sum", "[", 
                   RowBox[{
                    RowBox[{"FCb22", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"Get2", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}], 
                    ",", 
                    RowBox[{"Get2", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}]}],
                     "]"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"alpha", ",", 
                    RowBox[{"G", "[", 
                    RowBox[{
                    RowBox[{"n", "-", "1"}], ",", "s"}], "]"}]}], "}"}]}], 
                   "]"}]}]}]}], ";"}]}], "]"}], ";", "\[IndentingNewLine]", 
            "\[IndentingNewLine]", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"Get1", "[", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"s", "-", 
                   RowBox[{"1", "/", "2"}]}], ",", 
                  RowBox[{"m", "-", 
                   RowBox[{"1", "/", "2"}]}], ",", "x_"}], "}"}], "]"}], 
               "\[NotEqual]", "0"}], ",", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"c33", "=", 
                RowBox[{"c33", "+", 
                 RowBox[{"cont8", "*", 
                  RowBox[{"Sum", "[", 
                   RowBox[{
                    RowBox[{"FA11", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"Get1", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}], 
                    ",", 
                    RowBox[{"Get1", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}]}],
                     "]"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"alpha", ",", 
                    RowBox[{"G", "[", 
                    RowBox[{
                    RowBox[{"n", "-", "1"}], ",", "s"}], "]"}]}], "}"}]}], 
                   "]"}]}]}]}], ";", "\[IndentingNewLine]", 
               RowBox[{"c44", "=", 
                RowBox[{"c44", "+", 
                 RowBox[{"cont8", "*", 
                  RowBox[{"Sum", "[", 
                   RowBox[{
                    RowBox[{"FB11", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"Get1", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}], 
                    ",", 
                    RowBox[{"Get1", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}]}],
                     "]"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"alpha", ",", 
                    RowBox[{"G", "[", 
                    RowBox[{
                    RowBox[{"n", "-", "1"}], ",", "s"}], "]"}]}], "}"}]}], 
                   "]"}]}]}]}], ";", "\[IndentingNewLine]", 
               RowBox[{"c34", "=", 
                RowBox[{"c34", "+", 
                 RowBox[{"cont8", "*", 
                  RowBox[{"Sum", "[", 
                   RowBox[{
                    RowBox[{"FCa11", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"Get1", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}], 
                    ",", 
                    RowBox[{"Get1", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}]}],
                     "]"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"alpha", ",", 
                    RowBox[{"G", "[", 
                    RowBox[{
                    RowBox[{"n", "-", "1"}], ",", "s"}], "]"}]}], "}"}]}], 
                   "]"}]}]}]}], ";"}]}], "]"}], ";", "\[IndentingNewLine]", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"Get1", "[", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"s", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                   RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", "x_"}], "}"}], "]"}], 
                "\[NotEqual]", "0"}], "&&", 
               RowBox[{
                RowBox[{"Get2", "[", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"s", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                   RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", "x_"}], "}"}], "]"}], 
                "\[NotEqual]", "0"}]}], ",", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"c33", "=", 
                RowBox[{"c33", "+", 
                 RowBox[{"cont9", "*", "2", 
                  RowBox[{"Re", "[", 
                   RowBox[{"Sum", "[", 
                    RowBox[{
                    RowBox[{"FA12", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"Get1", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}], 
                    ",", 
                    RowBox[{"Get2", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}]}],
                     "]"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"alpha", ",", 
                    RowBox[{"G", "[", 
                    RowBox[{
                    RowBox[{"n", "-", "1"}], ",", "s"}], "]"}]}], "}"}]}], 
                    "]"}], "]"}]}]}]}], ";", "\[IndentingNewLine]", 
               RowBox[{"c44", "=", 
                RowBox[{"c44", "+", 
                 RowBox[{"cont9", "*", "2", 
                  RowBox[{"Re", "[", 
                   RowBox[{"Sum", "[", 
                    RowBox[{
                    RowBox[{"FB12", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"Get1", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}], 
                    ",", 
                    RowBox[{"Get2", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}]}],
                     "]"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"alpha", ",", 
                    RowBox[{"G", "[", 
                    RowBox[{
                    RowBox[{"n", "-", "1"}], ",", "s"}], "]"}]}], "}"}]}], 
                    "]"}], "]"}]}]}]}], ";", "\[IndentingNewLine]", 
               RowBox[{"c34", "=", 
                RowBox[{"c34", "+", 
                 RowBox[{"cont9", "*", 
                  RowBox[{"Sum", "[", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"FCa12", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"Get1", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}], 
                    ",", 
                    RowBox[{"Get2", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}]}],
                     "]"}], "]"}], "+", 
                    RowBox[{"FCa21", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"Get2", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}], 
                    ",", 
                    RowBox[{"Get1", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}]}],
                     "]"}], "]"}]}], ",", 
                    RowBox[{"{", 
                    RowBox[{"alpha", ",", 
                    RowBox[{"G", "[", 
                    RowBox[{
                    RowBox[{"n", "-", "1"}], ",", "s"}], "]"}]}], "}"}]}], 
                   "]"}]}]}]}], ";"}]}], "]"}], ";", "\[IndentingNewLine]", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"Get2", "[", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"s", "+", 
                   RowBox[{"1", "/", "2"}]}], ",", 
                  RowBox[{"m", "-", 
                   RowBox[{"1", "/", "2"}]}], ",", "x_"}], "}"}], "]"}], 
               "\[NotEqual]", "0"}], ",", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"c33", "=", 
                RowBox[{"c33", "+", 
                 RowBox[{"cont10", "*", 
                  RowBox[{"Sum", "[", 
                   RowBox[{
                    RowBox[{"FA22", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"Get2", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}], 
                    ",", 
                    RowBox[{"Get2", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}]}],
                     "]"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"alpha", ",", 
                    RowBox[{"G", "[", 
                    RowBox[{
                    RowBox[{"n", "-", "1"}], ",", "s"}], "]"}]}], "}"}]}], 
                   "]"}]}]}]}], ";", "\[IndentingNewLine]", 
               RowBox[{"c44", "=", 
                RowBox[{"c44", "+", 
                 RowBox[{"cont10", "*", 
                  RowBox[{"Sum", "[", 
                   RowBox[{
                    RowBox[{"FB22", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"Get2", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}], 
                    ",", 
                    RowBox[{"Get2", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}]}],
                     "]"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"alpha", ",", 
                    RowBox[{"G", "[", 
                    RowBox[{
                    RowBox[{"n", "-", "1"}], ",", "s"}], "]"}]}], "}"}]}], 
                   "]"}]}]}]}], ";", "\[IndentingNewLine]", 
               RowBox[{"c34", "=", 
                RowBox[{"c34", "+", 
                 RowBox[{"cont10", "*", 
                  RowBox[{"Sum", "[", 
                   RowBox[{
                    RowBox[{"FCa22", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"Get2", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}], 
                    ",", 
                    RowBox[{"Get2", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"s", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}], "]"}]}],
                     "]"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"alpha", ",", 
                    RowBox[{"G", "[", 
                    RowBox[{
                    RowBox[{"n", "-", "1"}], ",", "s"}], "]"}]}], "}"}]}], 
                   "]"}]}]}]}], ";"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
           ",", 
           RowBox[{"{", 
            RowBox[{"m", ",", 
             RowBox[{"-", "s"}], ",", "s"}], "}"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"s", ",", "smin", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"n", "-", "1"}], ")"}], "/", "2"}]}], "}"}]}], "]"}], 
       ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
        "Calculate", " ", "the", " ", "contributions", " ", "from", " ", 
         "each", " ", "of", " ", "the", " ", "vectors", " ", "in", " ", 
         RowBox[{"M2", "."}]}], "*)"}], "\[IndentingNewLine]", 
       RowBox[{"Do", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Get2", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"n", "/", "2"}], ",", 
                RowBox[{"m", "+", 
                 RowBox[{"1", "/", "2"}]}], ",", "x_"}], "}"}], "]"}], 
             "\[NotEqual]", "0"}], ",", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"c11", "=", 
              RowBox[{"c11", "+", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"1", "/", "2"}], "-", 
                   RowBox[{"m", "/", 
                    RowBox[{"(", 
                    RowBox[{"n", "+", "1"}], ")"}]}]}], ")"}], "/", "n"}], 
                "*", 
                RowBox[{"FA22", "[", 
                 RowBox[{"[", 
                  RowBox[{
                   RowBox[{"Get2", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"n", "/", "2"}], ",", 
                    RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", "x_"}], "}"}], "]"}], ",", 
                   RowBox[{"Get2", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"n", "/", "2"}], ",", 
                    RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", "x_"}], "}"}], "]"}]}], 
                  "]"}], "]"}]}]}]}], ";", "\[IndentingNewLine]", 
             RowBox[{"c22", "=", 
              RowBox[{"c22", "+", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"1", "/", "2"}], "-", 
                   RowBox[{"m", "/", 
                    RowBox[{"(", 
                    RowBox[{"n", "+", "1"}], ")"}]}]}], ")"}], "/", "n"}], 
                "*", 
                RowBox[{"FB22", "[", 
                 RowBox[{"[", 
                  RowBox[{
                   RowBox[{"Get2", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"n", "/", "2"}], ",", 
                    RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", "x_"}], "}"}], "]"}], ",", 
                   RowBox[{"Get2", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"n", "/", "2"}], ",", 
                    RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", "x_"}], "}"}], "]"}]}], 
                  "]"}], "]"}]}]}]}], ";", "\[IndentingNewLine]", 
             RowBox[{"c12", "=", 
              RowBox[{"c12", "+", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"1", "/", "2"}], "-", 
                   RowBox[{"m", "/", 
                    RowBox[{"(", 
                    RowBox[{"n", "+", "1"}], ")"}]}]}], ")"}], "/", "n"}], 
                "*", 
                RowBox[{"FCa22", "[", 
                 RowBox[{"[", 
                  RowBox[{
                   RowBox[{"Get2", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"n", "/", "2"}], ",", 
                    RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", "x_"}], "}"}], "]"}], ",", 
                   RowBox[{"Get2", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"n", "/", "2"}], ",", 
                    RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", "x_"}], "}"}], "]"}]}], 
                  "]"}], "]"}]}]}]}], ";"}]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"Get2", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"n", "/", "2"}], ",", 
                 RowBox[{"m", "+", 
                  RowBox[{"1", "/", "2"}]}], ",", "x_"}], "}"}], "]"}], 
              "\[NotEqual]", "0"}], "&&", 
             RowBox[{
              RowBox[{"Get2", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"n", "/", "2"}], ",", 
                 RowBox[{"m", "-", 
                  RowBox[{"1", "/", "2"}]}], ",", "x_"}], "}"}], "]"}], 
              "\[NotEqual]", "0"}]}], ",", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"c13", "=", 
              RowBox[{"c13", "+", 
               RowBox[{
                RowBox[{
                 RowBox[{"Sqrt", "[", 
                  RowBox[{
                   RowBox[{"1", "/", "4"}], "-", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"m", "/", 
                    RowBox[{"(", 
                    RowBox[{"n", "+", "1"}], ")"}]}], ")"}], "^", "2"}]}], 
                  "]"}], "/", "n"}], "*", 
                RowBox[{"FA22", "[", 
                 RowBox[{"[", 
                  RowBox[{
                   RowBox[{"Get2", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"n", "/", "2"}], ",", 
                    RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", "x_"}], "}"}], "]"}], ",", 
                   RowBox[{"Get2", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"n", "/", "2"}], ",", 
                    RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", "x_"}], "}"}], "]"}]}], 
                  "]"}], "]"}]}]}]}], ";", "\[IndentingNewLine]", 
             RowBox[{"c24", "=", 
              RowBox[{"c24", "+", 
               RowBox[{
                RowBox[{
                 RowBox[{"Sqrt", "[", 
                  RowBox[{
                   RowBox[{"1", "/", "4"}], "-", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"m", "/", 
                    RowBox[{"(", 
                    RowBox[{"n", "+", "1"}], ")"}]}], ")"}], "^", "2"}]}], 
                  "]"}], "/", "n"}], "*", 
                RowBox[{"FB22", "[", 
                 RowBox[{"[", 
                  RowBox[{
                   RowBox[{"Get2", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"n", "/", "2"}], ",", 
                    RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", "x_"}], "}"}], "]"}], ",", 
                   RowBox[{"Get2", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"n", "/", "2"}], ",", 
                    RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", "x_"}], "}"}], "]"}]}], 
                  "]"}], "]"}]}]}]}], ";", "\[IndentingNewLine]", 
             RowBox[{"c14", "=", 
              RowBox[{"c14", "+", 
               RowBox[{
                RowBox[{
                 RowBox[{"Sqrt", "[", 
                  RowBox[{
                   RowBox[{"1", "/", "4"}], "-", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"m", "/", 
                    RowBox[{"(", 
                    RowBox[{"n", "+", "1"}], ")"}]}], ")"}], "^", "2"}]}], 
                  "]"}], "/", "n"}], "*", 
                RowBox[{"FCa22", "[", 
                 RowBox[{"[", 
                  RowBox[{
                   RowBox[{"Get2", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"n", "/", "2"}], ",", 
                    RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", "x_"}], "}"}], "]"}], ",", 
                   RowBox[{"Get2", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"n", "/", "2"}], ",", 
                    RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", "x_"}], "}"}], "]"}]}], 
                  "]"}], "]"}]}]}]}], ";", "\[IndentingNewLine]", 
             RowBox[{"c23", "=", 
              RowBox[{"c23", "+", 
               RowBox[{
                RowBox[{
                 RowBox[{"Sqrt", "[", 
                  RowBox[{
                   RowBox[{"1", "/", "4"}], "-", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"m", "/", 
                    RowBox[{"(", 
                    RowBox[{"n", "+", "1"}], ")"}]}], ")"}], "^", "2"}]}], 
                  "]"}], "/", "n"}], "*", 
                RowBox[{"FCb22", "[", 
                 RowBox[{"[", 
                  RowBox[{
                   RowBox[{"Get2", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"n", "/", "2"}], ",", 
                    RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", "x_"}], "}"}], "]"}], ",", 
                   RowBox[{"Get2", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"n", "/", "2"}], ",", 
                    RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", "x_"}], "}"}], "]"}]}], 
                  "]"}], "]"}]}]}]}], ";"}]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Get2", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"n", "/", "2"}], ",", 
                RowBox[{"m", "-", 
                 RowBox[{"1", "/", "2"}]}], ",", "x_"}], "}"}], "]"}], 
             "\[NotEqual]", "0"}], ",", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"c33", "=", 
              RowBox[{"c33", "+", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"1", "/", "2"}], "+", 
                   RowBox[{"m", "/", 
                    RowBox[{"(", 
                    RowBox[{"n", "+", "1"}], ")"}]}]}], ")"}], "/", "n"}], 
                "*", 
                RowBox[{"FA22", "[", 
                 RowBox[{"[", 
                  RowBox[{
                   RowBox[{"Get2", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"n", "/", "2"}], ",", 
                    RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", "x_"}], "}"}], "]"}], ",", 
                   RowBox[{"Get2", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"n", "/", "2"}], ",", 
                    RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", "x_"}], "}"}], "]"}]}], 
                  "]"}], "]"}]}]}]}], ";", "\[IndentingNewLine]", 
             RowBox[{"c44", "=", 
              RowBox[{"c44", "+", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"1", "/", "2"}], "+", 
                   RowBox[{"m", "/", 
                    RowBox[{"(", 
                    RowBox[{"n", "+", "1"}], ")"}]}]}], ")"}], "/", "n"}], 
                "*", 
                RowBox[{"FB22", "[", 
                 RowBox[{"[", 
                  RowBox[{
                   RowBox[{"Get2", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"n", "/", "2"}], ",", 
                    RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", "x_"}], "}"}], "]"}], ",", 
                   RowBox[{"Get2", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"n", "/", "2"}], ",", 
                    RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", "x_"}], "}"}], "]"}]}], 
                  "]"}], "]"}]}]}]}], ";", "\[IndentingNewLine]", 
             RowBox[{"c34", "=", 
              RowBox[{"c34", "+", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"1", "/", "2"}], "+", 
                   RowBox[{"m", "/", 
                    RowBox[{"(", 
                    RowBox[{"n", "+", "1"}], ")"}]}]}], ")"}], "/", "n"}], 
                "*", 
                RowBox[{"FCa22", "[", 
                 RowBox[{"[", 
                  RowBox[{
                   RowBox[{"Get2", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"n", "/", "2"}], ",", 
                    RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", "x_"}], "}"}], "]"}], ",", 
                   RowBox[{"Get2", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"n", "/", "2"}], ",", 
                    RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", "x_"}], "}"}], "]"}]}], 
                  "]"}], "]"}]}]}]}], ";"}]}], "]"}], ";"}], 
         "\[IndentingNewLine]", ",", 
         RowBox[{"{", 
          RowBox[{"m", ",", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"(", 
              RowBox[{"n", "+", "1"}], ")"}]}], "/", "2"}], ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"n", "+", "1"}], ")"}], "/", "2"}]}], "}"}]}], "]"}], 
       ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"c21", "=", 
        RowBox[{"Conjugate", "[", "c12", "]"}]}], ";", 
       RowBox[{"c31", "=", 
        RowBox[{"Conjugate", "[", "c13", "]"}]}], ";", 
       RowBox[{"c41", "=", 
        RowBox[{"Conjugate", "[", "c14", "]"}]}], ";", 
       RowBox[{"c32", "=", 
        RowBox[{"Conjugate", "[", "c23", "]"}]}], ";", 
       RowBox[{"c42", "=", 
        RowBox[{"Conjugate", "[", "c24", "]"}]}], ";", 
       RowBox[{"c43", "=", 
        RowBox[{"Conjugate", "[", "c34", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"c11", ",", "c12", ",", "c13", ",", "c14"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"c21", ",", "c22", ",", "c23", ",", "c24"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"c31", ",", "c32", ",", "c33", ",", "c34"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"c41", ",", "c42", ",", "c43", ",", "c44"}], "}"}]}], 
         "}"}], "*", 
        RowBox[{"(", 
         RowBox[{"n", "/", "2"}], ")"}]}]}]}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"PBTChoiMatrix", "[", "x_", "]"}], ":=", 
    RowBox[{"PBTChoiMatrix", "[", 
     RowBox[{
      RowBox[{"x", "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", 
      RowBox[{"x", "[", 
       RowBox[{"[", "2", "]"}], "]"}], ",", 
      RowBox[{"x", "[", 
       RowBox[{"[", "3", "]"}], "]"}]}], "]"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"Utility", " ", "functions"}], ",", " ", 
     RowBox[{"used", " ", "in", " ", "the", " ", "main", " ", "functions"}]}],
     "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"CrossProd", "[", 
     RowBox[{"a_", ",", "b_"}], "]"}], ":=", 
    RowBox[{"ArrayFlatten", "[", 
     RowBox[{"TensorProduct", "[", 
      RowBox[{"a", ",", "b"}], "]"}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"G", "[", 
     RowBox[{"n_", ",", "j_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", "j"}], "+", "1"}], ")"}], 
     RowBox[{
      RowBox[{"n", "!"}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"n", "/", "2"}], "-", "j"}], ")"}], "!"}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"n", "/", "2"}], "+", "1", "+", "j"}], ")"}], "!"}]}], 
       ")"}]}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Retrieve", "[", 
     RowBox[{"list_", ",", "ref_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", "index", "}"}], ",", 
      RowBox[{
       RowBox[{"index", "=", 
        RowBox[{"Flatten", "[", 
         RowBox[{"Position", "[", 
          RowBox[{
           RowBox[{"list", "[", 
            RowBox[{"[", "1", "]"}], "]"}], ",", "ref"}], "]"}], "]"}]}], ";", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"index", "\[Equal]", 
          RowBox[{"{", "}"}]}], ",", 
         RowBox[{"list", "[", 
          RowBox[{"[", "3", "]"}], "]"}], ",", 
         RowBox[{"Flatten", "[", 
          RowBox[{"list", "[", 
           RowBox[{"[", 
            RowBox[{"2", ",", "index"}], "]"}], "]"}], "]"}]}], "]"}]}]}], 
     "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"sigma1", "[", 
     RowBox[{"sig1_", ",", "sig2_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"n", "=", 
         RowBox[{
          RowBox[{"Log2", "[", 
           RowBox[{"Length", "[", 
            RowBox[{"sig1", "[", 
             RowBox[{"[", 
              RowBox[{"2", ",", "1"}], "]"}], "]"}], "]"}], "]"}], "+", 
          "1"}]}], ",", 
        RowBox[{"list", "=", 
         RowBox[{"{", "}"}]}], ",", 
        RowBox[{"refs", "=", 
         RowBox[{"{", "}"}]}], ",", "jmin", ",", "jmax", ",", "mmax", ",", 
        "deg", ",", "d1"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"EvenQ", "[", "n", "]"}], ",", 
         RowBox[{"jmin", "=", "0"}], ",", 
         RowBox[{"jmin", "=", 
          RowBox[{"1", "/", "2"}]}]}], "]"}], ";", 
       RowBox[{"jmax", "=", 
        RowBox[{"n", "/", "2"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Do", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"mmax", "=", "j"}], ";", 
          RowBox[{"deg", "=", 
           RowBox[{"G", "[", 
            RowBox[{
             RowBox[{"n", "-", "1"}], ",", 
             RowBox[{"j", "+", 
              RowBox[{"1", "/", "2"}]}]}], "]"}]}], ";", 
          RowBox[{"d1", "=", 
           RowBox[{"G", "[", 
            RowBox[{
             RowBox[{"n", "-", "2"}], ",", 
             RowBox[{"j", "+", "1"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"Do", "[", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"Do", "[", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{
               RowBox[{"AppendTo", "[", 
                RowBox[{"refs", ",", 
                 RowBox[{"{", 
                  RowBox[{"j", ",", "m", ",", "alpha"}], "}"}]}], "]"}], ";", 
               "\[IndentingNewLine]", 
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{"alpha", "\[LessEqual]", "d1"}], ",", 
                 "\[IndentingNewLine]", 
                 RowBox[{
                  RowBox[{"AppendTo", "[", 
                   RowBox[{"list", ",", 
                    RowBox[{"Simplify", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Flatten", "[", 
                    RowBox[{"CrossProd", "[", 
                    RowBox[{
                    RowBox[{"Retrieve", "[", 
                    RowBox[{"sig1", ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"j", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}]}], "]"}],
                     ",", 
                    RowBox[{"{", 
                    RowBox[{"1", ",", "0"}], "}"}]}], "]"}], "]"}], 
                    RowBox[{"Quiet", "[", 
                    RowBox[{"ClebschGordan", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"j", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"1", "/", "2"}], ",", 
                    RowBox[{
                    RowBox[{"-", "1"}], "/", "2"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"j", ",", "m"}], "}"}]}], "]"}], "]"}]}], "+", 
                    RowBox[{
                    RowBox[{"Flatten", "[", 
                    RowBox[{"CrossProd", "[", 
                    RowBox[{
                    RowBox[{"Retrieve", "[", 
                    RowBox[{"sig1", ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"j", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}]}], "]"}],
                     ",", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "1"}], "}"}]}], "]"}], "]"}], 
                    RowBox[{"Quiet", "[", 
                    RowBox[{"ClebschGordan", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"j", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"1", "/", "2"}], ",", 
                    RowBox[{"1", "/", "2"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"j", ",", "m"}], "}"}]}], "]"}], "]"}]}]}], 
                    "]"}]}], "]"}], ";"}], ",", "\[IndentingNewLine]", 
                 RowBox[{
                  RowBox[{"AppendTo", "[", 
                   RowBox[{"list", ",", 
                    RowBox[{"Simplify", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Flatten", "[", 
                    RowBox[{"CrossProd", "[", 
                    RowBox[{
                    RowBox[{"Retrieve", "[", 
                    RowBox[{"sig2", ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"j", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"alpha", "-", "d1"}]}], "}"}]}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"1", ",", "0"}], "}"}]}], "]"}], "]"}], 
                    RowBox[{"Quiet", "[", 
                    RowBox[{"ClebschGordan", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"j", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"1", "/", "2"}], ",", 
                    RowBox[{
                    RowBox[{"-", "1"}], "/", "2"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"j", ",", "m"}], "}"}]}], "]"}], "]"}]}], "+", 
                    RowBox[{
                    RowBox[{"Flatten", "[", 
                    RowBox[{"CrossProd", "[", 
                    RowBox[{
                    RowBox[{"Retrieve", "[", 
                    RowBox[{"sig2", ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"j", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"alpha", "-", "d1"}]}], "}"}]}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "1"}], "}"}]}], "]"}], "]"}], 
                    RowBox[{"Quiet", "[", 
                    RowBox[{"ClebschGordan", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"j", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"1", "/", "2"}], ",", 
                    RowBox[{"1", "/", "2"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"j", ",", "m"}], "}"}]}], "]"}], "]"}]}]}], 
                    "]"}]}], "]"}], ";"}]}], "\[IndentingNewLine]", "]"}]}], 
              "\[IndentingNewLine]", ",", 
              RowBox[{"{", 
               RowBox[{"alpha", ",", "1", ",", "deg"}], "}"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"m", ",", 
              RowBox[{"-", "mmax"}], ",", "mmax"}], "}"}]}], "]"}]}], 
         "\[IndentingNewLine]", ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "jmin", ",", "jmax"}], "}"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"refs", ",", "list", ",", 
         RowBox[{"ConstantArray", "[", 
          RowBox[{"0", ",", 
           RowBox[{"2", "^", 
            RowBox[{"(", "n", ")"}]}]}], "]"}]}], "}"}]}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"sigma2", "[", 
     RowBox[{"sig1_", ",", "sig2_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"n", "=", 
         RowBox[{
          RowBox[{"Log2", "[", 
           RowBox[{"Length", "[", 
            RowBox[{"sig1", "[", 
             RowBox[{"[", 
              RowBox[{"2", ",", "1"}], "]"}], "]"}], "]"}], "]"}], "+", 
          "1"}]}], ",", 
        RowBox[{"list", "=", 
         RowBox[{"{", "}"}]}], ",", 
        RowBox[{"refs", "=", 
         RowBox[{"{", "}"}]}], ",", "jmin", ",", "jmax", ",", "mmax", ",", 
        "deg", ",", "d1"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"EvenQ", "[", "n", "]"}], ",", 
         RowBox[{"jmin", "=", "0"}], ",", 
         RowBox[{"jmin", "=", 
          RowBox[{"1", "/", "2"}]}]}], "]"}], ";", 
       RowBox[{"jmax", "=", 
        RowBox[{"n", "/", "2"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Do", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"mmax", "=", "j"}], ";", 
          RowBox[{"deg", "=", 
           RowBox[{"G", "[", 
            RowBox[{
             RowBox[{"n", "-", "1"}], ",", 
             RowBox[{"j", "-", 
              RowBox[{"1", "/", "2"}]}]}], "]"}]}], ";", 
          RowBox[{"d1", "=", 
           RowBox[{"G", "[", 
            RowBox[{
             RowBox[{"n", "-", "2"}], ",", "j"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"Do", "[", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"Do", "[", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{
               RowBox[{"AppendTo", "[", 
                RowBox[{"refs", ",", 
                 RowBox[{"{", 
                  RowBox[{"j", ",", "m", ",", "alpha"}], "}"}]}], "]"}], ";", 
               "\[IndentingNewLine]", 
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{"alpha", "\[LessEqual]", "d1"}], ",", 
                 "\[IndentingNewLine]", 
                 RowBox[{
                  RowBox[{"AppendTo", "[", 
                   RowBox[{"list", ",", 
                    RowBox[{"Simplify", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Flatten", "[", 
                    RowBox[{"CrossProd", "[", 
                    RowBox[{
                    RowBox[{"Retrieve", "[", 
                    RowBox[{"sig1", ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"j", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}]}], "]"}],
                     ",", 
                    RowBox[{"{", 
                    RowBox[{"1", ",", "0"}], "}"}]}], "]"}], "]"}], 
                    RowBox[{"Quiet", "[", 
                    RowBox[{"ClebschGordan", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"j", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"1", "/", "2"}], ",", 
                    RowBox[{
                    RowBox[{"-", "1"}], "/", "2"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"j", ",", "m"}], "}"}]}], "]"}], "]"}]}], "+", 
                    RowBox[{
                    RowBox[{"Flatten", "[", 
                    RowBox[{"CrossProd", "[", 
                    RowBox[{
                    RowBox[{"Retrieve", "[", 
                    RowBox[{"sig1", ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"j", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", "alpha"}], "}"}]}], "]"}],
                     ",", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "1"}], "}"}]}], "]"}], "]"}], 
                    RowBox[{"Quiet", "[", 
                    RowBox[{"ClebschGordan", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"j", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"1", "/", "2"}], ",", 
                    RowBox[{"1", "/", "2"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"j", ",", "m"}], "}"}]}], "]"}], "]"}]}]}], 
                    "]"}]}], "]"}], ";"}], ",", "\[IndentingNewLine]", 
                 RowBox[{
                  RowBox[{"AppendTo", "[", 
                   RowBox[{"list", ",", 
                    RowBox[{"Simplify", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Flatten", "[", 
                    RowBox[{"CrossProd", "[", 
                    RowBox[{
                    RowBox[{"Retrieve", "[", 
                    RowBox[{"sig2", ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"j", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"alpha", "-", "d1"}]}], "}"}]}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"1", ",", "0"}], "}"}]}], "]"}], "]"}], 
                    RowBox[{"Quiet", "[", 
                    RowBox[{"ClebschGordan", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"j", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"1", "/", "2"}], ",", 
                    RowBox[{
                    RowBox[{"-", "1"}], "/", "2"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"j", ",", "m"}], "}"}]}], "]"}], "]"}]}], "+", 
                    RowBox[{
                    RowBox[{"Flatten", "[", 
                    RowBox[{"CrossProd", "[", 
                    RowBox[{
                    RowBox[{"Retrieve", "[", 
                    RowBox[{"sig2", ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"j", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"alpha", "-", "d1"}]}], "}"}]}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "1"}], "}"}]}], "]"}], "]"}], 
                    RowBox[{"Quiet", "[", 
                    RowBox[{"ClebschGordan", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"j", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"1", "/", "2"}], ",", 
                    RowBox[{"1", "/", "2"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"j", ",", "m"}], "}"}]}], "]"}], "]"}]}]}], 
                    "]"}]}], "]"}], ";"}]}], "\[IndentingNewLine]", "]"}]}], 
              "\[IndentingNewLine]", ",", 
              RowBox[{"{", 
               RowBox[{"alpha", ",", "1", ",", "deg"}], "}"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"m", ",", 
              RowBox[{"-", "mmax"}], ",", "mmax"}], "}"}]}], "]"}]}], 
         "\[IndentingNewLine]", ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "jmin", ",", "jmax"}], "}"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"refs", ",", "list", ",", 
         RowBox[{"ConstantArray", "[", 
          RowBox[{"0", ",", 
           RowBox[{"2", "^", 
            RowBox[{"(", "n", ")"}]}]}], "]"}]}], "}"}]}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"psi1", "[", "sigma_", "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"n", "=", 
         RowBox[{
          RowBox[{"Log2", "[", 
           RowBox[{"Length", "[", 
            RowBox[{"sigma", "[", 
             RowBox[{"[", 
              RowBox[{"2", ",", "1"}], "]"}], "]"}], "]"}], "]"}], "+", 
          "1"}]}], ",", 
        RowBox[{"list", "=", 
         RowBox[{"{", "}"}]}], ",", 
        RowBox[{"refs", "=", 
         RowBox[{"{", "}"}]}], ",", "jmin", ",", "jmax", ",", "mmax", ",", 
        "deg"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"EvenQ", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", 
         RowBox[{"jmin", "=", 
          RowBox[{"1", "/", "2"}]}], ",", 
         RowBox[{"jmin", "=", "0"}]}], "]"}], ";", 
       RowBox[{"jmax", "=", 
        RowBox[{
         RowBox[{"n", "/", "2"}], "-", "1"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Do", "[", 
        RowBox[{
         RowBox[{"Do", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"pm", "\[Equal]", 
               RowBox[{"-", "1"}]}], ",", 
              RowBox[{"mmax", "=", 
               RowBox[{"j", "+", 
                RowBox[{"1", "/", "2"}]}]}], ",", 
              RowBox[{"mmax", "=", 
               RowBox[{"j", "-", 
                RowBox[{"1", "/", "2"}]}]}]}], "]"}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"Do", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"deg", "=", 
                RowBox[{"G", "[", 
                 RowBox[{
                  RowBox[{"n", "-", "1"}], ",", 
                  RowBox[{"j", "+", 
                   RowBox[{"1", "/", "2"}]}]}], "]"}]}], ";", 
               "\[IndentingNewLine]", 
               RowBox[{"Do", "[", "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{
                  RowBox[{"AppendTo", "[", 
                   RowBox[{"refs", ",", 
                    RowBox[{"{", 
                    RowBox[{"j", ",", "pm", ",", "m", ",", "alpha"}], "}"}]}],
                    "]"}], ";", "\[IndentingNewLine]", 
                  RowBox[{"AppendTo", "[", 
                   RowBox[{"list", ",", 
                    RowBox[{"Simplify", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Flatten", "[", 
                    RowBox[{"CrossProd", "[", 
                    RowBox[{
                    RowBox[{"Retrieve", "[", 
                    RowBox[{"sigma", ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"j", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "+", "1"}], ",", "alpha"}], "}"}]}], "]"}], 
                    ",", 
                    RowBox[{"{", 
                    RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}]}], 
                    "]"}], "]"}], 
                    RowBox[{"Quiet", "[", 
                    RowBox[{
                    RowBox[{"ClebschGordan", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"j", ",", 
                    RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"1", "/", "2"}], ",", 
                    RowBox[{
                    RowBox[{"-", "1"}], "/", "2"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"j", "-", 
                    RowBox[{"pm", "*", 
                    RowBox[{"1", "/", "2"}]}]}], ",", "m"}], "}"}]}], "]"}], 
                    RowBox[{"ClebschGordan", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"j", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "+", "1"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"1", "/", "2"}], ",", 
                    RowBox[{
                    RowBox[{"-", "1"}], "/", "2"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"j", ",", 
                    RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}]}], "}"}]}], "]"}]}], "]"}]}], 
                    "+", 
                    RowBox[{
                    RowBox[{"Flatten", "[", 
                    RowBox[{"CrossProd", "[", 
                    RowBox[{
                    RowBox[{"Retrieve", "[", 
                    RowBox[{"sigma", ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"j", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", "m", ",", "alpha"}], 
                    "}"}]}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "0", ",", "1", ",", "0"}], "}"}]}], 
                    "]"}], "]"}], 
                    RowBox[{"Quiet", "[", 
                    RowBox[{
                    RowBox[{"ClebschGordan", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"j", ",", 
                    RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"1", "/", "2"}], ",", 
                    RowBox[{
                    RowBox[{"-", "1"}], "/", "2"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"j", "-", 
                    RowBox[{"pm", "*", 
                    RowBox[{"1", "/", "2"}]}]}], ",", "m"}], "}"}]}], "]"}], 
                    RowBox[{"ClebschGordan", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"j", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", "m"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"1", "/", "2"}], ",", 
                    RowBox[{"1", "/", "2"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"j", ",", 
                    RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}]}], "}"}]}], "]"}]}], "]"}]}], 
                    "+", 
                    RowBox[{
                    RowBox[{"Flatten", "[", 
                    RowBox[{"CrossProd", "[", 
                    RowBox[{
                    RowBox[{"Retrieve", "[", 
                    RowBox[{"sigma", ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"j", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", "m", ",", "alpha"}], 
                    "}"}]}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "1", ",", "0", ",", "0"}], "}"}]}], 
                    "]"}], "]"}], 
                    RowBox[{"Quiet", "[", 
                    RowBox[{
                    RowBox[{"ClebschGordan", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"j", ",", 
                    RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"1", "/", "2"}], ",", 
                    RowBox[{"1", "/", "2"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"j", "-", 
                    RowBox[{"pm", "*", 
                    RowBox[{"1", "/", "2"}]}]}], ",", "m"}], "}"}]}], "]"}], 
                    RowBox[{"ClebschGordan", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"j", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", "m"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"1", "/", "2"}], ",", 
                    RowBox[{
                    RowBox[{"-", "1"}], "/", "2"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"j", ",", 
                    RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}]}], "}"}]}], "]"}]}], "]"}]}], 
                    "+", 
                    RowBox[{
                    RowBox[{"Flatten", "[", 
                    RowBox[{"CrossProd", "[", 
                    RowBox[{
                    RowBox[{"Retrieve", "[", 
                    RowBox[{"sigma", ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"j", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "-", "1"}], ",", "alpha"}], "}"}]}], "]"}], 
                    ",", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "0", ",", "0", ",", "1"}], "}"}]}], 
                    "]"}], "]"}], 
                    RowBox[{"Quiet", "[", 
                    RowBox[{
                    RowBox[{"ClebschGordan", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"j", ",", 
                    RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"1", "/", "2"}], ",", 
                    RowBox[{"1", "/", "2"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"j", "-", 
                    RowBox[{"pm", "*", 
                    RowBox[{"1", "/", "2"}]}]}], ",", "m"}], "}"}]}], "]"}], 
                    RowBox[{"ClebschGordan", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"j", "+", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "-", "1"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"1", "/", "2"}], ",", 
                    RowBox[{"1", "/", "2"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"j", ",", 
                    RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}]}], "}"}]}], "]"}]}], "]"}]}]}], 
                    "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", ",", 
                 RowBox[{"{", 
                  RowBox[{"alpha", ",", "1", ",", "deg"}], "}"}]}], "]"}]}], 
              ",", 
              RowBox[{"{", 
               RowBox[{"m", ",", 
                RowBox[{"-", "mmax"}], ",", "mmax"}], "}"}]}], "]"}]}], 
           "\[IndentingNewLine]", ",", 
           RowBox[{"{", 
            RowBox[{"pm", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "jmin", ",", "jmax"}], "}"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"refs", ",", "list", ",", 
         RowBox[{"ConstantArray", "[", 
          RowBox[{"0", ",", 
           RowBox[{"2", "^", 
            RowBox[{"(", 
             RowBox[{"n", "+", "1"}], ")"}]}]}], "]"}]}], "}"}]}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"psi2", "[", "sigma_", "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"n", "=", 
         RowBox[{
          RowBox[{"Log2", "[", 
           RowBox[{"Length", "[", 
            RowBox[{"sigma", "[", 
             RowBox[{"[", 
              RowBox[{"2", ",", "1"}], "]"}], "]"}], "]"}], "]"}], "+", 
          "1"}]}], ",", 
        RowBox[{"list", "=", 
         RowBox[{"{", "}"}]}], ",", 
        RowBox[{"refs", "=", 
         RowBox[{"{", "}"}]}], ",", "jmin", ",", "jmax", ",", "mmax", ",", 
        "deg"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"EvenQ", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", 
         RowBox[{"jmin", "=", 
          RowBox[{"1", "/", "2"}]}], ",", 
         RowBox[{"jmin", "=", "0"}]}], "]"}], ";", 
       RowBox[{"jmax", "=", 
        RowBox[{"n", "/", "2"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Do", "[", 
        RowBox[{
         RowBox[{"Do", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"pm", "\[Equal]", 
               RowBox[{"-", "1"}]}], ",", 
              RowBox[{"mmax", "=", 
               RowBox[{"j", "+", 
                RowBox[{"1", "/", "2"}]}]}], ",", 
              RowBox[{"mmax", "=", 
               RowBox[{"j", "-", 
                RowBox[{"1", "/", "2"}]}]}]}], "]"}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"Do", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"deg", "=", 
                RowBox[{"G", "[", 
                 RowBox[{
                  RowBox[{"n", "-", "1"}], ",", 
                  RowBox[{"j", "-", 
                   RowBox[{"1", "/", "2"}]}]}], "]"}]}], ";", 
               "\[IndentingNewLine]", 
               RowBox[{"Do", "[", "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{
                  RowBox[{"AppendTo", "[", 
                   RowBox[{"refs", ",", 
                    RowBox[{"{", 
                    RowBox[{"j", ",", "pm", ",", "m", ",", "alpha"}], "}"}]}],
                    "]"}], ";", "\[IndentingNewLine]", 
                  RowBox[{"AppendTo", "[", 
                   RowBox[{"list", ",", 
                    RowBox[{"Simplify", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Flatten", "[", 
                    RowBox[{"CrossProd", "[", 
                    RowBox[{
                    RowBox[{"Retrieve", "[", 
                    RowBox[{"sigma", ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"j", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "+", "1"}], ",", "alpha"}], "}"}]}], "]"}], 
                    ",", 
                    RowBox[{"{", 
                    RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}]}], 
                    "]"}], "]"}], 
                    RowBox[{"Quiet", "[", 
                    RowBox[{
                    RowBox[{"ClebschGordan", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"j", ",", 
                    RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"1", "/", "2"}], ",", 
                    RowBox[{
                    RowBox[{"-", "1"}], "/", "2"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"j", "-", 
                    RowBox[{"pm", "*", 
                    RowBox[{"1", "/", "2"}]}]}], ",", "m"}], "}"}]}], "]"}], 
                    RowBox[{"ClebschGordan", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"j", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "+", "1"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"1", "/", "2"}], ",", 
                    RowBox[{
                    RowBox[{"-", "1"}], "/", "2"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"j", ",", 
                    RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}]}], "}"}]}], "]"}]}], "]"}]}], 
                    "+", 
                    RowBox[{
                    RowBox[{"Flatten", "[", 
                    RowBox[{"CrossProd", "[", 
                    RowBox[{
                    RowBox[{"Retrieve", "[", 
                    RowBox[{"sigma", ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"j", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", "m", ",", "alpha"}], 
                    "}"}]}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "0", ",", "1", ",", "0"}], "}"}]}], 
                    "]"}], "]"}], 
                    RowBox[{"Quiet", "[", 
                    RowBox[{
                    RowBox[{"ClebschGordan", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"j", ",", 
                    RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"1", "/", "2"}], ",", 
                    RowBox[{
                    RowBox[{"-", "1"}], "/", "2"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"j", "-", 
                    RowBox[{"pm", "*", 
                    RowBox[{"1", "/", "2"}]}]}], ",", "m"}], "}"}]}], "]"}], 
                    RowBox[{"ClebschGordan", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"j", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", "m"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"1", "/", "2"}], ",", 
                    RowBox[{"1", "/", "2"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"j", ",", 
                    RowBox[{"m", "+", 
                    RowBox[{"1", "/", "2"}]}]}], "}"}]}], "]"}]}], "]"}]}], 
                    "+", 
                    RowBox[{
                    RowBox[{"Flatten", "[", 
                    RowBox[{"CrossProd", "[", 
                    RowBox[{
                    RowBox[{"Retrieve", "[", 
                    RowBox[{"sigma", ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"j", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", "m", ",", "alpha"}], 
                    "}"}]}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "1", ",", "0", ",", "0"}], "}"}]}], 
                    "]"}], "]"}], 
                    RowBox[{"Quiet", "[", 
                    RowBox[{
                    RowBox[{"ClebschGordan", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"j", ",", 
                    RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"1", "/", "2"}], ",", 
                    RowBox[{"1", "/", "2"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"j", "-", 
                    RowBox[{"pm", "*", 
                    RowBox[{"1", "/", "2"}]}]}], ",", "m"}], "}"}]}], "]"}], 
                    RowBox[{"ClebschGordan", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"j", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", "m"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"1", "/", "2"}], ",", 
                    RowBox[{
                    RowBox[{"-", "1"}], "/", "2"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"j", ",", 
                    RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}]}], "}"}]}], "]"}]}], "]"}]}], 
                    "+", 
                    RowBox[{
                    RowBox[{"Flatten", "[", 
                    RowBox[{"CrossProd", "[", 
                    RowBox[{
                    RowBox[{"Retrieve", "[", 
                    RowBox[{"sigma", ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"j", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "-", "1"}], ",", "alpha"}], "}"}]}], "]"}], 
                    ",", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "0", ",", "0", ",", "1"}], "}"}]}], 
                    "]"}], "]"}], 
                    RowBox[{"Quiet", "[", 
                    RowBox[{
                    RowBox[{"ClebschGordan", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"j", ",", 
                    RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"1", "/", "2"}], ",", 
                    RowBox[{"1", "/", "2"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"j", "-", 
                    RowBox[{"pm", "*", 
                    RowBox[{"1", "/", "2"}]}]}], ",", "m"}], "}"}]}], "]"}], 
                    RowBox[{"ClebschGordan", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"j", "-", 
                    RowBox[{"1", "/", "2"}]}], ",", 
                    RowBox[{"m", "-", "1"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"1", "/", "2"}], ",", 
                    RowBox[{"1", "/", "2"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"j", ",", 
                    RowBox[{"m", "-", 
                    RowBox[{"1", "/", "2"}]}]}], "}"}]}], "]"}]}], "]"}]}]}], 
                    "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", ",", 
                 RowBox[{"{", 
                  RowBox[{"alpha", ",", "1", ",", "deg"}], "}"}]}], "]"}]}], 
              ",", 
              RowBox[{"{", 
               RowBox[{"m", ",", 
                RowBox[{"-", "mmax"}], ",", "mmax"}], "}"}]}], "]"}]}], 
           "\[IndentingNewLine]", ",", 
           RowBox[{"{", 
            RowBox[{"pm", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "jmin", ",", "jmax"}], "}"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"refs", ",", "list", ",", 
         RowBox[{"ConstantArray", "[", 
          RowBox[{"0", ",", 
           RowBox[{"2", "^", 
            RowBox[{"(", 
             RowBox[{"n", "+", "1"}], ")"}]}]}], "]"}]}], "}"}]}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MergeVecTypes", "[", 
     RowBox[{"sig1_", ",", "sig2_", ",", 
      RowBox[{"alphaorder_:", "0"}]}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"n", "=", 
         RowBox[{"Log2", "[", 
          RowBox[{"Length", "[", 
           RowBox[{"sig1", "[", 
            RowBox[{"[", 
             RowBox[{"2", ",", "1"}], "]"}], "]"}], "]"}], "]"}]}], ",", 
        RowBox[{"list", "=", 
         RowBox[{"{", "}"}]}], ",", 
        RowBox[{"refs", "=", 
         RowBox[{"{", "}"}]}], ",", "jmin", ",", "jmax", ",", "mmax", ",", 
        "deg", ",", "d1"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"EvenQ", "[", "n", "]"}], ",", 
         RowBox[{"jmin", "=", "0"}], ",", 
         RowBox[{"jmin", "=", 
          RowBox[{"1", "/", "2"}]}]}], "]"}], ";", 
       RowBox[{"jmax", "=", 
        RowBox[{"n", "/", "2"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Do", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"mmax", "=", "j"}], ";", 
          RowBox[{"deg", "=", 
           RowBox[{"G", "[", 
            RowBox[{"n", ",", "j"}], "]"}]}], ";", 
          RowBox[{"d1", "=", 
           RowBox[{"G", "[", 
            RowBox[{
             RowBox[{"n", "-", "1"}], ",", 
             RowBox[{"j", "+", 
              RowBox[{"1", "/", "2"}]}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"alphaorder", "\[Equal]", "0"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"Do", "[", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"Do", "[", "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{
                 RowBox[{"AppendTo", "[", 
                  RowBox[{"refs", ",", 
                   RowBox[{"{", 
                    RowBox[{"j", ",", "m", ",", "alpha"}], "}"}]}], "]"}], 
                 ";", "\[IndentingNewLine]", 
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{"alpha", "\[LessEqual]", "d1"}], ",", 
                   RowBox[{"AppendTo", "[", 
                    RowBox[{"list", ",", 
                    RowBox[{"Retrieve", "[", 
                    RowBox[{"sig1", ",", 
                    RowBox[{"{", 
                    RowBox[{"j", ",", "m", ",", "alpha"}], "}"}]}], "]"}]}], 
                    "]"}], ",", 
                   RowBox[{"AppendTo", "[", 
                    RowBox[{"list", ",", 
                    RowBox[{"Retrieve", "[", 
                    RowBox[{"sig2", ",", 
                    RowBox[{"{", 
                    RowBox[{"j", ",", "m", ",", 
                    RowBox[{"alpha", "-", "d1"}]}], "}"}]}], "]"}]}], "]"}]}],
                   "]"}]}], "\[IndentingNewLine]", ",", 
                RowBox[{"{", 
                 RowBox[{"alpha", ",", "1", ",", "deg"}], "}"}]}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"m", ",", 
                RowBox[{"-", "mmax"}], ",", "mmax"}], "}"}]}], "]"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"Do", "[", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"Do", "[", "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{
                 RowBox[{"AppendTo", "[", 
                  RowBox[{"refs", ",", 
                   RowBox[{"{", 
                    RowBox[{"j", ",", "m", ",", "alpha"}], "}"}]}], "]"}], 
                 ";", "\[IndentingNewLine]", 
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{"alpha", "\[LessEqual]", "d1"}], ",", 
                   RowBox[{"AppendTo", "[", 
                    RowBox[{"list", ",", 
                    RowBox[{"Retrieve", "[", 
                    RowBox[{"sig1", ",", 
                    RowBox[{"{", 
                    RowBox[{"j", ",", "m", ",", "alpha"}], "}"}]}], "]"}]}], 
                    "]"}], ",", 
                   RowBox[{"AppendTo", "[", 
                    RowBox[{"list", ",", 
                    RowBox[{"Retrieve", "[", 
                    RowBox[{"sig2", ",", 
                    RowBox[{"{", 
                    RowBox[{"j", ",", "m", ",", 
                    RowBox[{"alpha", "-", "d1"}]}], "}"}]}], "]"}]}], "]"}]}],
                   "]"}]}], "\[IndentingNewLine]", ",", 
                RowBox[{"{", 
                 RowBox[{"m", ",", 
                  RowBox[{"-", "mmax"}], ",", "mmax"}], "}"}]}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"alpha", ",", "1", ",", "deg"}], "}"}]}], "]"}]}], 
           "]"}]}], "\[IndentingNewLine]", ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "jmin", ",", "jmax"}], "}"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"refs", ",", "list", ",", 
         RowBox[{"ConstantArray", "[", 
          RowBox[{"0", ",", 
           RowBox[{"2", "^", 
            RowBox[{"(", "n", ")"}]}]}], "]"}]}], "}"}]}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"RotateState", "[", 
     RowBox[{"state_", ",", "dir_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"indices", ",", 
        RowBox[{"n", "=", 
         RowBox[{
          RowBox[{"Dimensions", "[", "state", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}]}]}], "}"}], ",", 
      RowBox[{
       RowBox[{"indices", "=", 
        RowBox[{"Which", "[", 
         RowBox[{
          RowBox[{"dir", "\[Equal]", "0"}], ",", 
          RowBox[{"Table", "[", 
           RowBox[{"i", ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "1", ",", "n"}], "}"}]}], "]"}], ",", 
          RowBox[{"dir", ">", "0"}], ",", 
          RowBox[{"Riffle", "[", 
           RowBox[{
            RowBox[{"Table", "[", 
             RowBox[{"i", ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", "1", ",", 
                RowBox[{"n", "/", "2"}]}], "}"}]}], "]"}], ",", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"i", "+", 
               RowBox[{"n", "/", "2"}]}], ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", "1", ",", 
                RowBox[{"n", "/", "2"}]}], "}"}]}], "]"}]}], "]"}], ",", 
          RowBox[{"dir", "<", "0"}], ",", 
          RowBox[{"Flatten", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"2", "i"}], "-", "1"}], ",", 
               RowBox[{"{", 
                RowBox[{"i", ",", "1", ",", 
                 RowBox[{"n", "/", "2"}]}], "}"}]}], "]"}], ",", 
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"2", "i"}], ",", 
               RowBox[{"{", 
                RowBox[{"i", ",", "1", ",", 
                 RowBox[{"n", "/", "2"}]}], "}"}]}], "]"}]}], "}"}], "]"}]}], 
         "]"}]}], ";", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Length", "[", 
           RowBox[{"Dimensions", "[", "state", "]"}], "]"}], "\[Equal]", 
          "1"}], ",", 
         RowBox[{"state", "[", 
          RowBox[{"[", "indices", "]"}], "]"}], ",", 
         RowBox[{"state", "[", 
          RowBox[{"[", 
           RowBox[{"indices", ",", "indices"}], "]"}], "]"}]}], "]"}]}]}], 
     "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"SwapQubits", "[", 
     RowBox[{"state_", ",", "swap_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"swaplist", ",", 
        RowBox[{"n", "=", 
         RowBox[{
          RowBox[{"Dimensions", "[", "state", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], ",", "indices"}], "}"}], ",", 
      RowBox[{
       RowBox[{"swaplist", "=", 
        RowBox[{"Flatten", "[", 
         RowBox[{"Map", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{"#", "[", 
                RowBox[{"[", "1", "]"}], "]"}], "\[Rule]", 
               RowBox[{"#", "[", 
                RowBox[{"[", "2", "]"}], "]"}]}], ",", 
              RowBox[{
               RowBox[{"#", "[", 
                RowBox[{"[", "2", "]"}], "]"}], "\[Rule]", 
               RowBox[{"#", "[", 
                RowBox[{"[", "1", "]"}], "]"}]}]}], "}"}], "&"}], ",", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"2", "^", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"swap", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "-", "1"}], ")"}]}], "+", 
                "1", "+", "x"}], ",", 
               RowBox[{
                RowBox[{"2", "^", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"swap", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "-", "1"}], ")"}]}], "+", 
                "1", "+", "x"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"x", ",", 
               RowBox[{"Total", "[", 
                RowBox[{
                 RowBox[{"Subsets", "[", 
                  RowBox[{"2", "^", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Delete", "[", 
                    RowBox[{
                    RowBox[{"Table", "[", 
                    RowBox[{"x", ",", 
                    RowBox[{"{", 
                    RowBox[{"x", ",", 
                    RowBox[{"Log2", "[", "n", "]"}]}], "}"}]}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"swap", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"swap", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "}"}]}], "}"}]}], "]"}], 
                    "-", "1"}], ")"}]}], "]"}], ",", 
                 RowBox[{"{", "2", "}"}]}], "]"}]}], "}"}]}], "]"}]}], "]"}], 
         "]"}]}], ";", 
       RowBox[{"indices", "=", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{"x", ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "n"}], "}"}]}], "]"}], "/.", "swaplist"}]}], 
       ";", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Length", "[", 
           RowBox[{"Dimensions", "[", "state", "]"}], "]"}], "\[Equal]", 
          "1"}], ",", 
         RowBox[{"state", "[", 
          RowBox[{"[", "indices", "]"}], "]"}], ",", 
         RowBox[{"state", "[", 
          RowBox[{"[", 
           RowBox[{"indices", ",", "indices"}], "]"}], "]"}]}], "]"}]}]}], 
     "]"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "Constructs", " ", "the", " ", "spin", " ", "eigenbasis", " ", "for", " ",
      "n", " ", "dimensions"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ConstructBasis", "[", 
     RowBox[{"n_", ",", 
      RowBox[{"merge_:", "1"}]}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"e1", ",", "e2", ",", "e1new", ",", "e2new"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"n", "\[Equal]", "1"}], ",", 
         RowBox[{"Return", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"1", "/", "2"}], ",", 
                RowBox[{
                 RowBox[{"-", "1"}], "/", "2"}], ",", "1"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"1", "/", "2"}], ",", 
                RowBox[{"1", "/", "2"}], ",", "1"}], "}"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"1", ",", "0"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"0", ",", "1"}], "}"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0"}], "}"}]}], "}"}], "]"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"e1", "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0", ",", "1"}], "}"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"{", 
            RowBox[{"0", ",", 
             RowBox[{"-", 
              FractionBox["1", 
               SqrtBox["2"]]}], ",", 
             FractionBox["1", 
              SqrtBox["2"]], ",", "0"}], "}"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}]}], ";", 
       RowBox[{"e2", "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1", ",", 
              RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"1", ",", "0", ",", "1"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", 
              FractionBox["1", 
               SqrtBox["2"]], ",", 
              FractionBox["1", 
               SqrtBox["2"]], ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0", ",", "1"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}]}], ";",
        "\[IndentingNewLine]", 
       RowBox[{"Do", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"e1new", "=", 
           RowBox[{"sigma1", "[", 
            RowBox[{"e1", ",", "e2"}], "]"}]}], ";", 
          RowBox[{"e2new", "=", 
           RowBox[{"sigma2", "[", 
            RowBox[{"e1", ",", "e2"}], "]"}]}], ";", 
          RowBox[{"e1", "=", "e1new"}], ";", 
          RowBox[{"e2", "=", "e2new"}], ";"}], ",", 
         RowBox[{"{", 
          RowBox[{"n", "-", "2"}], "}"}]}], "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"merge", "\[Equal]", "1"}], ",", 
         RowBox[{"Return", "[", 
          RowBox[{"MergeVecTypes", "[", 
           RowBox[{"e1", ",", "e2"}], "]"}], "]"}], ",", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"merge", "\[Equal]", "2"}], ",", 
           RowBox[{"Return", "[", 
            RowBox[{"MergeVecTypes", "[", 
             RowBox[{"e1", ",", "e2", ",", "1"}], "]"}], "]"}], ",", 
           RowBox[{"Return", "[", 
            RowBox[{"{", 
             RowBox[{"e1", ",", "e2"}], "}"}], "]"}]}], "]"}]}], "]"}]}]}], 
     "]"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
     "Convert", " ", "a", " ", "resource", " ", "state", " ", "from", " ", 
      "the", " ", "number", " ", "state", " ", "basis"}], ",", " ", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"with", " ", "structure", " ", 
          SubscriptBox["B", "1"], 
          SubscriptBox["B", "2"]}], "..."}], 
        SubscriptBox["B", "n"], 
        SubscriptBox["A", "1"], 
        SubscriptBox["A", "2"]}], "..."}], 
      SubscriptBox["A", "n"]}], ",", " ", 
     RowBox[{"to", " ", "the", " ", "format", " ", 
      RowBox[{"(", 
       RowBox[{"3", " ", "matrices"}], ")"}], " ", "required", " ", "for", 
      " ", "the", " ", "function", " ", "PBTChoiMatrix"}]}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ConvertResource", "[", "R_", "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"Ra", ",", "Rb", ",", "Rc", ",", "b", ",", 
        RowBox[{"n", "=", 
         RowBox[{
          RowBox[{"Log2", "[", 
           RowBox[{
            RowBox[{"Dimensions", "[", "R", "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}], "]"}], "/", "2"}]}], ",", 
        "bvects"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Ra", "=", 
        RowBox[{"RotateState", "[", 
         RowBox[{
          RowBox[{"Sum", "[", 
           RowBox[{
            RowBox[{"R", "[", 
             RowBox[{"[", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"i", "-", "1"}], ")"}], 
                  RowBox[{"(", 
                   RowBox[{"2", "^", "n"}], ")"}]}], "+", "1"}], ";;", 
                RowBox[{"i", 
                 RowBox[{"(", 
                  RowBox[{"2", "^", "n"}], ")"}]}]}], ",", 
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"i", "-", "1"}], ")"}], 
                  RowBox[{"(", 
                   RowBox[{"2", "^", "n"}], ")"}]}], "+", "1"}], ";;", 
                RowBox[{"i", 
                 RowBox[{"(", 
                  RowBox[{"2", "^", "n"}], ")"}]}]}]}], "]"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "1", ",", 
              RowBox[{"2", "^", 
               RowBox[{"(", 
                RowBox[{"n", "-", "1"}], ")"}]}]}], "}"}]}], "]"}], ",", 
          "1"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Rb", "=", 
        RowBox[{"RotateState", "[", 
         RowBox[{
          RowBox[{"Sum", "[", 
           RowBox[{
            RowBox[{"R", "[", 
             RowBox[{"[", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"i", "+", 
                    RowBox[{"2", "^", 
                    RowBox[{"(", 
                    RowBox[{"n", "-", "1"}], ")"}]}], "-", "1"}], ")"}], 
                  RowBox[{"(", 
                   RowBox[{"2", "^", "n"}], ")"}]}], "+", "1"}], ";;", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"i", "+", 
                   RowBox[{"2", "^", 
                    RowBox[{"(", 
                    RowBox[{"n", "-", "1"}], ")"}]}]}], ")"}], 
                 RowBox[{"(", 
                  RowBox[{"2", "^", "n"}], ")"}]}]}], ",", 
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"i", "+", 
                    RowBox[{"2", "^", 
                    RowBox[{"(", 
                    RowBox[{"n", "-", "1"}], ")"}]}], "-", "1"}], ")"}], 
                  RowBox[{"(", 
                   RowBox[{"2", "^", "n"}], ")"}]}], "+", "1"}], ";;", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"i", "+", 
                   RowBox[{"2", "^", 
                    RowBox[{"(", 
                    RowBox[{"n", "-", "1"}], ")"}]}]}], ")"}], 
                 RowBox[{"(", 
                  RowBox[{"2", "^", "n"}], ")"}]}]}]}], "]"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "1", ",", 
              RowBox[{"2", "^", 
               RowBox[{"(", 
                RowBox[{"n", "-", "1"}], ")"}]}]}], "}"}]}], "]"}], ",", 
          "1"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Rc", "=", 
        RowBox[{"RotateState", "[", 
         RowBox[{
          RowBox[{"Sum", "[", 
           RowBox[{
            RowBox[{"R", "[", 
             RowBox[{"[", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"i", "-", "1"}], ")"}], 
                  RowBox[{"(", 
                   RowBox[{"2", "^", "n"}], ")"}]}], "+", "1"}], ";;", 
                RowBox[{"i", 
                 RowBox[{"(", 
                  RowBox[{"2", "^", "n"}], ")"}]}]}], ",", 
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"i", "+", 
                    RowBox[{"2", "^", 
                    RowBox[{"(", 
                    RowBox[{"n", "-", "1"}], ")"}]}], "-", "1"}], ")"}], 
                  RowBox[{"(", 
                   RowBox[{"2", "^", "n"}], ")"}]}], "+", "1"}], ";;", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"i", "+", 
                   RowBox[{"2", "^", 
                    RowBox[{"(", 
                    RowBox[{"n", "-", "1"}], ")"}]}]}], ")"}], 
                 RowBox[{"(", 
                  RowBox[{"2", "^", "n"}], ")"}]}]}]}], "]"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "1", ",", 
              RowBox[{"2", "^", 
               RowBox[{"(", 
                RowBox[{"n", "-", "1"}], ")"}]}]}], "}"}]}], "]"}], ",", 
          "1"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"b", "=", 
        RowBox[{"ConstructBasis", "[", 
         RowBox[{"n", ",", "0"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"bvects", "=", 
        RowBox[{"Flatten", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"b", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "2"}], "]"}], "]"}], ",", 
            RowBox[{"b", "[", 
             RowBox[{"[", 
              RowBox[{"2", ",", "2"}], "]"}], "]"}]}], "}"}], ",", "1"}], 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Simplify", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"bvects", ".", "Ra", ".", 
           RowBox[{"Transpose", "[", "bvects", "]"}]}], ",", 
          RowBox[{"bvects", ".", "Rb", ".", 
           RowBox[{"Transpose", "[", "bvects", "]"}]}], ",", 
          RowBox[{"bvects", ".", "Rc", ".", 
           RowBox[{"Transpose", "[", "bvects", "]"}]}]}], "}"}], "]"}]}]}], 
     "]"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
     "Takes", " ", "a", " ", "resource", " ", "state", " ", "in", " ", "the", 
      " ", "number", " ", "state", " ", "basis"}], ",", " ", 
     RowBox[{"with", " ", "qubits", " ", "BA"}], ",", " ", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"and", " ", "returns", " ", 
          SubscriptBox["B", "1"], 
          SubscriptBox["B", "2"]}], "..."}], 
        SubscriptBox["B", "n"], 
        SubscriptBox["A", "1"], 
        SubscriptBox["A", "2"]}], "..."}], 
      SubscriptBox["A", "n"], " ", 
      RowBox[{"(", 
       RowBox[{"tensor", " ", "product", " ", "of", " ", "n", " ", "copies"}],
        ")"}]}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"RepeatResource", "[", 
     RowBox[{"resource_", ",", "n_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"state", "=", "resource"}], ",", "swaps", ",", "i"}], "}"}], 
      ",", 
      RowBox[{
       RowBox[{"swaps", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"i", ",", 
            RowBox[{"i", "+", "1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "2", ",", "n"}], "}"}]}], "]"}]}], ";", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"i", "=", "2"}], ",", 
         RowBox[{"i", "\[LessEqual]", "n"}], ",", 
         RowBox[{"i", "++"}], ",", 
         RowBox[{
          RowBox[{"state", "=", 
           RowBox[{"CrossProd", "[", 
            RowBox[{"state", ",", "resource"}], "]"}]}], ";", 
          RowBox[{"Do", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"state", "=", 
              RowBox[{"SwapQubits", "[", 
               RowBox[{"state", ",", 
                RowBox[{"swaps", "[", 
                 RowBox[{"[", "j", "]"}], "]"}]}], "]"}]}], ";"}], ",", 
            RowBox[{"{", 
             RowBox[{"j", ",", 
              RowBox[{"i", "-", "1"}]}], "}"}]}], "]"}]}]}], "]"}], ";", 
       "state"}]}], "]"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "Convert", " ", "the", " ", "Choi", " ", "matrix", " ", "into", " ", 
     "Kraus", " ", "operators"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ChoiToKraus", "[", "Choi_", "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"U", ",", "d", ",", 
        RowBox[{"Kraus", "=", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", "}"}], ",", 
           RowBox[{"{", "}"}], ",", 
           RowBox[{"{", "}"}], ",", 
           RowBox[{"{", "}"}]}], "}"}]}]}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"U", "=", 
        RowBox[{"Transpose", "[", 
         RowBox[{"Eigenvectors", "[", "Choi", "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"d", "=", 
        RowBox[{"Eigenvalues", "[", "Choi", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Do", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Kraus", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "=", 
          RowBox[{"Transpose", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"U", "[", 
               RowBox[{"[", 
                RowBox[{
                 RowBox[{"1", ";;", "2"}], ",", "i"}], "]"}], "]"}], ",", 
              RowBox[{"U", "[", 
               RowBox[{"[", 
                RowBox[{
                 RowBox[{"3", ";;", "4"}], ",", "i"}], "]"}], "]"}]}], "}"}], 
            "*", 
            RowBox[{"Sqrt", "[", 
             RowBox[{"2", 
              RowBox[{"d", "[", 
               RowBox[{"[", "i", "]"}], "]"}]}], "]"}]}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "4"}], "}"}]}], "]"}], ";", 
       "\[IndentingNewLine]", "Kraus"}]}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.742314486744037*^9, 3.7423146555775776`*^9}, {
   3.7423147059785542`*^9, 3.7423148228789773`*^9}, {3.7423148675286875`*^9, 
   3.742315003411399*^9}, {3.742315098978916*^9, 3.7423151218280725`*^9}, {
   3.742315240111946*^9, 3.742315268694998*^9}, {3.742317361845049*^9, 
   3.7423173665454073`*^9}, {3.742564958124116*^9, 3.742564967874194*^9}, {
   3.7425713433299446`*^9, 3.742571536246674*^9}, 3.7425717076638384`*^9, {
   3.742571744046939*^9, 3.742571757580681*^9}, {3.7425725446685925`*^9, 
   3.7425725611186237`*^9}, {3.7425800026264324`*^9, 
   3.7425800206755304`*^9}, {3.7425802365927396`*^9, 
   3.7425802389594927`*^9}, {3.7516509461710844`*^9, 3.751650973687242*^9}, {
   3.751651277354951*^9, 3.751651669987235*^9}, {3.7516517146408205`*^9, 
   3.751651866014135*^9}, {3.7516519696510525`*^9, 3.751652011247841*^9}, {
   3.7516522041101713`*^9, 3.751652224638313*^9}, {3.7516522879101505`*^9, 
   3.7516522931979856`*^9}, {3.751653163063778*^9, 3.751653206213623*^9}, {
   3.751653424825417*^9, 3.7516535217153797`*^9}, {3.751653562064642*^9, 
   3.7516536107080793`*^9}, {3.7516578568685393`*^9, 
   3.7516579262319155`*^9}, {3.7516583970779085`*^9, 3.751658425977412*^9}, {
   3.7516585669496903`*^9, 3.7516586028283873`*^9}, {3.7516586536655254`*^9, 
   3.751658686479515*^9}, {3.751658766801126*^9, 3.7516588208834066`*^9}, 
   3.751818129318057*^9, 3.7518183161101875`*^9, {3.7518208525902376`*^9, 
   3.751820883411106*^9}, {3.7518268201153154`*^9, 3.751826900787272*^9}, {
   3.751827007681691*^9, 3.751827124775647*^9}, {3.7526001128332253`*^9, 
   3.752600113506344*^9}, {3.753211121468016*^9, 3.7532111218893213`*^9}, {
   3.753795803921734*^9, 3.753795844515469*^9}, {3.753816310889736*^9, 
   3.7538163171585083`*^9}, 3.754064438741563*^9, {3.756652837824418*^9, 
   3.756652838598631*^9}, {3.7568076996955466`*^9, 3.756807700073535*^9}, {
   3.7576680551711187`*^9, 3.7576680567711277`*^9}, 3.7582914927289553`*^9, {
   3.825966187535733*^9, 3.825966189471711*^9}, {3.8259696543375587`*^9, 
   3.825969660564193*^9}, {3.8259697541035585`*^9, 3.8259697815920963`*^9}, {
   3.8259698135668983`*^9, 3.825969844996834*^9}, {3.825969879217429*^9, 
   3.82596991364573*^9}, {3.8259699804525247`*^9, 3.825970098043215*^9}, {
   3.8259701331509123`*^9, 3.8259701576117735`*^9}, {3.8259702130666065`*^9, 
   3.8259702158689775`*^9}, 3.825970420679324*^9, {3.8259705810651865`*^9, 
   3.825970581839105*^9}, {3.825970686236709*^9, 3.8259706918373313`*^9}, {
   3.825970808549464*^9, 3.82597088041031*^9}},
 CellLabel->
  "In[501]:=",ExpressionUUID->"3e6a16d1-b283-4aee-8be7-16120b527a8d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "Demonstration", " ", "of", " ", "how", " ", "to", " ", "use", " ", "the", 
    " ", "functions"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"NoisyBellState", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "p"}], ")"}], 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", 
           FractionBox["1", "2"], ",", 
           RowBox[{"-", 
            FractionBox["1", "2"]}], ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", 
           RowBox[{"-", 
            FractionBox["1", "2"]}], ",", 
           FractionBox["1", "2"], ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}]}], "+", 
      RowBox[{"p", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           FractionBox["1", "2"], ",", "0", ",", "0", ",", 
           FractionBox["1", "2"]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           FractionBox["1", "2"], ",", "0", ",", "0", ",", 
           FractionBox["1", "2"]}], "}"}]}], "}"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   "\"\<Find the output for PBT using a resource state consisting of 4 copies \
of the state below.\>\"", "\[IndentingNewLine]", 
   RowBox[{"NoisyBellState", "//", "MatrixForm"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Resource", "=", 
     RowBox[{"RepeatResource", "[", 
      RowBox[{"NoisyBellState", ",", "4"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ResourceInCorrectFormat", "=", 
     RowBox[{"ConvertResource", "[", "Resource", "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ChoiOfPBT", "=", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{
       RowBox[{"PBTChoiMatrix", "[", "ResourceInCorrectFormat", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"p", "\[GreaterEqual]", "0"}], ",", 
         RowBox[{"p", "\[LessEqual]", "1"}]}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\"\<Choi matrix of the resulting PBT channel\>\"", 
   "\[IndentingNewLine]", 
   RowBox[{"ChoiOfPBT", "//", "MatrixForm"}], "\[IndentingNewLine]", 
   "\"\<Corresponding Kraus operators\>\"", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"KrausOperators", "=", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{
       RowBox[{"ChoiToKraus", "[", "ChoiOfPBT", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"p", "\[GreaterEqual]", "0"}], ",", 
         RowBox[{"p", "\[LessEqual]", "1"}]}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Map", "[", 
    RowBox[{"MatrixForm", ",", "KrausOperators"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8259709194161687`*^9, 3.8259709386100307`*^9}, {
   3.825970974385121*^9, 3.825970975490999*^9}, 3.82597106613606*^9, {
   3.825971164654397*^9, 3.825971488154726*^9}, {3.825971559570323*^9, 
   3.82597170972521*^9}, {3.8259717438545356`*^9, 3.825971792568082*^9}},
 CellLabel->
  "In[614]:=",ExpressionUUID->"b7f8efb8-1fea-460f-897e-071bf991e916"],

Cell[BoxData["\<\"Find the output for PBT using a resource state consisting \
of 4 copies of the state below.\"\>"], "Output",
 CellChangeTimes->{
  3.825970922266642*^9, {3.825971221504896*^9, 3.825971292881733*^9}, {
   3.825971331615718*^9, 3.82597148887035*^9}, 3.8259715803298426`*^9, 
   3.825971689802623*^9, 3.8259717752476883`*^9, 3.825971806816643*^9},
 CellLabel->
  "Out[615]=",ExpressionUUID->"24fa02bf-f624-48a8-bab2-ef6ba104a99d"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox["p", "2"], "0", "0", 
      FractionBox["p", "2"]},
     {"0", 
      FractionBox[
       RowBox[{"1", "-", "p"}], "2"], 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "p"}], ")"}]}], "0"},
     {"0", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "p"}], ")"}]}], 
      FractionBox[
       RowBox[{"1", "-", "p"}], "2"], "0"},
     {
      FractionBox["p", "2"], "0", "0", 
      FractionBox["p", "2"]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.825970922266642*^9, {3.825971221504896*^9, 3.825971292881733*^9}, {
   3.825971331615718*^9, 3.82597148887035*^9}, 3.8259715803298426`*^9, 
   3.825971689802623*^9, 3.8259717752476883`*^9, 3.8259718068232684`*^9},
 CellLabel->
  "Out[616]//MatrixForm=",ExpressionUUID->"89b55d33-dbc2-48c6-952d-\
ce11651f262b"],

Cell[BoxData["\<\"Choi matrix of the resulting PBT channel\"\>"], "Output",
 CellChangeTimes->{
  3.825970922266642*^9, {3.825971221504896*^9, 3.825971292881733*^9}, {
   3.825971331615718*^9, 3.82597148887035*^9}, 3.8259715803298426`*^9, 
   3.825971689802623*^9, 3.8259717752476883`*^9, 3.825971807273957*^9},
 CellLabel->
  "Out[620]=",ExpressionUUID->"c875c109-a6e1-44de-b182-d420f958fc48"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       FractionBox["1", "64"], " ", 
       RowBox[{"(", 
        RowBox[{"19", "+", 
         RowBox[{"2", " ", 
          SqrtBox["2"]}], "+", 
         RowBox[{"2", " ", 
          SqrtBox["5"]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{"3", "+", 
            RowBox[{"2", " ", 
             SqrtBox["2"]}], "+", 
            RowBox[{"2", " ", 
             SqrtBox["5"]}]}], ")"}], " ", "p"}]}], ")"}]}], "0", "0", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "32"]}], " ", 
       RowBox[{"(", 
        RowBox[{"3", "+", 
         RowBox[{"2", " ", 
          SqrtBox["2"]}], "+", 
         RowBox[{"2", " ", 
          SqrtBox["5"]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "p"}], ")"}]}]},
     {"0", 
      RowBox[{
       FractionBox["1", "64"], " ", 
       RowBox[{"(", 
        RowBox[{"13", "-", 
         RowBox[{"2", " ", 
          SqrtBox["2"]}], "-", 
         RowBox[{"2", " ", 
          SqrtBox["5"]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"6", "+", 
            RowBox[{"4", " ", 
             SqrtBox["2"]}], "+", 
            RowBox[{"4", " ", 
             SqrtBox["5"]}]}], ")"}], " ", "p"}]}], ")"}]}], 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "32"]}], " ", 
       RowBox[{"(", 
        RowBox[{"3", "+", 
         RowBox[{"2", " ", 
          SqrtBox["2"]}], "+", 
         RowBox[{"2", " ", 
          SqrtBox["5"]}]}], ")"}], " ", "p"}], "0"},
     {"0", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "32"]}], " ", 
       RowBox[{"(", 
        RowBox[{"3", "+", 
         RowBox[{"2", " ", 
          SqrtBox["2"]}], "+", 
         RowBox[{"2", " ", 
          SqrtBox["5"]}]}], ")"}], " ", "p"}], 
      RowBox[{
       FractionBox["1", "64"], " ", 
       RowBox[{"(", 
        RowBox[{"13", "-", 
         RowBox[{"2", " ", 
          SqrtBox["2"]}], "-", 
         RowBox[{"2", " ", 
          SqrtBox["5"]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"6", "+", 
            RowBox[{"4", " ", 
             SqrtBox["2"]}], "+", 
            RowBox[{"4", " ", 
             SqrtBox["5"]}]}], ")"}], " ", "p"}]}], ")"}]}], "0"},
     {
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "32"]}], " ", 
       RowBox[{"(", 
        RowBox[{"3", "+", 
         RowBox[{"2", " ", 
          SqrtBox["2"]}], "+", 
         RowBox[{"2", " ", 
          SqrtBox["5"]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "p"}], ")"}]}], "0", "0", 
      RowBox[{
       FractionBox["1", "64"], " ", 
       RowBox[{"(", 
        RowBox[{"19", "+", 
         RowBox[{"2", " ", 
          SqrtBox["2"]}], "+", 
         RowBox[{"2", " ", 
          SqrtBox["5"]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{"3", "+", 
            RowBox[{"2", " ", 
             SqrtBox["2"]}], "+", 
            RowBox[{"2", " ", 
             SqrtBox["5"]}]}], ")"}], " ", "p"}]}], ")"}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.825970922266642*^9, {3.825971221504896*^9, 3.825971292881733*^9}, {
   3.825971331615718*^9, 3.82597148887035*^9}, 3.8259715803298426`*^9, 
   3.825971689802623*^9, 3.8259717752476883`*^9, 3.8259718072836323`*^9},
 CellLabel->
  "Out[621]//MatrixForm=",ExpressionUUID->"7fe84bcf-d61e-405f-9a31-\
4c714100809b"],

Cell[BoxData["\<\"Corresponding Kraus operators\"\>"], "Output",
 CellChangeTimes->{
  3.825970922266642*^9, {3.825971221504896*^9, 3.825971292881733*^9}, {
   3.825971331615718*^9, 3.82597148887035*^9}, 3.8259715803298426`*^9, 
   3.825971689802623*^9, 3.8259717752476883`*^9, 3.8259718073106146`*^9},
 CellLabel->
  "Out[622]=",ExpressionUUID->"75ff1015-17d4-4a8e-95c4-3896aea6ca44"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "4"]}], " ", 
         SqrtBox[
          RowBox[{
           FractionBox["13", "2"], "-", 
           SqrtBox["2"], "-", 
           SqrtBox["5"]}]]}], "0"},
       {"0", 
        RowBox[{
         FractionBox["1", "4"], " ", 
         SqrtBox[
          RowBox[{
           FractionBox["13", "2"], "-", 
           SqrtBox["2"], "-", 
           SqrtBox["5"]}]]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], ",", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        FractionBox[
         SqrtBox[
          RowBox[{
           FractionBox["313", "2"], "+", 
           SqrtBox["2"], "+", 
           RowBox[{"25", " ", 
            SqrtBox["5"]}], "+", 
           RowBox[{"28", " ", 
            SqrtBox["10"]}], "+", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{"279", "+", 
              RowBox[{"190", " ", 
               SqrtBox["2"]}], "+", 
              RowBox[{"142", " ", 
               SqrtBox["5"]}], "+", 
              RowBox[{"72", " ", 
               SqrtBox["10"]}]}], ")"}], " ", "p"}]}]], 
         RowBox[{"12", "+", 
          RowBox[{"8", " ", 
           SqrtBox["2"]}], "+", 
          RowBox[{"8", " ", 
           SqrtBox["5"]}]}]], "0"},
       {"0", 
        FractionBox[
         SqrtBox[
          RowBox[{"13", "-", 
           RowBox[{"2", " ", 
            SqrtBox["2"]}], "-", 
           RowBox[{"2", " ", 
            SqrtBox["5"]}], "+", 
           RowBox[{"4", " ", 
            RowBox[{"(", 
             RowBox[{"3", "+", 
              RowBox[{"2", " ", 
               SqrtBox["2"]}], "+", 
              RowBox[{"2", " ", 
               SqrtBox["5"]}]}], ")"}], " ", "p"}]}]], 
         RowBox[{"4", " ", 
          SqrtBox["2"]}]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], ",", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"0", 
        RowBox[{
         FractionBox["1", "4"], " ", 
         SqrtBox[
          RowBox[{
           FractionBox["13", "2"], "-", 
           SqrtBox["2"], "-", 
           SqrtBox["5"]}]]}]},
       {
        RowBox[{
         FractionBox["1", "4"], " ", 
         SqrtBox[
          RowBox[{
           FractionBox["1", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"13", "-", 
             RowBox[{"2", " ", 
              RowBox[{"(", 
               RowBox[{
                SqrtBox["2"], "+", 
                SqrtBox["5"]}], ")"}]}]}], ")"}]}]]}], "0"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], ",", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"0", 
        FractionBox[
         SqrtBox[
          RowBox[{"25", "+", 
           RowBox[{"6", " ", 
            SqrtBox["2"]}], "+", 
           RowBox[{"6", " ", 
            SqrtBox["5"]}], "-", 
           RowBox[{"4", " ", 
            RowBox[{"(", 
             RowBox[{"3", "+", 
              RowBox[{"2", " ", 
               SqrtBox["2"]}], "+", 
              RowBox[{"2", " ", 
               SqrtBox["5"]}]}], ")"}], " ", "p"}]}]], 
         RowBox[{"4", " ", 
          SqrtBox["2"]}]]},
       {
        RowBox[{"-", 
         FractionBox[
          SqrtBox[
           RowBox[{"25", "+", 
            RowBox[{"6", " ", 
             RowBox[{"(", 
              RowBox[{
               SqrtBox["2"], "+", 
               SqrtBox["5"]}], ")"}]}], "-", 
            RowBox[{"12", " ", "p"}], "-", 
            RowBox[{"8", " ", 
             RowBox[{"(", 
              RowBox[{
               SqrtBox["2"], "+", 
               SqrtBox["5"]}], ")"}], " ", "p"}]}]], 
          RowBox[{"4", " ", 
           SqrtBox["2"]}]]}], "0"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}], "}"}]], "Output",
 CellChangeTimes->{
  3.825970922266642*^9, {3.825971221504896*^9, 3.825971292881733*^9}, {
   3.825971331615718*^9, 3.82597148887035*^9}, 3.8259715803298426`*^9, 
   3.825971689802623*^9, 3.8259717752476883`*^9, 3.8259718123370256`*^9},
 CellLabel->
  "Out[624]=",ExpressionUUID->"45c2257f-499c-4a48-9a6f-24e969416f76"]
}, Open  ]]
},
WindowSize->{1920, 997},
WindowMargins->{{-8, Automatic}, {Automatic, -8}},
Magnification:>1.3 Inherited,
FrontEndVersion->"11.3 for Microsoft Windows (64-bit) (March 6, 2018)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 164277, 4027, 6356, "Input",ExpressionUUID->"3e6a16d1-b283-4aee-8be7-16120b527a8d"],
Cell[CellGroupData[{
Cell[164860, 4051, 3431, 87, 342, "Input",ExpressionUUID->"b7f8efb8-1fea-460f-897e-071bf991e916"],
Cell[168294, 4140, 445, 7, 43, "Output",ExpressionUUID->"24fa02bf-f624-48a8-bab2-ef6ba104a99d"],
Cell[168742, 4149, 1470, 44, 176, "Output",ExpressionUUID->"89b55d33-dbc2-48c6-952d-ce11651f262b"],
Cell[170215, 4195, 394, 6, 43, "Output",ExpressionUUID->"c875c109-a6e1-44de-b182-d420f958fc48"],
Cell[170612, 4203, 3986, 128, 192, "Output",ExpressionUUID->"7fe84bcf-d61e-405f-9a31-4c714100809b"],
Cell[174601, 4333, 385, 6, 43, "Output",ExpressionUUID->"75ff1015-17d4-4a8e-95c4-3896aea6ca44"],
Cell[174989, 4341, 5982, 182, 358, "Output",ExpressionUUID->"45c2257f-499c-4a48-9a6f-24e969416f76"]
}, Open  ]]
}
]
*)

